



****PLEASE USE STATA 14

/*Please download microdata Socioeconomic Survey 2018-2019 Ethiopia, 2018 - 2019 from 

https://microdata.worldbank.org/index.php/catalog/3823/get-microdata

Please data in folder ESS_2018
*/

**ETHIOPIA PRESUMPTIVE TAX PAPER 
** DOFILE #1


clear all
capture log close
set more off

ssc install winsor2


global rawdata 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2018
global newdata 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2018

global excel 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2018



** Sector classfications follow guideline. See https://unstats.un.org/unsd/publication/seriesm/seriesm_4rev4e.pdf



/* -------------------------------------------------------------------------- */
/*          CONSUMPTION AGGREGATES    -- RURAL AND URBAN                               */
/* -------------------------------------------------------------------------- */
 
use "$rawdata/cons_agg_w4.dta", clear



keep household_id cons_quint spat_totcons_aeq

tempfile consumption
save `consumption'
/* -------------------------------------------------------------------------- */
/*          A. HOUSEHOLD ROSTER                                     */
/* -------------------------------------------------------------------------- */
 ***Household roster 
 
use "$rawdata/sect1_hh_w4.dta", clear

ren saq14 rural 
ren saq01 region

ren s1q03a age
ren s1q02 sex
gen head=s1q01==1

ren s1q09 marital
keep household_id individual_id rural sex age  region
ren individual_id s12bq03_1
gen s12bq03_2=s12bq03_1
gen sex_1=sex
gen sex_2=sex

tempfile individual
save `individual'

 
 
 
/* -------------------------------------------------------------------------- */
/*         HH ENTERPRISE    - HH level                               */
/* -------------------------------------------------------------------------- */

* Data by household
 use "$rawdata/sect12a_hh_w4.dta", clear
 
 **household skip questions
 gen hh_nfe= s12aq01__1==1
 lab var hh_nfe "Non-ag enterprise or non-ag service"
 gen hh_agproduct=s12aq01__2==1
 lab var hh_agproduct "Processed or sold agricultural by-products"
 gen hh_trade= s12aq01__3==1
 lab var hh_trade "Trading business"
 gen hh_service=s12aq01__4==1
 lab var hh_service "Service or sold anything in street/market"
 gen hh_office= s12aq01__5==1
 lab var hh_office "Professional office"
 gen hh_carservice=s12aq01__6==1
 lab var hh_carservice "Car service (taxi or pickup truck)"
 gen hh_restaurant = s12aq01__7==1
 lab var hh_restaurant "Bar or restaurant"
 gen hh_othernfe=s12aq01__8==1
 lab var hh_othernfe "Other NFE"
 keep household_id hh*
 
tempfile enterprise
save `enterprise'
/* -------------------------------------------------------------------------- */
/*         HH ENTERPRISE                                  */
/* -------------------------------------------------------------------------- */

* By enterprise  
 use "$rawdata/sect12b1_hh_w4.dta", clear
 *1,735 enterprises
 

 *merge with indi data
merge m:1 household_id s12bq03_1 using  `individual'
drop if _m==2
drop _m
drop sex_2
lab var sex_1 "Sex of first owner"


merge m:1 household_id s12bq03_2 using  `individual'
drop if _m==2
drop _m
lab var sex_2 "Sex of second owner"

merge m:1 household_id  using  `enterprise'
drop if _m==2
drop _m


merge m:1 household_id  using  `consumption'
drop if _m==2
drop _m

**Sex of owner

gen owner_f= sex_1==2|sex_2==2
replace owner_f=. if sex==.
lab var owner_f "Owner is woman"

gen owner_m= sex_1==1|sex_2==1
replace owner_m=. if sex==.
lab var owner_m "Owner is man"

drop sex age

**Define male owner as male owner or male and female owner
gen owner_sex_2=1 if owner_m==1
replace owner_sex_2=2 if owner_m==0&owner_f==1
lab def owner_sex_2 1 "Male owned" 2 "Female owned", replace
lab val  owner_sex_2 owner_sex_2

gen owner_sex_3=1 if owner_m==1&owner_f==0
replace owner_sex_3=2 if owner_m==0&owner_f==1
replace owner_sex_3=3 if owner_m==1&owner_f==1
lab def owner_sex_3 1 "Male owned enterprise" 2 "Female owned enterprise" 3 "Jointly owned enterprise", replace
lab val  owner_sex_3 owner_sex_3

gen owner_joint=owner_m==1&owner_f==1

gen owner_nr=1 if sex_2==.
replace owner_nr=2 if sex_2!=.
lab var owner_n "Number of owners per enterprise"
*206 joint ownership

gen registered=s12bq18==1
lab var registered "Registered and has license"


preserve
*** By enterprise
keep household_id owner_sex_2  

gen enterprise_hh=1
gen male_owned=owner_sex_2==1
gen female_owned=owner_sex_2==2

collapse (max) male_owned female_owned enterprise_hh   , by(household_id)
lab var enterprise_hh "Household has NFE"

lab var male_owned "Male-owned enterprise"
lab var female_owned "Female-owned enterprise"
** 26 households have both

*** By household
save "$newdata/ethiopia_household_number.dta", replace
restore 


svyset ea_id[pw=pw_w4],  strata(region)
*******
**Where does it operate?
**********

gen home_inside=s12bq02==1
lab var home_inside "Inside residence"
gen home_outside= s12bq02==2
lab var home_outside "Home, outside residence"
gen market= s12bq02==3
lab var market "Traditional market"
gen shop= s12bq02==4
lab var shop "Shop in commercial area"
gen road= s12bq02==5
lab var road "Roadside"
gen mobile= s12bq02==6
lab var mobile "Mobile"
gen construction_site= s12bq02==8
lab var construction_site "Construction site"


****************************
**Sector
*************************
** Sector classfications follow guideline. See https://unstats.un.org/unsd/publication/seriesm/seriesm_4rev4e.pdf

gen bar=s12bq01a=="Bar"|s12bq01a=="Bar "
replace bar=1 if s12bq01a=="Hotel"|s12bq01a=="Hotel and restaurant"|s12bq01a=="Bar and accomodation "|s12bq01a=="Bar and Restaurant "
replace bar=1 if s12bq01a=="Bar and Restaurant"|s12bq01a=="Bar and accomodation"

lab var bar "Bars and hotels"

gen game= s12bq01a=="Bilyardo and pool table game house"|s12bq01a=="Bilyardo table game house"
replace game=1 if s12bq01a=="Pool table game house"
replace game=1 if s12bq01a=="Football table game house"|s12bq01a=="Game house"

gen restaurant=s12bq01a=="Tea room"|s12bq01a=="Restaurant"|s12bq01a=="Restaurant "
replace restaurant=1 if s12bq01a=="Retaurant "|s12bq01a=="Retaurant"
replace restaurant=1 if s12bq01a=="Coffee house"|s12bq01a=="Coffee house and Oil shop"|s12bq01a=="Tea room"|s12bq01a=="Tea  room"|s12bq01a=="Coffe house"
lab var restaurant "Restaurants and coffee houses"

*Bakeries= manufacturing of food 
gen bakery=s12bq01a=="Bakery"|s12bq01a=="Bakery and breakfast house" 
lab var bakery "Bakeries"


**** SUBSECTOR: FOOD AND BEVERAGE SERVICES AND HOTELS (Bakeries=food manuf)

gen food_service=s12bq01b==56
replace food_service=1 if s12bq01a=="Waiter"|s12bq01a=="Waiter "
replace food_service=1 if restaurant==1|bar==1
replace food_service=0 if s12bq01a=="Grocery"|s12bq01a=="Researcher"

lab var food_service "Food and beverage services & hotels, exc alcohol"

gen food_trade=s12bq01a=="Potato trader"|s12bq01a=="Papper trader"|s12bq01a=="Selling fruits "|s12bq01a=="Selling fruits  and vegetables" |s12bq01a=="Selling vegetables"|s12bq01a=="Selling vegetables "|s12bq01a=="Vegetable trader"|s12bq01a=="Vegetable trader "|s12bq01a=="Selling cooked potato and beans "||s12bq01a=="Selling cooked potato and beans"
replace food_trade=1 if s12bq01a=="Selling spicy food"|s12bq01a=="Selling Cookie"|s12bq01a=="Selling cooked potato"
replace food_trade=1 if s12bq01a=="Selling coffee"|s12bq01a=="Selling milk"|s12bq01a=="Selling water"|s12bq01a=="Selling water "
replace food_trade=1 if s12bq01a=="retail of grains"|s12bq01a=="Crop buying and selling "|s12bq01a=="Crop selling "|s12bq01a=="Crop trader"|s12bq01a=="Crop trader "|s12bq01a=="Selling Flour"
replace food_trade=1 if s12bq01a=="Selling maize"|s12bq01a=="Selling maize and sorghum"
replace food_trade=1 if s12bq01b==47&s12bq01a=="Selling Enjera "|s12bq01b==47&s12bq01a=="Selling Enjera"
replace food_trade=1 if s12bq01a=="Grocery"
replace food_trade=1 if s12bq01a=="Sheep trader"|s12bq01a=="Chicken trader"|s12bq01a=="Goat trader"|s12bq01a=="Livestock trader"
replace food_trade=1 if s12bq01a=="Vegetable store"|s12bq01a=="Supermarket"
** 0 if wholesale
replace food_trade=0 if s12bq01b ==45
lab var food_trade "Retail trade in fruit, vegetables, cereal"


*** MANUFACTURING/SALE OF LOCAL BEVERAGE 
 gen alcohol=  s12bq01a=="Producing local drinks"|s12bq01a=="Selling beer and local beer"|s12bq01a=="Selling of local beer"
replace alcohol=1 if s12bq01a=="Selling Areke"|s12bq01a=="Selling Areke and Tela"
replace alcohol=1 if s12bq01a=="Selling alcholic beverages"|s12bq01a=="Selling beverages"|s12bq01a=="Selling honey wine "|s12bq01a=="Selling local beer"
replace alcohol=1 if s12bq01a=="Selling alcholic beverages"|s12bq01a=="Selling beverages"|s12bq01a=="Selling honey wine"|s12bq01a=="Selling local beer"
replace alcohol=1 if s12bq01a=="Selling alcholic beverages"|s12bq01a=="Selling beverages"
replace alcohol=1 if s12bq01a=="Selling Areke"|s12bq01a=="Selling Areke and Tela"
replace alcohol=1 if s12bq01a=="Selling of local beer"|s12bq01a== "Selling local beer"|s12bq01a== "Producing and selling honey wine "|s12bq01a== "Selling beer and local beer" |s12bq01a== "Producing and selling honey wine"
replace alcohol=1 if s12bq01a=="Areke Production"|s12bq01a=="Areke Production and Selling"|s12bq01a=="Areke and Borde Production"|s12bq01a=="Areke and Tela Production"
replace alcohol=1 if s12bq01a=="Producing and selling local beer"| s12bq01a=="Producing and selling local drinks"| s12bq01a=="Producing local beer"| s12bq01a=="Selling Areke"| s12bq01a=="Selling Areke and Tela"| s12bq01a=="Selling local drinks"
replace alcohol=1 if (s12bq01a=="Selling Areke"|s12bq01a=="Selling Areke and Tela"|s12bq01a=="Selling alcholic beverages"|s12bq01a=="Selling beverages"|s12bq01a=="Selling honey wine "|s12bq01a=="Selling local beer")

gen manuf_beverage=s12bq01b==11
replace manuf_beverage=1 if alcohol==1

replace manuf_beverage=0 if s12bq01a=="Transport service"|s12bq01a=="Restaurant"|s12bq01a=="Retailer"
lab var manuf_beverage "Manufacture beverages"

replace food_service=0 if alcohol==1
replace food_trade=0 if alcohol==1



gen manuf_food= s12bq01b==10
replace manuf_food=1 if s12bq01a=="Refrigerate bananas"|s12bq01a=="Ripen bananas"
replace manuf_food=1 if  s12bq01a=="Boutchery shop"|s12bq01a=="Butchery shop"| s12bq01a=="Butcher"
replace manuf_food=1 if bakery==1
lab var manuf_food "Manufacture food products"

replace food_service=0 if food_service==1&alcohol==1
replace food_service=0 if food_service==1&manuf_food==1

gen manuf_cloth= s12bq01b==13|s12bq01b==14
replace manuf_cloth=1 if s12bq01a=="Tailor"|s12bq01a=="Tailor and boutique"|s12bq01a=="Upholsterer"
lab var manuf_cloth "Manufacture of textile or wearing apparel"

gen wood=s12bq01a==" Selling Charcoal"|s12bq01a=="Charcoal trader"|s12bq01a=="Charoal trader"
replace wood=1 if s12bq01a=="Collecting and Selling fire wood "|s12bq01a=="Collecting and Selling wood "|s12bq01a=="Collecting and selling wood"
replace wood=1 if s12bq01a=="Selling wood"|s12bq01a=="Selling wood "|s12bq01a=="Selling wood and charcoal"
replace wood=1 if s12bq01a=="Selling water and wood"|s12bq01a=="Producing Charcoal"|s12bq01a=="Selling fire wood"|s12bq01a=="Selling charcoal"|s12bq01a=="Producing and selling Charcoal"
replace wood=1 if s12bq01a=="Collecting and Selling fire wood"
replace wood=1 if s12bq01a=="Collecting and Selling wood"|s12bq01a=="Selling Charcoal"

lab var wood "Sell wood or charcoal"


gen manuf_wood= s12bq01b==16|s12bq01b==31
replace manuf_wood=1 if s12bq01a=="Carpenter"

replace manuf_wood=0 if wood==1&(s12bq01b ==16)
lab var manuf_wood "Manufacture wood products or furniture"

gen manuf_metal=s12bq01b==25
replace manuf_metal=1 if s12bq01a=="Metal works "|s12bq01a=="Metal works"
lab var manuf_metal "Manufacture metal products"

gen manuf_other= manuf_wood +manuf_metal
replace manuf_other=1 if s12bq01b==15|s12bq01b==21|s12bq01b==25|s12bq01b==32
lab var manuf_other "Other manufacturing"

gen transit= s12bq01b==49
replace transit=1 if s12bq01a=="Bajaj Operator and owner"
replace transit=1 if s12bq01a=="Transport service"
lab var transit "Transit service"

*Wholesale
gen wholesale=s12bq01b ==46|s12bq01b ==45
lab var wholesale "Wholesale trade"


gen retail_other=s12bq01b==47

replace retail_other=1 if wood==1&(s12bq01b ==47|s12bq01b ==96|s12bq01b ==16)
replace retail_other=0 if transit==1| food_service==1 |food_trade==1| manuf_food==1| alcohol==1| manuf_cloth==1| manuf_wood==1| manuf_metal==1| manuf_other==1| wholesale==1
replace retail_other=0 if alcohol==1
lab var retail_other "Other retail trade"

egen retail_all=rowtotal(food_trade  retail_other)
lab var retail_all "All retail trade"
egen sector_trade=rowtotal(retail_all wholesale ) 
lab var sector_trade "Trade"

gen other_pc=s12bq01b==96
replace other_pc=0 if transit==1| food_service==1 |food_trade==1| manuf_food==1| alcohol==1| manuf_cloth==1| manuf_wood==1| manuf_metal==1| manuf_other==1|  wholesale==1|retail_other==1
lab var other_pc "Other personal service activities"

egen sector_service=rowtotal(transit alcohol food_service other_pc)
lab var sector_service "Service sector"
egen sector_manuf=rowtotal(manuf_food manuf_cloth manuf_other)
lab var sector_manuf "Manufacturing sector"
egen temp5=rowtotal(sector_manuf sector_service sector_trade)

drop temp5


gen sector_primary=s12bq01b ==1|s12bq01b ==2|s12bq01b ==7|s12bq01b ==8
lab var sector_primary "Ag production or mining sectors"

lab var sector_primary "Ag production or mining sectors"
gen sector_construction=s12bq01b==33|s12bq01b==41|s12bq01b==43
lab var sector_construction "Construction sector"

**** Professional, scientific, technical, administrative and support activities,Public administration and defence, education, human health and social work activities
*This section includes a variety of activities that support general business operations
***Includes Renting motor vehicles, guard services, education, health
gen guard=s12bq01a=="Guard"

gen sector_prof=s12bq01b==69|s12bq01b==71|s12bq01b==72|s12bq01b==74|s12bq01b==77|s12bq01b==78|s12bq01b==79|s12bq01b==80|s12bq01b==82|s12bq01b==84|s12bq01b==85|s12bq01b==86|s12bq01b==87|s12bq01b==88
replace sector_prof=1 if s12bq01a=="Professional service"|guard==1|s12bq01a=="Researcher"
replace sector_prof=1 if s12bq01a=="Bicycle renting"|s12bq01a=="Computer maintainance"|s12bq01a=="Engineer"|s12bq01a=="Maintenance work"
replace sector_prof=1 if s12bq01a=="Car rental"
replace sector_prof=1 if s12bq01a=="Renting and maintaining bicycle"
lab var sector_prof "Professional, admin support activities"

replace sector_prof=0 if sector_primary==1|transit==1| food_service==1 | manuf_food==1| alcohol==1| manuf_cloth==1| manuf_wood==1| manuf_metal==1| manuf_other==1|  wholesale==1|retail_other==1

egen temp4=rowtotal(sector_manuf sector_service sector_trade sector_primary sector_construction sector_prof)
gen sector_misc=temp4==0

lab var sector_misc "Misc"

drop temp4

gen other_activities=sector_primary+sector_construction+sector_misc
lab var other_activities "Other"

egen temp6=rowtotal(sector_manuf sector_service sector_trade sector_primary sector_prof sector_construction sector_misc )
drop temp6 
 
 

gen sector=1 if sector_manuf==1
replace sector=2 if sector_trade==1
replace sector=3 if sector_service==1
replace sector=4 if sector_prof==1
replace sector=5 if sector_construction==1
replace sector=6 if sector_primary==1
replace sector=7 if sector_misc==1
lab def sector 1 "Manufacturing" 2 "Trade" 3 "Services" 4 "Professional, admin support"   5 "Construction" 6  "Agriculture and mining"  7 "Others", replace
lab val sector sector
lab var sector "Sectors"

gen food_service_alcohol=food_service==1|alcohol==1
lab var food_service_alcohol "Food and beverage services and hotels, inc local beverage"

gen sub_sector=1 if manuf_food==1
replace sub_sector=2 if manuf_cloth==1
replace sub_sector=3 if manuf_other==1
replace sub_sector=4 if retail_all==1
replace sub_sector=5 if wholesale==1
replace sub_sector=6 if alcohol==1
replace sub_sector=7 if food_service==1
replace sub_sector=8 if transit==1
replace sub_sector=9 if other_pc==1
replace sub_sector=10 if sector_construction==1
replace sub_sector=11 if sector_prof==1
replace sub_sector=12 if  sector_primary==1
replace sub_sector=13 if sector_misc==1
lab def sub_sector  1 "Manufacturing food" 2 "Manufacturing clothes" 3 "Other manufacturing" 4 "Retail trade" 5 "Wholesale trade" 6 "Manufacture or sale of local beverages" 7 "Food and beverage services and hotels" 8 "Transportation services" 9 "Other personal services" 10 "Construction" 11 "Professional, admin support"   12 "Agriculture and mining" 13 "Others", replace
lab val sub_sector sub_sector
lab var sub_sector "Sub-sectors"



gen retail_stall=retail_all==1&(market==1|shop==1)
lab var retail_stall "Retail at market or stall"
gen retail_otherplace=retail_all==1&retail_stall==0
lab var retail_otherplace "Retail at other locations"

*************
** Now disaggregate by activities  - to align with presumptive tax schedule
****
**Oil and coffee sale same 10%
gen oil=s12bq01a =="Oil distributer "|s12bq01a =="Oil and sugar distributer "
replace oil=1 if s12bq01a =="Selling coffee"|s12bq01a =="Oil distributer"|s12bq01a =="Oil and sugar distributer"

gen cotton= s12bq01a=="Producing and selling cotton yarn"

gen chat=s12bq01a=="Chat trader"|s12bq01a=="Chat Production"
lab var chat "Chat trader"

*Animal products sale& chicken sale
gen meat=s12bq01a=="Sheep trader"|s12bq01a=="Chicken trader"|s12bq01a=="Goat trader"|s12bq01a=="Livestock trader"
replace meat =1 if s12bq01a=="House and Animal trader"|s12bq01a=="Chicken Farm"
replace meat =1 if s12bq01a=="Selling milk"|s12bq01a=="Distributing milk"
lab var meat "Meat trader"

gen butcher=s12bq01a=="Boutchery shop"|s12bq01a=="Butchery shop"| s12bq01a=="Butcher"

**General Merchandise  Trade and Grocery
gen store=s12bq01a=="Grocery"|s12bq01a=="Vegetable store"|s12bq01a=="Supermarket"
replace store=1 if s12bq01a=="Biskut seller"
replace store=1 if  s12bq01a=="Selling water"|s12bq01a=="Selling water "
replace store=1 if  s12bq01a=="Selling soft drinks"|s12bq01a== "Selling spicy food"| s12bq01a=="Selling cooked potato"|s12bq01a=="Selling cooked potato and beans "  
replace store=1 if  s12bq01a=="Distributing drinks"|s12bq01a=="Selling bread "|s12bq01a=="Selling bread"
replace store=1 if  s12bq01a=="Producing and selling Enjera"|s12bq01a=="Selling Enjera "|s12bq01a=="Selling Enjera"
replace store=1 if  s12bq01a=="Producing and selling food  spices"
replace store=1 if  s12bq01a=="Selling cooked potato and beans"
replace store=1 if  s12bq01a=="Selling Cookie"
lab var store "Store/supermarket, merchandice"

gen veg_trade=s12bq01a=="Potato trader"|s12bq01a=="Papper trader"|s12bq01a=="Selling fruits "|s12bq01a=="Selling fruits  and vegetables" |s12bq01a=="Selling vegetables"|s12bq01a=="Selling vegetables "|s12bq01a=="Vegetable trader"|s12bq01a=="Vegetable trader "|s12bq01a=="Selling fruits"
lab var veg_trade "Fruits and vegetable trade"

gen gold_trade=s12bq01a=="Gold trader"|s12bq01a=="Selling gold"

gen grain=s12bq01a=="retail of grains"|s12bq01a=="Crop buying and selling "|s12bq01a=="Crop selling "|s12bq01a=="Crop trader"|s12bq01a=="Crop trader "|s12bq01a=="Selling Flour"
replace grain=1 if s12bq01a=="Selling maize"|s12bq01a=="Selling maize and sorghum"
replace grain=1 if s12bq01a=="Crop buying and selling"|s12bq01a=="Crop selling"
lab var grain "Selling cereals"

replace grain=0 if s12bq01a=="Selling Enjera "&s12bq01b==56

gen mill=s12bq01a=="Mill service"
gen furniture=s12bq01a=="Furniture store"

gen construction_building=s12bq01b==41|s12bq01b==43
lab var construction_building "Construction of buildings"

gen clay=s12bq01a=="Producing materials from clay"|s12bq01a=="Producing materials from clay"|s12bq01a=="Producing materials from clay and selling"
replace clay=1 if s12bq01a=="Selling building materials"|s12bq01a=="Producing materials from clay "
replace clay=1 if s12bq01a=="Cement trader"

gen factory=s12bq01a=="Blocket factory "

gen beautysalon=s12bq01a=="Beauty salon"|s12bq01a=="Barber"
lab var beautysalon "Beauty salon"
gen boutique=s12bq01a=="Boutique"|s12bq01a=="Boutique "
replace boutique=1 if s12bq01a=="Selling cloths"
gen carpenter=s12bq01a== "Carpenter"|s12bq01a== "Wood production"|s12bq01a== "Wood manufacturing "


gen bamboo=s12bq01a=="Bamboo craft"
replace bamboo=1 if s12bq01a=="Craftsman"|s12bq01a=="Craftswoman"
replace bamboo=1 if s12bq01a=="Handcraft "
replace bamboo=1 if s12bq01a=="Handcraft"

 gen tire=s12bq01a== "Tire technician"
 replace tire=1 if s12bq01a== "Spare part"
 gen phone=s12bq01a=="Mobile Phone shop"|s12bq01a=="Mobile Phone maintainance"
 gen electrician=s12bq01a=="Electrician "|s12bq01a=="Electric service"
 replace electrician=1 if s12bq01a=="Installation worker"|s12bq01a=="Electrician"
 
 gen broker=s12bq01a=="Broker"|s12bq01a== "Broker "
 gen leather=s12bq01a=="Leather factory"
 gen mason=s12bq01a=="Mason"|s12bq01a=="Mason "
 gen mechanic=s12bq01a=="Mechanic"|s12bq01a=="Mechanic "
 
 gen movie=s12bq01a=="Film house"|s12bq01a=="Movie house"
 
gen laundry=s12bq01a=="Laundary service"|s12bq01a=="Laundary and computer  service"
gen shoe=s12bq01a=="Shoe seller"|s12bq01a=="Shoemaker"


*****************
*TAXES ON PROFITS AND INCOME
**********************

gen taxpaid=s12bq20==1
lab var taxpaid "Was any tax paid as profit or income tax?"

gen tax=s12bq21
replace tax=0 if taxpaid==0
lab var tax "Taxes paid as profit or income tax,=0 if no tax paid"
winsor2 tax, replace cuts(0 98) trim
 format tax %12.0gc
 
gen tax_0=tax/1000
lab var tax_0 "Taxes paid as profit or income tax, '000"

gen markettax_paid=s12bq22==1
lab var markettax_paid "Paid market tax, municipality fee"

gen markettax=s12bq23
replace markettax=0 if markettax_paid==0
lab var markettax "Market taxes paid (Birr)"
winsor2 markettax, replace cuts(0 98) trim
 format markettax %12.0gc

gen markettax_0=markettax/1000
lab var markettax_0 "Market taxes paid ('000 Birr)"
 
*How many months active?

*9 firms 0 months active
ta s12bq12
*Drop inactive firms 
drop if s12bq12==0

*********************
** Gross turnover
********************

*Monthly sales s12bq16
replace s12bq12=12 if s12bq12>12

*** Drop if sale_monthly==0
ta s12bq16

gen sale_monthly=s12bq16
lab var sale_monthly "Average monthly sales"

drop if sale_monthly==0
*122 dropped

*1,604 firms left

gen sale_monthly_0=sale_monthly/1000
lab var sale_monthly_0 "Average monthly sales ('000 Birr)"

gen gross=sale_monthly*s12bq12 
lab var gross "Annual turnover, Birr"

*Restrict to Category C enterprises
count if gross>=500000
*50 firms over the Category C limit
drop if gross>=500000

winsor2 gross, replace cuts(1 100) trim
drop if gross==.
*15 dropped
** 1,539 firms left


gen gross_0=gross/1000
lab var gross_0 "Annual turnover ('000 Birr)"

*gen percentage_income=s12bq24
*lab var percentage_income "Percentage of income from NFE"

gen     gross_cat=1 if gross_0<=50
replace gross_cat=2 if gross_0>50&gross_0<=75
replace gross_cat=3 if gross_0>75&gross_0<=100
replace gross_cat=4 if gross_0>100&gross_0<=125
replace gross_cat=5 if gross_0>125&gross_0<=150
replace gross_cat=6 if gross_0>150&gross_0<=175
replace gross_cat=7 if gross_0>175&gross_0<=200
replace gross_cat=8 if gross_0>200&gross_0<=225
replace gross_cat=9 if gross_0>225&gross_0<=250
replace gross_cat=10 if gross_0>250&gross_0<=275
replace gross_cat=11 if gross_0>275&gross_0<=300
replace gross_cat=12 if gross_0>300&gross_0<=325
replace gross_cat=13 if gross_0>325&gross_0<=350
replace gross_cat=14 if gross_0>350&gross_0<=375
replace gross_cat=15 if gross_0>375&gross_0<=400
replace gross_cat=16 if gross_0>400&gross_0<=425
replace gross_cat=17 if gross_0>425&gross_0<=450
replace gross_cat=18 if gross_0>450&gross_0<=475
replace gross_cat=19 if gross_0>475&gross_0<=500
lab def gross_cat 1 "<50,000" 2 "50,001-75,000" 3 "75,001-100,000" 4 "100,001-125,000" 5 "125,001-150,000" 6 "150,001-175,000" 7 "175,001-200,000" 8 "200,001-225,000" 9 "225,001-250,000" ///
10 "250,001-275,000" 11 "275,001-300,000" 12 "300,001-325,000" 13 "325,001-350,000" 14 "350,001-375,000" 15 "375,001-400,000" ///
16 "400,001-425,000" 17 "425,001-450,000" 18 "450,001-475,000" 19 "475,001-500,000"
lab val gross_cat gross_cat
lab var gross_cat "Turnover, Birr"

bysort gross_cat: su tax
gen gross_50=gross_0<=50
lab var gross_50 "<=50,000 Birr"

gen     gross_cat_10=1 if gross_0<=50
replace gross_cat_10=2 if gross_0>50&gross_0<=75
replace gross_cat_10=3 if gross_0>75&gross_0<=100
replace gross_cat_10=4 if gross_0>100&gross_0<=125
replace gross_cat_10=5 if gross_0>125&gross_0<=150
replace gross_cat_10=6 if gross_0>150&gross_0<=175
replace gross_cat_10=7 if gross_0>175&gross_0<=200
replace gross_cat_10=8 if gross_0>200&gross_0<=300
replace gross_cat_10=9 if gross_0>300&gross_0<=400
replace gross_cat_10=10 if gross_0>400&gross_0<500
lab def gross_cat_10 1 "<=50" 2 "50-75" 3 "75-100" 4 "100-125" 5 "125-150" 6 "150-175" 7 "175-200" 8 "200-300" 9 "300-400" 10 "400-500", replace 
lab val gross_cat_10 gross_cat_10
lab var gross_cat_10 "Turnover, '000 Birr"


* No employees: Own account enterprises
gen ownaccount=s12bq14==0
lab var ownaccount "Own account"
gen micro=s12bq14<=5
lab var micro "Microenterprise: 5 or less"

gen employee=s12bq14
lab var employee "Number of employees"

gen taxrate=(tax/gross)*100
lab var taxrate  "Tax as % of turnover"
replace taxrate=. if taxrate>100
*9 obs

gen obs_tax= s12bq25_1==131|s12bq25_2==131|s12bq25_3==131
lab var obs_tax "High taxes an obstacle (%)"

gen obs_informaltax= s12bq25_1==132|s12bq25_2==132|s12bq25_3==132
lab var obs_informaltax "Unofficial taxes an obstacle (%)"



**Annual costs of goods sold, 000 Birr
gen month_operational= s12bq12
lab var month_operational "Number of months operational"


gen goods=(s12bq17b*month_operational)
lab var goods "Annual purchase of goods for sale, Birr"
gen rawmaterial=(s12bq17c*month_operational)
lab var rawmaterial "Annual raw materials, Birr"


**Customer base
gen customer_local=s12bq09_1==1
lab var customer_local "Local consumers, passerby"
gen customer_market=s12bq09_1==2
lab var customer_market "Market"
gen customer_trader=s12bq09_1==3
lab var customer_trader "Traders"

gen urban=rural==2
lab var urban "Urban"


**Impute presumptive taxes by sector and turnover


** Chat trade (16%)
gen presump_impute=80 if chat==1&gross_cat==1
replace presump_impute=480 if chat==1&gross_cat==2
replace presump_impute=880 if chat==1&gross_cat==3
replace presump_impute=1290 if chat==1&gross_cat==4
replace presump_impute=1890 if chat==1&gross_cat==5
replace presump_impute=2490 if chat==1&gross_cat==6
replace presump_impute=3090 if chat==1&gross_cat==7
replace presump_impute=3690 if chat==1&gross_cat==8
replace presump_impute=5170 if chat==1&gross_cat==10
replace presump_impute=5970 if chat==1&gross_cat==11
replace presump_impute=11220 if chat==1&gross_cat==17

** Charcoal trade (10%)
replace presump_impute=0 if wood==1&gross_cat==1
replace presump_impute=30 if wood==1&gross_cat==2
replace presump_impute=530 if wood==1&gross_cat==4
replace presump_impute=1030 if wood==1&gross_cat==6
replace presump_impute=1290 if wood==1&gross_cat==7
replace presump_impute=3915 if wood==1&gross_cat==14

** Beauty salon (10%)
replace presump_impute=0 if beautysalon==1&gross_cat==1
replace presump_impute=30 if beautysalon==1&gross_cat==2
replace presump_impute=280 if beautysalon==1&gross_cat==3
replace presump_impute=1290 if beautysalon==1&gross_cat==7


**Weaving/boutique (10%) = Thread, Textiles and Textile Products Trade /Tailoring Service Only (same rate)
replace presump_impute=0 if (manuf_cloth==1|boutique==1)&gross_cat==1
replace presump_impute=30 if (manuf_cloth==1|boutique==1)&gross_cat==2
replace presump_impute=280 if (manuf_cloth==1|boutique==1)&gross_cat==3
replace presump_impute=530 if (manuf_cloth==1|boutique==1)&gross_cat==4
replace presump_impute=780 if (manuf_cloth==1|boutique==1)&gross_cat==5
replace presump_impute=2040 if (manuf_cloth==1|boutique==1)&gross_cat==9
replace presump_impute=2790 if (manuf_cloth==1|boutique==1)&gross_cat==11
replace presump_impute=3165 if (manuf_cloth==1|boutique==1)&gross_cat==12
replace presump_impute=3540 if (manuf_cloth==1|boutique==1)&gross_cat==13
replace presump_impute=3915 if (manuf_cloth==1|boutique==1)&gross_cat==14
replace presump_impute=4370 if(manuf_cloth==1|boutique==1)&gross_cat==15


** Cereal Trade =Cereals and Pulses Trade (10%)
replace presump_impute=0 if grain==1&gross_cat==1
replace presump_impute=30 if grain==1&gross_cat==2
replace presump_impute=780 if grain==1&gross_cat==5
replace presump_impute=1290 if grain==1&gross_cat==7
replace presump_impute=3915 if grain==1&gross_cat==14
replace presump_impute=4370 if grain==1&gross_cat==15

* Meat trader (10%) = animal / animal product trade, also = Chicken and Egg Trade 
replace presump_impute=0 if meat==1&gross_cat==1
replace presump_impute=30 if meat==1&gross_cat==2
replace presump_impute=280 if meat==1&gross_cat==3
replace presump_impute=530 if meat==1&gross_cat==4
replace presump_impute=780 if meat==1&gross_cat==5
replace presump_impute=2040 if meat==1&gross_cat==9

**Edible oil or bamboo prod or tyre repair or grain cleaning =mill service (10%)
replace presump_impute=0 if (bamboo==1|oil==1|tire==1|mill==1)&gross_cat==1
replace presump_impute=30 if oil==1&gross_cat==2
replace presump_impute=530 if (bamboo==1|oil==1|tire==1)&gross_cat==4
replace presump_impute=780 if oil==1&gross_cat==5

**Furniture store, carpenter? = Bed ,Mattress and Dengel Production and Trade? (10%)
replace presump_impute=0 if (carpenter==1|furniture==1)&gross_cat==1
replace presump_impute=30 if (carpenter==1|furniture==1)&gross_cat==2
replace presump_impute=280 if (carpenter==1|furniture==1)&gross_cat==3
replace presump_impute=530 if (carpenter==1|furniture==1)&gross_cat==4
replace presump_impute=780 if (carpenter==1|furniture==1)&gross_cat==5
replace presump_impute=2790 if (carpenter==1|furniture==1)&gross_cat==11

replace presump_impute=4370 if (carpenter==1|furniture==1)&gross_cat==15

***Laundry service (11%)
replace presump_impute=0 if laundry==1&gross_cat==1
replace presump_impute=380 if laundry==1&gross_cat==3

*Guard service (12%)
replace presump_impute=0 if guard==1&gross_cat==1

**Fruit and veg trade (13%)
replace presump_impute=0 if veg_trade==1&gross_cat==1
replace presump_impute=905 if veg_trade==1&gross_cat==4
replace presump_impute=1230 if veg_trade==1&gross_cat==5

*Butcher = slaughter services (13%)
replace presump_impute=0 if butcher==1&gross_cat==1
replace presump_impute=255 if butcher==1&gross_cat==2
replace presump_impute=905 if butcher==1&gross_cat==4
replace presump_impute=3165 if butcher==1&gross_cat==9

**Mechanic & motorcycle operater=Vehicles Spare Parts Trade and Workshop Services (13%)
replace presump_impute=0 if mechanic==1&gross_cat==1
replace presump_impute=0 if s12bq01a=="Motorcycle Operator and owner"&gross_cat==1

replace presump_impute=255 if mechanic==1&gross_cat==2
replace presump_impute=580 if mechanic==1&gross_cat==3
replace presump_impute=905 if mechanic==1&gross_cat==4
replace presump_impute=2190 if mechanic==1&gross_cat==7
replace presump_impute=3165 if mechanic==1&gross_cat==9

gen internet_service=s12bq01a =="Internet service "|s12bq01a =="Internet service"
gen banana=s12bq01a=="Refrigerate bananas"|s12bq01a=="Ripen bananas"

** Grocery store/supermarket =General Merchandise  Trade and Grocery(14%)
*** Classify local alcohol and beverage manuf under this one.
**Internet service (14%)
replace presump_impute=0 if (banana==1|internet_service==1|alcohol==1|store==1|bakery==1)&gross_cat==1
replace presump_impute=330 if (internet_service==1|alcohol==1|store==1|bakery==1)&gross_cat==2
replace presump_impute=680 if (internet_service==1|alcohol==1|store==1|bakery==1)&gross_cat==3
replace presump_impute=1030 if (internet_service==1|alcohol==1|store==1|bakery==1)&gross_cat==4
replace presump_impute=1440 if (internet_service==1|alcohol==1|store==1|bakery==1)&gross_cat==5
replace presump_impute=2490 if (internet_service==1|alcohol==1|store==1|bakery==1)&gross_cat==7
replace presump_impute=3540 if (internet_service==1|alcohol==1|store==1|bakery==1)&gross_cat==9
replace presump_impute=4070 if (internet_service==1|alcohol==1|store==1|bakery==1)&gross_cat==10
replace presump_impute=6870 if (internet_service==1|alcohol==1|store==1|bakery==1)&gross_cat==14


**Shoe and Shoe imputs sales, Shoe Making and Repair (18%)
replace presump_impute=180 if shoe==1&gross_cat==1

**Leather- Producing Leather  Products, Tailoring  and Trade (21%)
replace presump_impute=330 if leather==1&gross_cat==1

**Movie = Cinema Houses (27%)
replace presump_impute=630 if movie==1&gross_cat==1
replace presump_impute=3353 if movie==1&gross_cat==4


** Transit services (30%)
replace presump_impute=780 if transit==1&gross_cat==1
replace presump_impute=1665 if transit==1&gross_cat==2
replace presump_impute=2790 if transit==1&gross_cat==3
replace presump_impute=3915 if transit==1&gross_cat==4
replace presump_impute=5370 if transit==1&gross_cat==5
replace presump_impute=6870 if transit==1&gross_cat==6
replace presump_impute=8370 if transit==1&gross_cat==7
replace presump_impute=10095 if transit==1&gross_cat==8
replace presump_impute=11970 if transit==1&gross_cat==9
replace presump_impute=13845 if transit==1&gross_cat==10
replace presump_impute=15720 if transit==1&gross_cat==11
replace presump_impute=16125 if transit==1&gross_cat==12
replace presump_impute=18750 if transit==1&gross_cat==13

** Manuf metal, producing clay, gold trade - Gold, Silver Smith, Jewelry and other Precious Minerals Trade (15%), Is this "Metal and Building Materials Trade" (15%) not "Construction Materials Production and Trade" (18%)
replace presump_impute=30 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==1
replace presump_impute=405 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==2
replace presump_impute=1155 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==4
replace presump_impute=2228 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==6
replace presump_impute=3353 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==8
replace presump_impute=3915 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==9


* Building contractor or  mason=Building Contractors (16%)
replace presump_impute=80 if (mason==1|construction_building==1)&gross_cat==1
replace presump_impute=480 if (mason==1|construction_building==1)&gross_cat==2
replace presump_impute=880 if (mason==1|construction_building==1)&gross_cat==3
replace presump_impute=1290 if (mason==1|construction_building==1)&gross_cat==4
replace presump_impute=1890 if (mason==1|construction_building==1)&gross_cat==5
replace presump_impute=5970 if (mason==1|construction_building==1)&gross_cat==11

**Blocket factory=General Manufacturing Industries Production (Factory Level) (16%)
replace presump_impute=11220 if  factory==1&gross_cat==17

**Phone store=Electronic Goods Supply and Repair (16%)
replace presump_impute=80 if  phone==1&gross_cat==1
replace presump_impute=480 if  phone==1&gross_cat==2
replace presump_impute=880 if  phone==1&gross_cat==3
replace presump_impute=1290 if  phone==1&gross_cat==4

** Cotton trade (17%)
replace presump_impute=130 if cotton==1&gross_cat==1

***Electricians? =Electrical Lift Works and Repair (25%)
replace presump_impute=530 if  electrician==1&gross_cat==1
replace presump_impute=1155 if  electrician==1&gross_cat==2
replace presump_impute=2040 if  electrician==1&gross_cat==3
replace presump_impute=3915 if  electrician==1&gross_cat==5
replace presump_impute=5120 if  electrician==1&gross_cat==6

**Legal=Attorney Services (25%)
replace presump_impute=1155 if s12bq01a=="Legal advisor/counselor "&gross_cat==2
replace presump_impute=1155 if s12bq01a=="Legal advisor/counselor"&gross_cat==2

**** Bars, hotel, cafes (25%), Sporting Activities and Games Services (25%) 
replace presump_impute=530  if (restaurant==1|game==1|bar==1)& gross_cat==1
replace presump_impute=1155 if (restaurant==1|game==1|bar==1)& gross_cat==2
replace presump_impute=2040 if (restaurant==1|game==1|bar==1)& gross_cat==3
replace presump_impute=2978 if (restaurant==1|game==1|bar==1)& gross_cat==4
replace presump_impute=3915 if (restaurant==1|game==1|bar==1)& gross_cat==5
replace presump_impute=5120 if (restaurant==1|game==1|bar==1)& gross_cat==6
replace presump_impute=6370 if (restaurant==1|game==1|bar==1)& gross_cat==7
replace presump_impute=7620 if (restaurant==1|game==1|bar==1)& gross_cat==8
replace presump_impute=8870 if (restaurant==1|game==1|bar==1)& gross_cat==9
replace presump_impute=10408 if (restaurant==1|game==1|bar==1)& gross_cat==10
replace presump_impute=11970 if (restaurant==1|game==1|bar==1)& gross_cat==11
replace presump_impute=13533 if (restaurant==1|game==1|bar==1)& gross_cat==12
replace presump_impute=15095 if (restaurant==1|game==1|bar==1)& gross_cat==13
replace presump_impute=14813 if (restaurant==1|game==1|bar==1)& gross_cat==14
replace presump_impute=17000 if (restaurant==1|game==1|bar==1)& gross_cat==15
replace presump_impute=19188 if (restaurant==1|game==1|bar==1)& gross_cat==16
replace presump_impute=21375 if (restaurant==1|game==1|bar==1)& gross_cat==17
replace presump_impute=23563 if (restaurant==1|game==1|bar==1)& gross_cat==18
replace presump_impute=25750 if (restaurant==1|game==1|bar==1)& gross_cat==19

**photography
replace presump_impute=20675 if  s12bq01a=="Photographer"& gross_cat==16

**Broker (30%)
replace presump_impute=780 if  broker==1&gross_cat==1
replace presump_impute=1665 if  broker==1&gross_cat==2
replace presump_impute=2790 if  broker==1&gross_cat==3
replace presump_impute=5370 if  broker==1&gross_cat==5
lab var presump_impute "Imputed presumptive taxes"

** Vehicle renting (30%)
replace presump_impute=780 if  (s12bq01a=="Renting Motorcycle"&gross_cat==1)
replace presump_impute=780 if  (s12bq01a=="Renting and maintaining bicycle"&gross_cat==1)
replace presump_impute=15720 if  (s12bq01a=="Car rental"&gross_cat==11)


gen taxrate_impute=((presump_impute)/gross)*100
lab var taxrate_impute "Imputed presumptive tax as % of sales"
replace taxrate_impute=. if taxrate_impute>100
*9


gen lngross=ln(gross)
lab var lngross "Log of annual sales"


gen taxnet=100 if presump_impute>0&presump_impute!=.
replace taxnet=0 if presump_impute==0&presump_impute!=.
replace taxnet=. if presump_impute==.
lab var taxnet "% who should pay presumptive tax"


gen year_ent=2019-s12bq08b
replace year_ent=. if year_ent<0
lab var year_ent "Number of years enterprise operated"



xtile gross_quartile= gross[pweight=pw_w4], nq(4)
lab var gross_quartile "Quartile of turnover"

xtile gross_quintile = gross[pweight=pw_w4], nq(5)
lab var gross_quintile "Quintile of turnover"

gen     gross_cat_3=1 if gross_0<=50
replace gross_cat_3=2 if gross_0>50&gross_0<=75
replace gross_cat_3=3 if gross_0>75
lab def gross_cat_3 1 "<=50" 2 "50-75" 3 "75-500", replace 
lab val gross_cat_3 gross_cat_3
lab var gross_cat_3 "Turnover, '000 Birr"


gen     gross_cat_4=1 if gross_0<=25
replace gross_cat_4=2 if gross_0>25&gross_0<=50
replace gross_cat_4=3 if gross_0>50&gross_0<=75
replace gross_cat_4=4 if gross_0>75
lab def gross_cat_4 1 "<=25" 2 "25-50" 3 "50-75" 4 "75-500", replace 
lab val gross_cat_4 gross_cat_4
lab var gross_cat_4 "Turnover, '000 Birr"


**Hypothetical taxes
** Presumptive tax=2.5% of turnover, exempts 50,000 Birr
gen presump_hyp=gross*0.025
replace presump_hyp=0 if gross<=50000
*set to missing if taxpaid is missing so as to compare two results
replace presump_hyp=. if tax==.
lab var presump_hyp "Hypothetical presumptive tax amount"


gen presump_hyp_rate=presump_hyp/gross*100
lab var presump_hyp_rate "Hypothetical presumptive tax rate"

lab var gross_50 "<=50,000 Birr"

gen gross_cat_2=1 if gross_0<=50
replace gross_cat_2=2 if gross_0>50
lab def gross_cat_2 1 "<=50" 2 "50-500", replace 
lab val gross_cat_2 gross_cat_2
lab var gross_cat_2 "Turnover, '000 Birr"


**Define sectors without tax free thresholds

gen non_exempt_sector=chat==1| leather==1| movie==1| transit ==1|gold_trade==1|clay==1|manuf_metal==1 | mason==1|construction_building==1| factory==1| phone==1| cotton==1| electrician==1| bar==1| broker==1|restaurant==1
replace non_exempt_sector=. if presump_impute==.
lab var non_exempt_sector "Non exempt sector"



gen presump_hyp_positive=presump_hyp
replace presump_hyp_positive=. if presump_hyp<=0
lab var presump_hyp_positive "Presumptive taxes paid hypothetical given tax>0"

gen tax_positive=tax
replace tax_positive=. if tax<=0
lab var tax_positive "Tax paid, given tax>0"

gen exempt_hyp=presump_hyp==0
replace exempt_hyp=. if presump_hyp==.
lab var exempt_hyp "% of firms that are exempt"

gen taxpaying_hyp=presump_hyp!=0
replace taxpaying_hyp=. if presump_hyp==.
lab var taxpaying_hyp "% of taxpaying firms, hypothetical"

gen presump_hyp_50=presump_hyp
replace presump_hyp_50=0 if gross_0<100
lab var presump_hyp_50 "Hypothetical presumptive tax but noncompliance for firms <100,000"

gen presump_hyp_50_positive=presump_hyp_50
replace presump_hyp_50_positive=. if presump_hyp_50<=0
lab var presump_hyp_50_positive "Hypothetical presumptive tax but noncompliance for firms <100,000 given tax>0"

gen exempt_hyp_50 = presump_hyp_50==0
lab var exempt_hyp_50 "% of firms that are not paying"

gen taxpaying_hyp50=presump_hyp_50!=0
replace taxpaying_hyp50=. if presump_hyp_50==.
lab var taxpaying_hyp50 "% of taxpaying firms, hypothetical 50% compliance"

gen tax_new2=0.02*gross
replace tax_new2=0 if gross<=50000
count if tax_new2!=0

gen tax_new25=0.025*gross
replace tax_new25=0 if gross<=50000
count if tax_new25!=0

gen tax_new3=0.03*gross
replace tax_new3=0 if gross<=50000
count if tax_new3!=0


gen presump_hyp_2_50=tax_new2
replace presump_hyp_2_50=0 if gross_0<100
lab var presump_hyp_2_50 "Hypothetical presumptive tax (2%) but noncompliance for firms <100,000"


gen presump_hyp_rate_2= tax_new2/gross*100
lab var presump_hyp_rate_2 "Hypothetical presumptive tax rate (2%)"

gen exempt=presump_impute==0

foreach var in presump_hyp_positive taxpaying_hyp presump_hyp_50 presump_hyp_50_positive exempt_hyp_50 taxpaying_hyp50 presump_hyp_2_50{
    replace `var'=. if presump_hyp==.
}


gen non_exempt_sector_per=non_exempt_sector*100
lab var non_exempt_sector_per "% of firms in non exempt sectors"

gen retail_unknown= s12bq01b==47& (s12bq01a=="Retailer"|s12bq01a=="Retaier"|s12bq01a=="Reatailer")
lab var retail_unknown "Unknown retail activity"
ta registered if retail_unknown==1

gen exempt_sector=non_exempt_sector==0
replace exempt_sector=. if non_exempt_sector==.
lab var exempt_sector "Sector with tax-free threshold"

gen exempt_sector_per=exempt_sector*100
lab var exempt_sector_per "% of firms with tax-free threshold"

 gen taxpaid_per=taxpaid*100
 lab var taxpaid_per "% of taxpayers"
 
 
foreach var in home_inside home_outside market shop road mobile construction_site{
    replace `var'=`var'*100
}

 
gen other_sector=sector_prof+sector_misc+sector_primary
lab var other_sector "Others"  

gen alcohol_per=alcohol*100
gen transit_per=transit*100
gen food_service_per=food_service*100
gen sector_trade_per=sector_trade*100

foreach var in sector_manuf manuf_food manuf_cloth manuf_other   wholesale sector_service    other_pc sector_construction other_sector{
    replace `var'=`var'*100
}


gen sub_sector_short=1 if sector_trade_per==1
replace sub_sector_short=2 if alcohol_per==1
replace sub_sector_short=3 if manuf_cloth==1
replace sub_sector_short=4 if manuf_food==1
replace sub_sector_short=5 if manuf_other==1
replace sub_sector_short=6 if food_service_per==1
replace sub_sector_short=7 if transit_per==1
replace sub_sector_short=8 if other_pc==1
replace sub_sector_short=9 if sector_construction==1
replace sub_sector_short=710 if other_sector==1
lab  def sub_sector_short 1 "Trade" 2 "Manufacturing alcohol" 3 "Manufacturing clothes" 4 "Food manufacturing" 5 "Other manufacturing" 6 "Food service" 7 "Transit services" 8 "Other personal service" 9  "Construction" 10 "Other"
lab val sub_sector_short sub_sector_short 

save "$newdata/ethiopia_enterprise_wave4_Oct92023.dta", replace





use "$newdata/ethiopia_enterprise_wave4_Oct92023", clear




preserve
*** By enterprise
keep household_id  presump_impute gross gross_0   tax tax_0  transit bar restaurant food_service food_trade wood manuf_beverage manuf_food alcohol manuf_cloth manuf_wood manuf_metal manuf_other wholesale retail_other retail_all sector_trade other_pc sector_service sector_manuf sector_primary sector_construction sector* other_activities sector sub_sector

**Convert to household level indicators
collapse   (sum) presump_impute gross gross_0    tax tax_0 (max)  transit bar restaurant food_service food_trade wood manuf_beverage manuf_food alcohol manuf_cloth manuf_wood manuf_metal manuf_other wholesale retail_other retail_all sector_trade other_pc sector_service sector_manuf sector_primary sector_construction  sector_prof sector_misc  other_activities  , by(household_id)
lab var gross "Annual turnover, Birr"
lab var gross_0 "Annual turnover ('000 Birr)"
lab var presump_impute "Impute presumptive taxes"

*** By household
save "$newdata/ethiopia_household_Oct92023.dta", replace
restore


set more off


use "$newdata/ethiopia_enterprise_wave4_Oct92023", clear
drop if tax==.




*************************
********FIGURE 1  THIS GENERATES DATA FOR FIGURE 1
*************************

/*
graph bar (mean) sector_trade_per alcohol_per  manuf_cloth  manuf_food  manuf_other food_service_per  transit_per other_pc  sector_construction other_sector,  blabel(bar,  format(%9.1f)) scheme(s1color) over(owner_sex_2)title("Period 1 (2018/2019)") ,  [pw=pw_w4],  ///
   legend(label(1 "Trade") label(2 "Manuf of local beverages") label(3 "Manufacturing clothes") label(4 "Manufacturing food") label(5 "Other manufacturing") label(6 "Food services") label(7 "Transportation services") label(8 "Other personal services") label(9 "Construction") label(10 "Others"))   ///
  title("Period 1 (2018/2019)")   ///
  ytitle("% of enterprises") ///
  graphregion(color(white)) bgcolor(white)
graph save Graph "$excel/Figure1_1.gph", replace
*/


putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(Figure 1)

svyset ea_id[pw=pw_w4],  strata(region)

putexcel B1 = "Figure 1: Sector of nonfarm enterprises (%)"
putexcel B4 = "Period 1, 2018/2019"
putexcel B5 = "Male-owned"
putexcel C5 = "Female-owned"

tabstat sector_trade_per  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "Trade"

tabstat alcohol_per  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B7=matrix(r(Stat1)),  nformat(0.0)
putexcel C7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "Manufacture or sale of local beverages"

tabstat manuf_cloth  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B8=matrix(r(Stat1)),  nformat(0.0)
putexcel C8=matrix(r(Stat2)),  nformat(0.0)
putexcel A8  = "Manufacturing clothes"

tabstat manuf_food  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B9=matrix(r(Stat1)),  nformat(0.0)
putexcel C9=matrix(r(Stat2)),  nformat(0.0)
putexcel A9  = "Manufacturing food"

tabstat manuf_other  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B10=matrix(r(Stat1)),  nformat(0.0)
putexcel C10=matrix(r(Stat2)),  nformat(0.0)
putexcel A10  = "Other manufacturing"


tabstat food_service_per  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B11=matrix(r(Stat1)),  nformat(0.0)
putexcel C11=matrix(r(Stat2)),  nformat(0.0)
putexcel A11  = "Food and beverage services and hotels"

tabstat transit_per  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B12=matrix(r(Stat1)),  nformat(0.0)
putexcel C12=matrix(r(Stat2)),  nformat(0.0)
putexcel A12  = "Transportation services"


tabstat other_pc  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B13=matrix(r(Stat1)),  nformat(0.0)
putexcel C13=matrix(r(Stat2)),  nformat(0.0)
putexcel A13  = "Other personal services"


tabstat sector_construction  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B14=matrix(r(Stat1)),  nformat(0.0)
putexcel C14=matrix(r(Stat2)),  nformat(0.0)
putexcel A14  = "Construction"

tabstat other_sector  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B15=matrix(r(Stat1)),  nformat(0.0)
putexcel C15=matrix(r(Stat2)),  nformat(0.0)
putexcel A15  = "Others"
 

/********************
*********ENTERPRISE CHARACTERISTICS  /TABLE 3
********************/


foreach var in micro ownaccount registered urban gross_50 markettax_paid   exempt_sector{
    replace `var'=`var'*100
}



putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(TABLE 3)

svyset ea_id[pw=pw_w4],  strata(region)
count if owner_sex_2==1
putexcel B20=(`r(N)')
count if owner_sex_2==2
putexcel C20=(`r(N)')

svyset ea_id[pw=pw_w4],  strata(region)

putexcel A1 = "Table 3: Enterprise characteristics, by sex of owner"

putexcel B4 = "Period 1 (2018/2019)", bold

putexcel B5 = "Male-owned"
putexcel C5 = "Female-owned"
putexcel F5 = "P-values"


tabstat micro  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "Microenterprise (%)"
svy: mean micro, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D6=(`r(p)'), nformat(number_d2)

tabstat ownaccount  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B7=matrix(r(Stat1)),  nformat(0.0)
putexcel C7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "Own account (%)"
svy: mean ownaccount, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D7=(`r(p)'), nformat(number_d2)


tabstat registered  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B8=matrix(r(Stat1)),  nformat(0.0)
putexcel C8=matrix(r(Stat2)),  nformat(0.0)

putexcel A8 = "Registered (%)"
svy: mean registered, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D8=(`r(p)'), nformat(number_d2)


tabstat urban  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B9=matrix(r(Stat1)),  nformat(0.0)
putexcel C9=matrix(r(Stat2)),  nformat(0.0)
putexcel A9  = "Urban (%)"
svy: mean urban, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D9=(`r(p)'), nformat(number_d2)

putexcel A10  = "Annual sales"

tabstat gross_0  [aw = pw_w4],  by(owner_sex_2) s(median) save 
putexcel B11=matrix(r(Stat1)),  nformat(0.0)
putexcel C11=matrix(r(Stat2)),  nformat(0.0)
putexcel A11  = "  Median annual sales ('000 Birr)"

median gross_0, by(owner_sex_2)

** mean
tabstat gross_0  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B12=matrix(r(Stat1)),  nformat(0.0)
putexcel C12=matrix(r(Stat2)),  nformat(0.0)

** with standard deviation
tabstat gross_0  [aw = pw_w4],  by(owner_sex_2) s(sd) save 
putexcel B13 = matrix(r(Stat1)), nformat("(0.0)")
putexcel C13 = matrix(r(Stat2)), nformat("(0.0)")

putexcel A12  = "  Average annual sales ('000 Birr)"
svy: mean gross_0, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D12=(`r(p)'), nformat(number_d2)




tabstat gross_50  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B14=matrix(r(Stat1)),  nformat(0.0)
putexcel C14=matrix(r(Stat2)),  nformat(0.0)
putexcel A14  = "  % with sales <=50,000 Birr"
svy: mean gross_50, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D14=(`r(p)'), nformat(number_d2)

putexcel A15  = "Taxes"

tabstat markettax_paid  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B16=matrix(r(Stat1)),  nformat(0.0)
putexcel C16=matrix(r(Stat2)),  nformat(0.0)
putexcel A16  = "  Paid market tax or municipality fees (%)"
svy: mean markettax_paid, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D16=(`r(p)'), nformat(number_d2)


tabstat taxpaid_per [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B17=matrix(r(Stat1)),  nformat(0.0)
putexcel C17=matrix(r(Stat2)),  nformat(0.0)
putexcel A17  = "  Paid tax on business income (%)"
svy: mean taxpaid_per, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D17=(`r(p)'), nformat(number_d2)


putexcel A18  = "  Average tax paid on business income (Birr, self-reported)"


****** Mean and standard deviation
tabstat tax  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B18=matrix(r(Stat1)),  nformat(0.0)
putexcel C18=matrix(r(Stat2)),  nformat(0.0)
svy: mean tax, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D18=(`r(p)'), nformat(number_d2)

tabstat tax  [aw = pw_w4],  by(owner_sex_2) s(sd) save 
putexcel B19=matrix(r(Stat1)),  nformat("(0.0)")
putexcel C19=matrix(r(Stat2)),  nformat("(0.0)")

 
count if owner_sex_2==1&tax!=.
putexcel B20=(`r(N)')
count if owner_sex_2==2&tax!=.
putexcel C20=(`r(N)')
putexcel A20 = "Number of enterprises"


tabstat taxnet  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B21=matrix(r(Stat1)),  nformat(0.0)
putexcel C21=matrix(r(Stat2)),  nformat(0.0)
putexcel A21  = "  % of enterprises in presumptive tax net"
svy: mean taxnet, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D21=(`r(p)'), nformat(number_d2)


****** Mean 
tabstat presump_impute  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B22=matrix(r(Stat1)),  nformat(0.0)
putexcel C22=matrix(r(Stat2)),  nformat(0.0)
putexcel A22  = "Average presumptive tax (Birr, imputed)"
svy: mean presump_impute, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D22=(`r(p)'), nformat(number_d2)

* standard deviation
tabstat presump_impute  [aw = pw_w4],  by(owner_sex_2) s(sd) save 
putexcel B23=matrix(r(Stat1)),  nformat("(0.0)")
putexcel C23=matrix(r(Stat2)),  nformat("(0.0)")


tabstat exempt_sector [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B24=matrix(r(Stat1)),  nformat(0.0)
putexcel C24=matrix(r(Stat2)),  nformat(0.0)
putexcel A24  = "  % in sectors with tax-free threshold"
svy: mean exempt_sector, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel D24=(`r(p)'), nformat(number_d2)

count if owner_sex_2==1&presump_impute!=.
putexcel B25=(`r(N)')
count if owner_sex_2==2&presump_impute!=.
putexcel C25=(`r(N)') 
putexcel A25 = "Number of enterprises"



putexcel (B6:C6), bold
putexcel (B7:C7), bold
putexcel (B8:C8), bold
putexcel (B11:C11), bold
putexcel (B12:C12), bold
putexcel (B14:C14), bold
putexcel (B16:C16), bold
putexcel (B17:C17), bold
putexcel (B18:C18), bold
putexcel (B21:C21), bold
putexcel (B22:C22), bold

/************************
* TABLE 4
************************/
set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(TABLE 4)
putexcel A1 = "Table 4: Enterprise characteristics, by sex of owner and sector"
putexcel B4 = "Period 1"

putexcel B5 = "Male-owned"
putexcel C5 = "Female-owned"
putexcel F5 = "Male-owned"
putexcel G5 = "Female-owned"
putexcel F3 = "Period 1"


putexcel A6 = "Median annual sales ('000 Birr) by sector"
putexcel F4 = "Number of enterprises"

tabstat gross_0  [aw = pw_w4],  by(owner_sex_2) s(median), if alcohol==1, save 
putexcel B7="na"
putexcel C7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "  Manufacturing beverages"

count if owner_sex_2==2&alcohol==1
putexcel G7=(`r(N)')

tabstat gross_0  [aw = pw_w4],  by(owner_sex_2) s(median), if food_service==1, save 
putexcel B8="na"
putexcel C8=matrix(r(Stat2)),  nformat(0.0)
putexcel A8  = "  Food and beverage services ('000 Birr)"
median gross_0, by(owner_sex_2), if food_service==1

count if owner_sex_2==2&food_service==1
putexcel G8=(`r(N)')

tabstat gross_0  [aw = pw_w4],  by(owner_sex_2) s(median), if retail_all==1, save 
putexcel B9=matrix(r(Stat1)),  nformat(0.0)
putexcel C9=matrix(r(Stat2)),  nformat(0.0)
putexcel A9  = "  Retail ('000 Birr)"
median gross_0, by(owner_sex_2), if retail_all==1

count if owner_sex_2==1&retail_all==1
putexcel F9=(`r(N)')
count if owner_sex_2==2&retail_all==1
putexcel G9=(`r(N)')

tabstat gross_0  [aw = pw_w4],  by(owner_sex_2) s(median), if transit==1, save 
putexcel B10=matrix(r(Stat1)),  nformat(0.0)
putexcel C10="na"
putexcel A10  = "  Transit services ('000 Birr)"
count if owner_sex_2==1&transit==1
putexcel F10=(`r(N)')



putexcel A11 = "Average annual sales ('000 Birr) by sector"

tabstat gross_0  [aw = pw_w4],  by(owner_sex_2) s(mean), if alcohol==1, save 
putexcel B12="na"
putexcel C12=matrix(r(Stat2)),  nformat(0.0)
putexcel A12  = "  Manufacture or sale of local beverages ('000 Birr)"
svy: mean gross_0,  over(owner_sex_2) , if alcohol==1
test  _b[_subpop_1] = _b[_subpop_2]


count if owner_sex_2==2&alcohol==1
putexcel G12=(`r(N)')

tabstat gross_0  [aw = pw_w4],  by(owner_sex_2) s(mean), if food_service==1, save 
putexcel B13="na"
putexcel C13=matrix(r(Stat2)),  nformat(0.0)
putexcel A13  = "  Food and beverage services ('000 Birr)"

count if owner_sex_2==2&food_service==1
putexcel G13=(`r(N)')

tabstat gross_0  [aw = pw_w4],  by(owner_sex_2) s(mean), if retail_all==1, save 
putexcel B14=matrix(r(Stat1)),  nformat(0.0)
putexcel C14=matrix(r(Stat2)),  nformat(0.0)
putexcel A14  = "  Retail ('000 Birr)"

svy: mean gross_50, over(owner_sex_2), if retail_all==1
test  _b[_subpop_1] = _b[_subpop_2]

estat sd

count if owner_sex_2==1&retail_all==1
putexcel F14=(`r(N)')
count if owner_sex_2==2&retail_all==1
putexcel G14=(`r(N)')

tabstat gross_0  [aw = pw_w4],  by(owner_sex_2) s(mean), if transit==1, save 
putexcel B15=matrix(r(Stat1)),  nformat(0.0)
putexcel C15="na"
putexcel A15  = "  Transit services ('000 Birr)"
count if owner_sex_2==1&transit==1
putexcel F15=(`r(N)')
svy: mean gross_0,  over(owner_sex_2) , if transit==1
estat sd


**Firms with less than 50,000 Birr
putexcel A16  = "% of firms with <50,000 Birr"


tabstat gross_50[aw = pw_w4],  by(owner_sex_2) s(mean), if alcohol==1, save
putexcel B17="na"
putexcel C17=matrix(r(Stat2)),  nformat(0.0)
putexcel A17  = "  Manufacture or sale of local beverages"


count if owner_sex_2==2&alcohol==1
putexcel G17=(`r(N)')

tabstat gross_50[aw = pw_w4],  by(owner_sex_2) s(mean), if food_service==1, save
putexcel B18="na"
putexcel C18=matrix(r(Stat2)),  nformat(0.0)
putexcel A18  = "  Food and beverage services"
svy: mean gross_50, over(owner_sex_2), if food_service==1
test  _b[_subpop_1] = _b[_subpop_2]

count if owner_sex_2==2&food_service==1
putexcel G18=(`r(N)')


tabstat gross_50[aw = pw_w4],  by(owner_sex_2) s(mean), if retail_all==1, save
putexcel B19=matrix(r(Stat1)),  nformat(0.0)
putexcel C19=matrix(r(Stat2)),  nformat(0.0)
putexcel A19  = "  Retail"
svy: mean gross_50, over(owner_sex_2), if retail_all==1
test  _b[_subpop_1] = _b[_subpop_2]


count if owner_sex_2==1&retail_all==1
putexcel F19=(`r(N)')
count if owner_sex_2==2&retail_all==1
putexcel G19=(`r(N)')

tabstat gross_50[aw = pw_w4],  by(owner_sex_2) s(mean), if transit==1, save
putexcel B20=matrix(r(Stat1)),  nformat(0.0)
putexcel C20="na"
putexcel A20  = "  Transit services"
count if owner_sex_2==1&transit==1
putexcel F20=(`r(N)')


************************
* TABLE 5 
************************

set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(TABLE 5)

putexcel A2 = "Table 5: Percentage of businesses in non-exempt sectors, by quartile", bold

putexcel A5 = "Quartile (turnover)"
putexcel B4 = "Period 1"
putexcel B5 = "Male-owned"
putexcel C5 = "Female-owned"
putexcel D5 = "Male-owned"
putexcel E5 = "Female-owned"
putexcel D4 = "Period 2"

tabstat non_exempt_sector_per  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==1&taxrate_impute!=.,s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "1"

svy: mean non_exempt_sector_per, over(owner_sex_2), if  gross_quartile==1&taxrate_impute!=.
test  _b[_subpop_1] = _b[_subpop_2]

tabstat non_exempt_sector_per  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==2&taxrate_impute!=., s(mean) save 
putexcel B7=matrix(r(Stat1)),  nformat(0.0)
putexcel C7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "2"
svy: mean non_exempt_sector_per, over(owner_sex_2), if  gross_quartile==2&taxrate_impute!=.
test  _b[_subpop_1] = _b[_subpop_2]


tabstat non_exempt_sector_per  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==3&taxrate_impute!=., s(mean) save 
putexcel B8=matrix(r(Stat1)),  nformat(0.0)
putexcel C8=matrix(r(Stat2)),  nformat(0.0)
putexcel A8  = "3"
svy: mean non_exempt_sector_per, over(owner_sex_2), if  gross_quartile==3&taxrate_impute!=.
test  _b[_subpop_1] = _b[_subpop_2]



tabstat non_exempt_sector_per  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==4&taxrate_impute!=., s(mean) save 
putexcel B9=matrix(r(Stat1)),  nformat(0.0)
putexcel C9=matrix(r(Stat2)),  nformat(0.0)
putexcel A9  = "4"
svy: mean non_exempt_sector_per, over(owner_sex_2), if  gross_quartile==4&taxrate_impute!=.
test  _b[_subpop_1] = _b[_subpop_2]


putexcel A10  = "Number of enterprises"

count if owner_sex_2==1&taxrate_impute!=.
putexcel B10=(`r(N)')
count if owner_sex_2==2&taxrate_impute!=.
putexcel C10=(`r(N)')



***************************
******FIGURE 2:  PANEL 1: SELF-REPORTED
**************************
 
 set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(FIGURE 2 PANEL 1)

putexcel A1 = "Figure 2: Effective tax rates (percentage of turnover), by turnover quartile", bold

putexcel B2 = "Panel 1: Self-reported"
putexcel A3 = "Turnover quartile"
putexcel B3 = "Period 1"


putexcel A4  = "1"
tabstat  taxrate [aw = pw_w4],s(mean ),  if  gross_quartile==1, save 
return list
matrix all = r(StatTotal)'
putexcel B4 = matrix(all), nformat(0.0)

putexcel A5  = "2"
tabstat  taxrate [aw = pw_w4], s(mean ), if  gross_quartile==2, save 
return list
matrix all = r(StatTotal)'
putexcel B5 = matrix(all), nformat(0.0)


putexcel A6  = "3"
tabstat  taxrate [aw = pw_w4],s(mean ),  if  gross_quartile==3, save 
return list
matrix all = r(StatTotal)'
putexcel B6 = matrix(all), nformat(0.0)

putexcel A7  = "4"
tabstat  taxrate [aw = pw_w4], s(mean ), if  gross_quartile==4, save 
return list
matrix all = r(StatTotal)'
putexcel B7 = matrix(all), nformat(0.0)


***************************
******FIGURE 2:  PANEL 2: IMPUTED
**************************
 
 
 
 set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(FIGURE 2 PANEL 2)

 
putexcel B2 = "Panel 2: Imputed"
putexcel A3 = "Turnover quartile"
putexcel A3 = "Period 1"

putexcel A4  = "1"
tabstat  taxrate_impute [aw = pw_w4],s(mean ),  if  gross_quartile==1, save 
return list
matrix all = r(StatTotal)'
putexcel B4 = matrix(all), nformat(0.0)

putexcel A5  = "2"
tabstat  taxrate_impute [aw = pw_w4], s(mean ), if  gross_quartile==2, save 
return list
matrix all = r(StatTotal)'
putexcel B5 = matrix(all), nformat(0.0)


putexcel A6  = "3"
tabstat  taxrate_impute [aw = pw_w4],s(mean ),  if  gross_quartile==3, save 
return list
matrix all = r(StatTotal)'
putexcel B6 = matrix(all), nformat(0.0)

putexcel A7  = "4"
tabstat  taxrate_impute [aw = pw_w4], s(mean ), if  gross_quartile==4, save 
return list
matrix all = r(StatTotal)'
putexcel B7 = matrix(all), nformat(0.0)


************************
*** FIGURE 2, PANEL 3: SELF-REPORTED, PERIOD 1
*************************

 set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(FIGURE 2 PANEL 3)

putexcel B1 = "Panel 3: Self-reported, period 1"
putexcel A2 = "Turnover quartile"

putexcel B2 = "Male-owned"
putexcel C2 = "Female-owned"


tabstat taxrate  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==1,s(mean) save 
putexcel B3=matrix(r(Stat1)),  nformat(0.0)
putexcel C3=matrix(r(Stat2)),  nformat(0.0)
putexcel A3  = "1"
svy: mean taxrate, over(owner_sex_2), if  gross_quartile==1
test  _b[_subpop_1] = _b[_subpop_2]


tabstat taxrate  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==2,s(mean) save 
putexcel B4=matrix(r(Stat1)),  nformat(0.0)
putexcel C4=matrix(r(Stat2)),  nformat(0.0)
putexcel A4  = "2"
svy: mean taxrate, over(owner_sex_2), if  gross_quartile==2
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==3,s(mean) save 
putexcel B5=matrix(r(Stat1)),  nformat(0.0)
putexcel C5=matrix(r(Stat2)),  nformat(0.0)
putexcel A5  = "3"
svy: mean taxrate, over(owner_sex_2), if  gross_quartile==3
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==4,s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "4**"
svy: mean taxrate, over(owner_sex_2), if  gross_quartile==4
test  _b[_subpop_1] = _b[_subpop_2]


************************
*** FIGURE 2, PANEL 5: IMPUTED, PERIOD 1
*************************

putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(FIGURE 2 PANEL 5)

putexcel B1 = "Panel 5: Imputed, period 1"
putexcel A2 = "Turnover quartile"

putexcel B2 = "Male-owned"
putexcel C2 = "Female-owned"


tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==1,s(mean) save 
putexcel B3=matrix(r(Stat1)),  nformat(0.0)
putexcel C3=matrix(r(Stat2)),  nformat(0.0)
putexcel A3  = "1"
svy: mean taxrate_impute, over(owner_sex_2), if  gross_quartile==1
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==2,s(mean) save 
putexcel B4=matrix(r(Stat1)),  nformat(0.0)
putexcel C4=matrix(r(Stat2)),  nformat(0.0)
putexcel A4  = "2"
svy: mean taxrate_impute, over(owner_sex_2), if  gross_quartile==2
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==3,s(mean) save 
putexcel B5=matrix(r(Stat1)),  nformat(0.0)
putexcel C5=matrix(r(Stat2)),  nformat(0.0)
putexcel A5  = "3*"
svy: mean taxrate_impute, over(owner_sex_2), if  gross_quartile==3
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==4,s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "4"
svy: mean taxrate_impute, over(owner_sex_2), if  gross_quartile==4
test  _b[_subpop_1] = _b[_subpop_2]


/*
separate taxrate, by(owner_sex_2) veryshortlabel

graph bar (mean) taxrate1 taxrate2,  over(gross_quartile) nofill bar(1, bcolor(blue)) bar(2, bcolor(orange)) blabel(bar,  format(%9.1f)), [pw=pw_w4], ///
 title("Panel 3: Self-reported, period 1")  ytitle("")  ylabel(0 2 4 6 8 10 12 14) legend(order(1 "Male" 2 "Female" )) ///
graphregion(color(white)) bgcolor(white)   
graph save Graph "$excel/Figure3_3.gph", replace
*/
 /*
************
*** FIGURE 2, PANEL 5: IMPUTED, PERIOD 1
**********

separate taxrate_impute, by(owner_sex_2) veryshortlabel
graph bar (mean) taxrate_impute1 taxrate_impute2,  over(gross_quartile) nofill bar(1, bcolor(blue)) bar(2, bcolor(orange)) blabel(bar,  format(%9.1f)), [pw=pw_w4], ///
 title("Panel 5: Imputed, period 1")  ytitle("")  ylabel(0 2 4 6 8 10 12 14) legend(order(1 "Male" 2 "Female" )) ///
graphregion(color(white)) bgcolor(white)   
graph save Graph "$excel/Figure3_5.gph", replace

*/

***********************
**TABLE 6 
********************
set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(TABLE 6)

putexcel A1="Table 6: Effective tax rates (percentage of turnover), by sector and sex of owner"

putexcel B3 = "(1)"
putexcel C3 = "(2)"
putexcel D3 = "(3)"
putexcel E3 = "(4)"
putexcel B4 = "Period 1", hcenter
putexcel D4 = "Period 2", hcenter

*putexcel (B4:C4), merge
*putexcel (D4:E4), merge


putexcel B5 = "Male-owned"
putexcel C5 = "Female-owned"

putexcel D5 = "Male-owned"
putexcel E5 = "Female-owned"
putexcel F5 = "Male-owned"
putexcel G5 = "Female-owned"
putexcel F4 = "Period 1"
putexcel F3 = "Number of enterprises"
*putexcel (F4:I4), merge


svyset ea_id[pw=pw_w4],  strata(region)

putexcel A6="(1) Effective tax rate (self-reported)"


****** Mean and standard deviation
tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "Effective tax rate (self-reported)"
svy: mean taxrate, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(sd) save 
putexcel B7 = matrix(r(Stat1)), nformat("(0.0)")
putexcel C7 = matrix(r(Stat2)), nformat("(0.0)")


count if owner_sex_2==1&taxrate!=.
putexcel F6=(`r(N)')
count if owner_sex_2==2&taxrate!=.
putexcel G6=(`r(N)')

tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B8=matrix(r(Stat1)),  nformat(0.0)
putexcel C8=matrix(r(Stat2)),  nformat(0.0)
putexcel A8  = "Effective tax rate (imputed)"
svy: mean taxrate_impute, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(sd) save 
putexcel B9 = matrix(r(Stat1)), nformat("(0.0)")
putexcel C9 = matrix(r(Stat2)), nformat("(0.0)")

count if owner_sex_2==1&taxrate_impute!=.
putexcel F8=(`r(N)')
count if owner_sex_2==2&taxrate_impute!=.
putexcel G8=(`r(N)')


tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(mean), if taxpaid==1, save 
putexcel B10=matrix(r(Stat1)),  nformat(0.0)
putexcel C10=matrix(r(Stat2)),  nformat(0.0)
putexcel A10  = "Effective tax rate (self-reported), given tax>0"
svy: mean taxrate, over(owner_sex_2), if taxpaid==1
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(sd), if taxpaid==1, save 
putexcel B11 = matrix(r(Stat1)), nformat("(0.0)")
putexcel C11 = matrix(r(Stat2)), nformat("(0.0)")


count if owner_sex_2==1&taxpaid==1&taxrate!=.
putexcel F10=(`r(N)')
count if owner_sex_2==2&taxpaid==1&taxrate!=.
putexcel G10=(`r(N)')

putexcel A12  = "Effective tax rate (imputed), given tax>0"

tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(mean), if presump_impute>0&presump_impute!=., save 
putexcel B12=matrix(r(Stat1)),  nformat(0.0)
putexcel C12=matrix(r(Stat2)),  nformat(0.0)
svy: mean taxrate_impute, over(owner_sex_2), if presump_impute>0&presump_impute!=.
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(sd), if presump_impute>0&presump_impute!=., save 
putexcel B13 = matrix(r(Stat1)), nformat("(0.0)")
putexcel C13 = matrix(r(Stat2)), nformat("(0.0)")


count if owner_sex_2==1&taxrate_impute!=.&presump_impute>0&presump_impute!=.
putexcel F12=(`r(N)')
count if owner_sex_2==2&taxrate_impute!=.&presump_impute>0&presump_impute!=.
putexcel G12=(`r(N)')

putexcel A14  =   "Effective tax rate (self-reported), by sector"


putexcel A15  =   "(5) Manufacturing or sale of local beverages"
count if owner_sex_2==2& alcohol==1&taxrate!=.
putexcel G15=(`r(N)')

tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(mean), if  alcohol==1, save 
putexcel B15 = "na"
putexcel C15=matrix(r(Stat2)),  nformat(0.0)

tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(sd), if  alcohol==1, save 
putexcel C16 = matrix(r(Stat2)), nformat("(0.0)")


putexcel A17  =  "(6)  Food and beverage services"
count if owner_sex_2==2& food_service==1&taxrate!=.
putexcel G17=(`r(N)')

tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(mean), if  food_service==1, save 
putexcel B17 = "na"
putexcel C17=matrix(r(Stat2)),  nformat(0.0)

tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(sd), if  food_service==1, save 
putexcel C18 = matrix(r(Stat2)), nformat("(0.0)")


putexcel A19  =  "(7)  Retail trade"
count if owner_sex_2==1& retail_all==1&taxrate!=.
putexcel F19=(`r(N)')
count if owner_sex_2==2& retail_all==1&taxrate!=.
putexcel G19=(`r(N)')

tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(mean), if  retail_all==1, save 
putexcel B19=matrix(r(Stat1)),  nformat(0.0)
putexcel C19=matrix(r(Stat2)),  nformat(0.0)

svy: mean taxrate, over(owner_sex_2), if retail_all==1
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(sd), if  retail_all==1, save 
putexcel B20 = matrix(r(Stat1)), nformat("(0.0)")
putexcel C20 = matrix(r(Stat2)), nformat("(0.0)")

putexcel A21  =   "(8) Transit services"
count if owner_sex_2==1& transit==1&taxrate!=.
putexcel F21=(`r(N)')


tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(mean), if  transit==1, save 
putexcel B21=matrix(r(Stat1)),  nformat(0.0)
putexcel C21 = "na"

tabstat taxrate  [aw = pw_w4],  by(owner_sex_2) s(sd), if  transit==1, save 
putexcel B22 = matrix(r(Stat1)), nformat("(0.0)")


putexcel A23="Effective tax rate (imputed), by sector"

putexcel A24  = "(9) Manufacturing or sale of local beverages"
tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(mean), if alcohol==1, save 
putexcel B24 = "na"
putexcel C24=matrix(r(Stat2)),  nformat(0.0)

tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(sd), if alcohol==1, save 
putexcel C25=matrix(r(Stat2)),   nformat("(0.0)")

count if owner_sex_2==2&taxrate_impute!=.& (alcohol==1)
putexcel G24=(`r(N)')


putexcel A26  = "(10)  Food and beverage services"
tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(mean), if food_service==1, save 
putexcel B26 = "na"
putexcel C26=matrix(r(Stat2)),  nformat(0.0)

tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(sd), if food_service==1, save 
putexcel C27=matrix(r(Stat2)),   nformat("(0.0)")

count if owner_sex_2==2&taxrate_impute!=.& (food_service==1)
putexcel G26=(`r(N)')


putexcel A28 = "(11) Retail trade"
tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(mean), if retail_all==1, save 
putexcel B28=matrix(r(Stat1)),  nformat(0.0)
putexcel C28=matrix(r(Stat2)),  nformat(0.0)

tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(sd), if retail_all==1, save 
putexcel B29 = matrix(r(Stat1)), nformat("(0.0)")
putexcel C29 = matrix(r(Stat2)), nformat("(0.0)")

svy: mean taxrate_impute, over(owner_sex_2), if retail_all==1
test  _b[_subpop_1] = _b[_subpop_2]

count if owner_sex_2==1&taxrate_impute!=.& retail_all==1
putexcel F28=(`r(N)')
count if owner_sex_2==2&taxrate_impute!=.& retail_all==1.
putexcel G28=(`r(N)')

putexcel A30  = "(12) Transit services"
tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(mean), if transit==1, save 
putexcel B30=matrix(r(Stat1)),  nformat(0.0)
putexcel C30 = "na"
tabstat taxrate_impute  [aw = pw_w4],  by(owner_sex_2) s(sd), if transit==1, save 
putexcel B31=matrix(r(Stat1)),   nformat("(0.0)")

count if owner_sex_2==1&taxrate_impute!=.& transit==1
putexcel F30=(`r(N)')



putexcel (B28:C28), bold

***********
*** TABLE 7
************HYPOTHETICAL TAX RATE (2.5% ON TURNOVER OF FIRMS MAKING OVER 50,000 
*****************************************

putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(TABLE 7)

svyset ea_id[pw=pw_w4],  strata(region)
count if owner_sex_2==1&taxrate!=.
putexcel B8=(`r(N)')
count if owner_sex_2==2&taxrate!=.
putexcel C8=(`r(N)')

*putexcel (B4:C4), merge
putexcel A1 =  "Table 7: Effective tax rates of a hypothetical presumptive tax, by sex (2.5% of turnover)"
putexcel B4 = "Period 1", hcenter
putexcel B5 = "Male-owned"
putexcel C5 = "Female-owned"

putexcel A8 = "Number of enterprises"

tabstat presump_hyp_rate  [aw = pw_w4],  by(owner_sex_2), if taxrate!=., s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "(1) Effective tax rate (all)"
svy: mean presump_hyp_rate, over(owner_sex_2), if taxrate!=.
test  _b[_subpop_1] = _b[_subpop_2]


tabstat presump_hyp_rate  [aw = pw_w4],  by(owner_sex_2), if presump_hyp_rate>0& taxrate!=., s(mean) save 
putexcel B7=matrix(r(Stat1)),  nformat(0.0)
putexcel C7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "(2) Effective tax rate, given tax>0"


********************************
********FIGURE 3 THIS GENERATES DATA FOR THE GRAPHS
******************************
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(FIGURE 3 PANEL1)
/*
separate presump_hyp_rate, by(owner_sex_2) veryshortlabel
graph bar (mean) presump_hyp_rate1 presump_hyp_rate2,  over(gross_quartile) nofill bar(1, bcolor(blue)) bar(2, bcolor(orange)) blabel(bar,  format(%9.1f)), [pw=pw_w4], ///
 title("Panel 1: hypothetical, period 1")  ytitle("")  ylabel(0 2 4 6 8 10 12 14) legend(order(1 "Male" 2 "Female" )) ///
graphregion(color(white)) bgcolor(white)   
graph save Graph "$excel/Figure4_1.gph", replace
*/


putexcel A1="Figure 3: Effective tax rates of a hypothetical presumptive tax, by turnover quartile"

putexcel B2 = "Panel 1: hypothetical, period 1"
putexcel A3 = "Turnover quartile"

putexcel B3 = "Male-owned"
putexcel C3 = "Female-owned"


tabstat presump_hyp_rate  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==1&taxrate!=.,s(mean) save 
putexcel B4=matrix(r(Stat1)),  nformat(0.0)
putexcel C4=matrix(r(Stat2)),  nformat(0.0)
putexcel A4  = "1"
svy: mean presump_hyp_rate, over(owner_sex_2), if  gross_quartile==1
test  _b[_subpop_1] = _b[_subpop_2]

tabstat presump_hyp_rate  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==2&taxrate!=.,s(mean) save 
putexcel B5=matrix(r(Stat1)),  nformat(0.0)
putexcel C5=matrix(r(Stat2)),  nformat(0.0)
putexcel A5  = "2"
svy: mean presump_hyp_rate, over(owner_sex_2), if  gross_quartile==2
test  _b[_subpop_1] = _b[_subpop_2]

tabstat presump_hyp_rate  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==3&taxrate!=.,s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "3"
svy: mean presump_hyp_rate, over(owner_sex_2), if  gross_quartile==3
test  _b[_subpop_1] = _b[_subpop_2]

tabstat presump_hyp_rate  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==4&taxrate!=.,s(mean) save 
putexcel B7=matrix(r(Stat1)),  nformat(0.0)
putexcel C7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "4**"
svy: mean presump_hyp_rate, over(owner_sex_2), if  gross_quartile==4
test  _b[_subpop_1] = _b[_subpop_2]



******************************
***** APPENDIX 5 THIS GENERATES DATA FOR THE GRAPHS
*************************

putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 5)

svyset ea_id[pw=pw_w4],  strata(region)

putexcel B1 = "Appendix 5: Primary location where enterprise operates"

putexcel B4 = "Period 1 (2018/2019)"

putexcel B5 = "Male-owned"
putexcel C5 = "Female-owned"

tabstat home_inside  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "Inside home***"
svy: mean home_inside, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat home_outside  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B7=matrix(r(Stat1)),  nformat(0.0)
putexcel C7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "Outside home**"
svy: mean home_outside, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat market  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B8=matrix(r(Stat1)),  nformat(0.0)
putexcel C8=matrix(r(Stat2)),  nformat(0.0)
putexcel A8  = "Traditional market"
svy: mean market, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat shop  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B9=matrix(r(Stat1)),  nformat(0.0)
putexcel C9=matrix(r(Stat2)),  nformat(0.0)
putexcel A9  = "Shop in commercial area***"
svy: mean shop, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat road  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B10=matrix(r(Stat1)),  nformat(0.0)
putexcel C10=matrix(r(Stat2)),  nformat(0.0)
putexcel A10 = "Roadside"
svy: mean road, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat mobile  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B11=matrix(r(Stat1)),  nformat(0.0)
putexcel C11=matrix(r(Stat2)),  nformat(0.0)
putexcel A11  = "Mobile location***"
svy: mean mobile, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat construction_site  [aw = pw_w4],  by(owner_sex_2) s(mean) save 
putexcel B12=matrix(r(Stat1)),  nformat(0.0)
putexcel C12=matrix(r(Stat2)),  nformat(0.0)
putexcel A12  = "Construction site***"
svy: mean construction_site, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]




/*
graph bar (mean) home_inside home_outside market shop road mobile construction_site, over(owner_sex_2) scheme(s1color)  blabel(bar,  format(%9.1f)), [pw=pw_w4],  ///
   legend(label(1 "Inside home") label(2 "Outside home") label(3 "Market") label(4 "Shop") label(5 "Road") label(6 "Mobile") label(7 "Construction site"))   ///
   title("Period 1 (2018/2019)")   ///
  ytitle("% of enterprises") ///
  graphregion(color(white)) bgcolor(white)
graph save Graph "$excel/Appendix5_1.gph", replace
*/

**********************
*****APPENDIX 8
***********************


putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 8)

putexcel A1 ="Appendix 8: Businesses who paid tax, by turnover quartile (%)"
putexcel B4 = "Period 1"
putexcel B5 = "Male-owned"
putexcel C5 = "Female-owned"

tabstat taxpaid_per [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==1,s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "1"
svy: mean taxpaid_per, over(owner_sex_2), if  gross_quartile==1
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxpaid_per  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==2,s(mean) save 
putexcel B7=matrix(r(Stat1)),  nformat(0.0)
putexcel C7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "2"
svy: mean taxpaid_per, over(owner_sex_2), if  gross_quartile==2
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxpaid_per  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==3,s(mean) save 
putexcel B8=matrix(r(Stat1)),  nformat(0.0)
putexcel C8=matrix(r(Stat2)),  nformat(0.0)
putexcel A8  = "3"
svy: mean taxpaid_per, over(owner_sex_2), if  gross_quartile==3
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxpaid_per  [aw = pw_w4],  by(owner_sex_2), if  gross_quartile==4,s(mean) save 
putexcel B9=matrix(r(Stat1)),  nformat(0.0)
putexcel C9=matrix(r(Stat2)),  nformat(0.0)
putexcel A9  = "4"
svy: mean taxpaid_per, over(owner_sex_2), if  gross_quartile==4
test  _b[_subpop_1] = _b[_subpop_2]






***********
*** APPENDIX 10
************HYPOTHETICAL TAX RATE (2% ON TURNOVER OF FIRMS MAKING OVER 50,000 
*****************************************

putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 10)

svyset ea_id[pw=pw_w4],  strata(region)
count if owner_sex_2==1&taxrate!=.
putexcel B8=(`r(N)')
count if owner_sex_2==2&taxrate!=.
putexcel C8=(`r(N)')

*putexcel (B4:C4), merge
putexcel A1 =  "Appendix 10: Effective tax rates of a hypothetical presumptive tax, by sex (2% of turnover)"
putexcel B4 = "Period 1", hcenter
putexcel B5 = "Male-owned"
putexcel C5 = "Female-owned"

putexcel A8 = "Number of enterprises"

tabstat presump_hyp_rate_2  [aw = pw_w4],  by(owner_sex_2), if taxrate!=., s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "(1) Effective tax rate (all)"
svy: mean presump_hyp_rate_2, over(owner_sex_2), if taxrate!=.
test  _b[_subpop_1] = _b[_subpop_2]


tabstat presump_hyp_rate_2  [aw = pw_w4],  by(owner_sex_2), if presump_hyp_rate>0& taxrate!=., s(mean) save 
putexcel B7=matrix(r(Stat1)),  nformat(0.0)
putexcel C7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "(2) Effective tax rate, given tax>0"



putexcel (B6:C6), bold 
