

**ETHIOPIA PRESUMPTIVE TAX PAPER 
** DOFILE #2


/*Socioeconomic Survey 2021-2022 Ethiopia has not yet been publicly released. Please use data provided. Create a folder names "ESS_2021" and put data in the folder
*/

*********WAVE 5


clear all
capture log close
set more off


global rawdata 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2021
global newdata 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2021

global excel 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2018




/* -------------------------------------------------------------------------- */
/*          CONSUMPTION AGGREGATES    -- RURAL AND URBAN                               */
/* -------------------------------------------------------------------------- */
 
use "$rawdata/cons_agg_w5.dta", clear
*4959 households


keep household_id cons_quint spat_totcons_aeq

tempfile consumption
save `consumption'

/* -------------------------------------------------------------------------- */
/*          A. HOUSEHOLD ROSTER                                     */
/* -------------------------------------------------------------------------- */


 ***Household roster 
 ** 25,374 members
 
use "$rawdata/sect1_hh_w5.dta", clear

ren saq14 rural 
ren saq01 region

ren s1q03a age
ren s1q02 sex
gen head=s1q01==1

ren s1q09 marital
keep household_id individual_id rural sex age  region
ren individual_id s12bq03_1
gen s12bq03_2=s12bq03_1
gen sex_1=sex
gen sex_2=sex

tempfile individual
save `individual'

 /*-------------------------------------------------------------------------- */
/*        HOUSING DWELLING OWNERSHIP                            */
/* -------------------------------------------------------------------------- */

 use "$rawdata/sect10a_hh_w5.dta", clear

 gen own_dwelling=s10aq02==1|s10aq02==2
 lab var own_dwelling "Own dwelling or free rent"
 keep household_id own_dwelling
 
tempfile dwelling
save `dwelling'
 
 
/* -------------------------------------------------------------------------- */
/*         HH ENTERPRISE    - HH level                               */
/* -------------------------------------------------------------------------- */

* Data by household
 use "$rawdata/sect12a_hh_w5.dta", clear
 
 **household skip questions
 gen hh_nfe= s12aq01_1==1
 lab var hh_nfe "Non-ag enterprise or non-ag service"
 *641 households
 
 gen hh_agproduct=s12aq01_2==1
 lab var hh_agproduct "Processed or sold agricultural by-products"
 gen hh_trade= s12aq01_3==1
 lab var hh_trade "Trading business"
 gen hh_service=s12aq01_4==1
 lab var hh_service "Service or sold anything in street/market"
 gen hh_office= s12aq01_5==1
 lab var hh_office "Professional office"
 gen hh_carservice=s12aq01_6==1
 lab var hh_carservice "Car service (taxi or pickup truck)"
 gen hh_restaurant = s12aq01_7==1
 lab var hh_restaurant "Bar or restaurant"
 gen hh_othernfe=s12aq01_8==1
 lab var hh_othernfe "Other NFE"
 keep household_id hh*
 
tempfile enterprise
save `enterprise'

/* -------------------------------------------------------------------------- */
/*         HH ENTERPRISE                                  */
/* -------------------------------------------------------------------------- */

* By enterprise  
 use "$rawdata/sect12b1_hh_w5.dta", clear
 *1,551 enterprises
 
**Drop if don't know owner
drop if s12bq03_1==.

*1,550 enterprises
 *merge with indi data
merge m:1 household_id s12bq03_1 using  `individual'
drop if _m==2
drop _m
drop sex_2
lab var sex_1 "Sex of first owner"


merge m:1 household_id s12bq03_2 using  `individual'
drop if _m==2
drop _m
lab var sex_2 "Sex of second owner"

merge m:1 household_id  using  `enterprise'
drop if _m==2
drop _m
merge m:1 household_id  using  `dwelling'
drop if _m==2
drop _m


merge m:1 household_id  using  `consumption'
drop if _m==2
drop _m

**Sex of owner

gen owner_f= sex_1==2|sex_2==2
replace owner_f=. if sex==.
lab var owner_f "Owner is woman"

gen owner_m= sex_1==1|sex_2==1
replace owner_m=. if sex==.
lab var owner_m "Owner is man"

drop sex age

**Define male owner as male owner or male and female owner
gen owner_sex_2=1 if owner_m==1
replace owner_sex_2=2 if owner_m==0&owner_f==1
lab def owner_sex_2 1 "Male owned enterprise" 2 "Female owned enterprise", replace
lab val  owner_sex_2 owner_sex_2

gen owner_sex_3=1 if owner_m==1&owner_f==0
replace owner_sex_3=2 if owner_m==0&owner_f==1
replace owner_sex_3=3 if owner_m==1&owner_f==1
lab def owner_sex_3 1 "Male owned enterprise" 2 "Female owned enterprise" 3 "Jointly owned enterprise", replace
lab val  owner_sex_3 owner_sex_3

gen owner_joint=owner_m==1&owner_f==1

gen owner_nr=1 if sex_2==.
replace owner_nr=2 if sex_2!=.
lab var owner_nr "Number of owners per enterprise"
*175 joint ownership

gen registered=s12bq18==1
lab var registered "Registered and has license"
*463


preserve
*** By enterprise
** Male owner defined as as male owner or joint owner
keep household_id owner_sex_2  

gen enterprise_hh=1
gen male_owned=owner_sex_2==1
gen female_owned=owner_sex_2==2

collapse (max) male_owned female_owned enterprise_hh   , by(household_id)
lab var enterprise_hh "Household has NFE"

lab var male_owned "Male-owned enterprise"
lab var female_owned "Female-owned enterprise"
** 26 households have both

*** By household
save "$newdata/ethiopia_household_number_wave5.dta", replace
restore 


svyset ea_id[pw=pw_w5],  strata(region)



*******
**Where does it operate?
**********

gen home_inside=s12bq02==1
lab var home_inside "Inside residence"
gen home_outside= s12bq02==2
lab var home_outside "Home, outside residence"
gen market= s12bq02==3
lab var market "Traditional market"
gen shop= s12bq02==4
lab var shop "Shop in commercial area"
gen road= s12bq02==5
lab var road "Roadside"
gen mobile= s12bq02==6
lab var mobile "Mobile"
gen construction_site= s12bq02==8
lab var construction_site "Construction site"


****************************
**Sector
*************************

gen bar=s12bq01a=="Hotel"
lab var bar "Bars and hotels"

gen restaurant=s12bq01a=="Tea room"|s12bq01a=="Restaurant"|s12bq01a=="Restaurant "|s12bq01a=="Cafe"|s12bq01a=="Café"
replace restaurant=1 if s12bq01a=="Coffee house"|s12bq01a=="Coffee house and Oil shop"|s12bq01a=="Tea room"|s12bq01a=="Tea  room"|s12bq01a=="Coffe house"
replace restaurant=1 if s12bq01a=="Coffee/tea shop"
lab var restaurant "Restaurants, coffee houses"

gen bakery=s12bq01a=="Baking and selling Enjera"|s12bq01a=="Baking and selling biscuits"|s12bq01a=="Baking and selling bread"|s12bq01a=="Pastry Selling Enjera"|s12bq01a=="Selling Enjera"|s12bq01a=="Pastry"
lab var bakery "Bakeries"
 
**** SUBSECTOR: FOOD AND BEVERAGE SERVICES AND HOTELS 
**Jan 4 2023 We  classify selling local alcohol as beverage service 

gen alcohol=  s12bq01a=="Selling local alcoholic beverages"|s12bq01a=="Selling alcoholic beverage"|s12bq01a=="Selling alcoholic beverages" 
 

gen food_service=s12bq01b==56
replace food_service=0 if s12bq01a=="Selling local alcoholic beverages"|s12bq01a=="Selling alcoholic beverage"|s12bq01a=="Selling alcoholic beverages"
lab var food_service "Food and beverage services & hotels, ex alcohol"

** 119 selling alcohol in food/beverage service

**** Manufacturing food - include bakeries and butchers
gen manuf_food= s12bq01b==10
replace manuf_food=0 if s12bq01a=="Selling local alcoholic beverages"
lab var manuf_food "Manufacture food products"

gen manuf_beverage=s12bq01b==11
replace manuf_beverage=1 if alcohol==1
lab var manuf_beverage "Manufacture beverages"

****Using ISIC code, transit = land transport & transport via pipelines (passenger transport, urban and suburban land transport, other passenger land transport, freight land transport)
gen transit=s12bq01b==49
replace transit=0 if s12bq01a=="Laborer"|s12bq01a=="Bicycle renting"
lab var transit "Transit or transport service"


**Selling charcoal and firewood is under "Other retail trade" and "Retail trade" (in sector)
gen wood=s12bq01a=="Charcoal production and sales"|s12bq01a=="Fire wood sales"
replace wood=1 if s12bq01a=="Selling wood"|s12bq01a=="Selling wood "|s12bq01a=="Selling wood and charcoal"
lab var wood "Sell wood or charcoal"

*"This division includes all tailoring (ready-to-wear or made-to-measure), in all materials"
gen manuf_cloth= s12bq01b==13|s12bq01b==14
replace manuf_cloth=1 if s12bq01a=="Traditional weaving"
replace manuf_cloth=1 if s12bq01a=="Garment factory" |s12bq01a=="Embroidery"
lab var manuf_cloth "Manufacture of textile or wearing apparel"

gen manuf_wood= s12bq01b==16|s12bq01b==31
lab var manuf_wood "Manufacture wood products or furniture"

gen manuf_metal=s12bq01b==25
replace manuf_metal=1 if s12bq01a=="Blacksmith"
lab var manuf_metal "Manufacture metal products"

gen manuf_other= manuf_wood +manuf_metal
replace manuf_other=1 if s12bq01b==15|s12bq01b==21|s12bq01b==25|s12bq01b==28|s12bq01b==32
replace manuf_other=0 if s12bq01a=="Traditional weaving"|s12bq01a=="Garment factory"||s12bq01a=="Embroidery"
lab var manuf_other "Other manufacturing"

*Wholesale
gen wholesale=s12bq01b ==46|s12bq01b ==45
lab var wholesale "Wholesale trade"

**Retail
gen retail_other=s12bq01b==47
replace retail_other=1 if s12bq01a=="Shop"|s12bq01a=="Shop keeper"|s12bq01a=="Shop keeper "|s12bq01a=="Shop worker"|s12bq01a=="shop keeper"|s12bq01a=="Music shop"|s12bq01a=="Video shop"
*define as retail
replace retail_other=1 if s12bq01a=="Poultry trade"


**Selling wood/charcoal in retail  defined as "other retail" (not supposed to be wood manuf as per ISIC def), unless charcoal production defined as forestry 
replace retail_other=1 if wood==1&(s12bq01b ==47|s12bq01b ==96|s12bq01b ==16)
replace retail_other=0 if transit==1| food_service==1 | alcohol==1|manuf_food==1| manuf_cloth==1| manuf_wood==1| manuf_metal==1| manuf_other==1| wholesale==1
lab var retail_other "Other retail trade"

gen retail_all= retail_other
lab var retail_all "All retail trade"
egen sector_trade=rowtotal(retail_all wholesale ) 
lab var sector_trade "Trade"

gen other_pc=s12bq01b==96
replace other_pc=0 if transit==1| food_service==1 | alcohol==1|manuf_food==1| manuf_cloth==1| manuf_wood==1| manuf_metal==1| manuf_other==1|  wholesale==1|retail_other==1
lab var other_pc "Other personal service activities"

** Jan 4 2023, Food service includes alcohol
egen sector_service=rowtotal(transit food_service alcohol other_pc)
lab var sector_service "Service sector"


egen sector_manuf=rowtotal(manuf_food manuf_cloth manuf_other)
lab var sector_manuf "Manufacturing sector"
egen temp5=rowtotal(sector_manuf sector_service sector_trade)
drop temp5


gen sector_primary=s12bq01b ==1|s12bq01b ==2|s12bq01b ==7|s12bq01b ==8
replace sector_primary=1 if s12bq01a=="Tea production"
replace sector_primary=0 if s12bq01a=="Poultry trade"
lab var sector_primary "Ag production or mining sectors"
gen sector_construction=s12bq01b==33|s12bq01b==41|s12bq01b==43
lab var sector_construction "Construction sector"


**** Professional, scientific, technical, administrative and support activities,Public administration and defence, education, human health and social work activities
*This section includes a variety of activities that support general business operations
***Includes Renting motor vehicles, guard services, education, health
gen guard=s12bq01a=="Guard"

gen sector_prof=s12bq01b==69|s12bq01b==71|s12bq01b==74|s12bq01b==77|s12bq01b==82|s12bq01b==85|s12bq01b==86|s12bq01b==87|s12bq01b==88
replace sector_prof=1 if s12bq01a=="Professional service"|guard==1
replace sector_prof=1 if s12bq01a=="Bicycle renting"|s12bq01a=="Computer maintainance"|s12bq01a=="Engineer"|s12bq01a=="Maintenance work"
lab var sector_prof "Professional, admin support activities"

replace sector_prof=0 if sector_primary==1|transit==1| food_service==1 | alcohol==1|manuf_food==1| manuf_cloth==1| manuf_wood==1| manuf_metal==1| manuf_other==1|  wholesale==1|retail_other==1

egen temp4=rowtotal(sector_manuf sector_service sector_trade sector_primary sector_construction sector_prof)
gen sector_misc=temp4==0
lab var sector_misc "Misc"

drop temp4

gen other_activities=sector_primary+sector_construction+sector_misc
replace other_activities=0 if s12bq01a=="Blacksmith"
lab var other_activities "Other"


egen temp6=rowtotal(sector_manuf sector_service sector_trade sector_primary sector_prof sector_construction sector_misc )
drop temp6 
 
gen sector=1 if sector_manuf==1
replace sector=2 if sector_trade==1
replace sector=3 if sector_service==1
replace sector=4 if sector_prof==1
replace sector=5 if sector_construction==1
replace sector=6 if sector_primary==1
replace sector=7 if sector_misc==1
lab def sector 1 "Manufacturing" 2 "Trade" 3 "Services" 4 "Professional, admin support"   5 "Construction" 6  "Agriculture and mining"  7 "Others", replace
lab val sector sector
lab var sector "Sectors"

**Jan 4 2023 We  classify selling local alcohol as beverage service 

gen food_service_alcohol=food_service==1|alcohol==1
lab var food_service_alcohol "Food and beverage services and hotels, inc local beverage"

gen sub_sector=1 if manuf_food==1
replace sub_sector=2 if manuf_cloth==1
replace sub_sector=3 if manuf_other==1
replace sub_sector=4 if retail_all==1
replace sub_sector=5 if wholesale==1
replace sub_sector=6 if alcohol==1
replace sub_sector=7 if food_service==1
replace sub_sector=8 if transit==1
replace sub_sector=9 if other_pc==1
replace sub_sector=10 if sector_construction==1
replace sub_sector=11 if sector_prof==1
replace sub_sector=12 if  sector_primary==1
replace sub_sector=13 if sector_misc==1
lab def sub_sector  1 "Manufacturing food" 2 "Manufacturing clothes" 3 "Other manufacturing" 4 "Retail trade" 5 "Wholesale trade" 6 "Manufacture of sale of local beverages" 7 "Food and beverage services and hotels" 8 "Transportation services" 9 "Other personal services" 10 "Construction" 11 "Professional, admin support"   12 "Agriculture and mining" 13 "Others", replace
lab val sub_sector sub_sector
lab var sub_sector "Sub-sectors"




gen retail_stall=retail_all==1&(market==1|shop==1)
lab var retail_stall "Retail at market or stall"
gen retail_otherplace=retail_all==1&retail_stall==0
lab var retail_otherplace "Retail at other locations"


*************
** Disaggregate by activities  - to align with presumptive tax schedule
****
**Oil and coffee sale same 10%
gen oil=s12bq01a =="Edible oil mill"
replace oil=1 if s12bq01a =="Selling coffee bean skin and salt"


gen chat=s12bq01a=="Selling chat"|s12bq01a=="Selling chat "|s12bq01a=="Broker- chat selling"
lab var chat "Chat trader"

*Animal products sale& chicken and egg sale (10% tax)
gen meat=s12bq01a=="Sheep trader"|s12bq01a=="Animal trader"|s12bq01a=="Chicken trader"|s12bq01a=="Goat trader"|s12bq01a=="Livestock trader"
replace meat =1 if s12bq01a=="Poultry trade"|s12bq01a=="Chicken Farm"|s12bq01a=="Cattle trade"||s12bq01a=="Sheep selling"
replace meat =1 if s12bq01a=="Selling milk"|s12bq01a=="Distributing milk"|s12bq01a=="Goat selling"
replace meat =1 if s12bq01a=="Poultry trade"|s12bq01a=="Diary products sales"|s12bq01a=="Selling butter"
lab var meat "Meat trader"

gen butcher=s12bq01a=="Butchery"

**General Merchandise  Trade and Grocery
gen store=s12bq01a=="Grocery"|s12bq01a=="Vegetable store"|s12bq01a=="Supermarket"
replace store=1 if s12bq01a=="Biskut seller"
replace store=1 if  s12bq01a=="Selling water"|s12bq01a=="Selling water "
replace store=1 if  s12bq01a=="Selling merchandise"
replace store=1 if  s12bq01a=="Selling soft drinks"|s12bq01a== "Selling spicy food"| s12bq01a=="Selling cooked potato"|s12bq01a=="Selling cooked potato and beans "  
replace store=1 if  s12bq01a=="Distributing drinks"|s12bq01a=="Selling bread "
replace store=1 if  s12bq01a=="Producing and selling food  spices"
replace store=1 if  s12bq01a=="Selling spices"
replace store=1 if  s12bq01a=="Selling Cookie"|s12bq01a=="Shoe shop"
lab var store "Store/supermarket, merchandice"

gen veg_trade=s12bq01a=="Potato trader"|s12bq01a=="Papper trader"|s12bq01a=="Selling fruits "|s12bq01a=="Selling fruits  and vegetables" |s12bq01a=="Selling vegetables"|s12bq01a=="Selling vegetables "|s12bq01a=="Vegetable trader"|s12bq01a=="Vegetable trader "|s12bq01a=="Vegetables selling"
replace veg_trade=1 if s12bq01a =="Selling shiro and chilli pepper powder"|s12bq01a =="Selling chilli pepper powder"|s12bq01a=="Selling fruits"
lab var veg_trade "Fruits and vegetable trade"

gen gold_trade=s12bq01a=="Gold trader"|s12bq01a=="Selling gold"

gen grain=s12bq01a=="retail of grains"|s12bq01a=="Crop buying and selling "|s12bq01a=="Crop selling "|s12bq01a=="Crop trader"|s12bq01a=="Crop trader "|s12bq01a=="Selling Flour"
replace grain=1 if s12bq01a=="Selling maize"|s12bq01a=="Selling maize and sorghum"|s12bq01a=="Selling grain"|s12bq01a=="Grain sales"
lab var grain "Selling cereals"

replace grain=0 if s12bq01a=="Selling Enjera "&s12bq01b==56

gen mill=s12bq01a=="Mill service"|s12bq01a=="Grain mill"
gen furniture=s12bq01a=="Furniture store"|s12bq01a=="Furniture and household items shop"
gen carpenter=s12bq01a== "Carpenter"|s12bq01a== "Wood production"|s12bq01a== "Wood manufacturing "|s12bq01a== "Carpentry"|s12bq01a== "Carpentry and selling Enjera"|s12bq01a== "Wood workshop"

gen construction_building=s12bq01b==41|s12bq01b==43
replace construction_building=0 if carpenter==1
lab var construction_building "Construction of buildings"

gen clay=s12bq01a=="Producing materials from clay"|s12bq01a=="Producing materials from clay"|s12bq01a=="Producing materials from clay and selling"
replace clay=1 if s12bq01a=="Selling building materials"|s12bq01a=="Producing materials from clay "
replace clay=1 if s12bq01a=="Cement trader"

gen factory=s12bq01a=="Blocket factory "

gen beautysalon=s12bq01a=="Beauty salon"|s12bq01a=="Barber"|s12bq01a=="Hair salon"|s12bq01a=="Barber shop"
lab var beautysalon "Beauty salon"

gen boutique=s12bq01a=="Boutique"|s12bq01a=="Boutique "|s12bq01a=="Clothes shop"|s12bq01a=="Selling clothes"


gen bamboo=s12bq01a=="Bamboo craft"
replace bamboo=1 if s12bq01a=="Craftsman"|s12bq01a=="Craftswoman"
replace bamboo=1 if s12bq01a=="Handcraft "

 gen tire=s12bq01a== "Tire technician"
 replace tire=1 if s12bq01a== "Spare part"|s12bq01a== "Tyre and car repair"|s12bq01a=="Tyre repair"|s12bq01a== "Spare parts shop"
 
 gen phone=s12bq01a=="Mobile Phone shop"|s12bq01a=="Mobile Phone maintainance"|s12bq01a=="Mobile Phone shop"|s12bq01a=="Mobile phone sales"|s12bq01a== "Mobile phone shop"|s12bq01a== "Phone repair"|s12bq01a==  "Mobile accessary"
 gen electrician=s12bq01a=="Electrician "|s12bq01a=="Electric service"|s12bq01a=="Electrician"
 replace electrician=1 if s12bq01a=="Installation worker"
 
 
 gen broker=s12bq01a=="Broker"|s12bq01a== "Broker "
 gen leather=s12bq01a=="Leather factory"
 gen mason=s12bq01a=="Mason"|s12bq01a=="Mason "
 gen mechanic=s12bq01a=="Mechanic"|s12bq01a=="Mechanic "|s12bq01a=="Auto mechanic"
 
 gen movie=s12bq01a=="Film house"|s12bq01a=="Movie house"
 gen laundry=s12bq01a=="Laundry/hand wash service"
 gen shoe=s12bq01a=="Shoe repair"|s12bq01a=="Shoemaker"
gen clean=s12bq01a=="Cleaning service"
gen engineer=s12bq01a=="Engineer"
 gen construction_trade=s12bq01a=="Construction material sales"|s12bq01a=="Construction materials sales"|s12bq01a=="Construction materials trade"|s12bq01a=="Bricks manufacturing"
gen attorney=s12bq01a=="Lawyer"
gen video=s12bq01a=="Video shop"

 egen temp=rowtotal(wood bar bakery transit manuf_cloth manuf_metal guard restaurant oil - video)

*****************
*TAXES ON PROFITS AND INCOME
**********************

gen taxpaid=s12bq20==1
lab var taxpaid "Was any tax paid?"

gen tax=s12bq21
replace tax=0 if taxpaid==0
lab var tax "Taxes paid,=0 if no tax paid"
winsor2 tax, replace cuts(0 98) trim
 format tax %12.0gc
 
gen tax_0=tax/1000
lab var tax_0 "Taxes paid as profit or income tax, '000"

gen markettax_paid=s12bq22==1
lab var markettax_paid "Paid market tax, municipality fee"

gen markettax=s12bq23
replace markettax=0 if markettax_paid==0
lab var markettax "Market taxes paid (Birr)"
winsor2 markettax, replace cuts(0 98) trim
 format markettax %12.0gc

gen markettax_0=markettax/1000
lab var markettax_0 "Market taxes paid ('000 Birr)"
 
*How many months active?

**8firms 0 months active
ta s12bq12
*Drop inactive firms 
drop if s12bq12==0

*********************
** Gross turnover
********************

*Monthly sales s12bq16 
replace s12bq12=12 if s12bq12>12

*** Drop if sale_monthly==0
ta s12bq16

gen sale_monthly=s12bq16
lab var sale_monthly "Average monthly sales"

drop if sale_monthly==0
*75 dropped


gen sale_monthly_0=sale_monthly/1000
lab var sale_monthly_0 "Average monthly sales ('000 Birr)"

gen gross=sale_monthly*s12bq12 
lab var gross "Annual turnover, Birr"

*Restrict to Category C enterprises
count if gross>=500000
*59 firms over the Category C limit
drop if gross>=500000

winsor2 gross, replace cuts(1 100) trim
drop if gross==.
*12 dropped
** 1,396 firms left


gen gross_0=gross/1000
lab var gross_0 "Annual turnover ('000 Birr)"

*gen percentage_income=s12bq24
*lab var percentage_income "Percentage of income from NFE"

gen     gross_cat=1 if gross_0<=50
replace gross_cat=2 if gross_0>50&gross_0<=75
replace gross_cat=3 if gross_0>75&gross_0<=100
replace gross_cat=4 if gross_0>100&gross_0<=125
replace gross_cat=5 if gross_0>125&gross_0<=150
replace gross_cat=6 if gross_0>150&gross_0<=175
replace gross_cat=7 if gross_0>175&gross_0<=200
replace gross_cat=8 if gross_0>200&gross_0<=225
replace gross_cat=9 if gross_0>225&gross_0<=250
replace gross_cat=10 if gross_0>250&gross_0<=275
replace gross_cat=11 if gross_0>275&gross_0<=300
replace gross_cat=12 if gross_0>300&gross_0<=325
replace gross_cat=13 if gross_0>325&gross_0<=350
replace gross_cat=14 if gross_0>350&gross_0<=375
replace gross_cat=15 if gross_0>375&gross_0<=400
replace gross_cat=16 if gross_0>400&gross_0<=425
replace gross_cat=17 if gross_0>425&gross_0<=450
replace gross_cat=18 if gross_0>450&gross_0<=475
replace gross_cat=19 if gross_0>475&gross_0<=500
lab def gross_cat 1 "<50,000" 2 "50,001-75,000" 3 "75,001-100,000" 4 "100,001-125,000" 5 "125,001-150,000" 6 "150,001-175,000" 7 "175,001-200,000" 8 "200,001-225,000" 9 "225,001-250,000" ///
10 "250,001-275,000" 11 "275,001-300,000" 12 "300,001-325,000" 13 "325,001-350,000" 14 "350,001-375,000" 15 "375,001-400,000" ///
16 "400,001-425,000" 17 "425,001-450,000" 18 "450,001-475,000" 19 "475,001-500,000"
lab val gross_cat gross_cat
lab var gross_cat "Turnover, Birr"

bysort gross_cat: su tax
gen gross_50=gross_0<=50
lab var gross_50 "<=50,000 Birr"

gen     gross_cat_10=1 if gross_0<=50
replace gross_cat_10=2 if gross_0>50&gross_0<=75
replace gross_cat_10=3 if gross_0>75&gross_0<=100
replace gross_cat_10=4 if gross_0>100&gross_0<=125
replace gross_cat_10=5 if gross_0>125&gross_0<=150
replace gross_cat_10=6 if gross_0>150&gross_0<=175
replace gross_cat_10=7 if gross_0>175&gross_0<=200
replace gross_cat_10=8 if gross_0>200&gross_0<=300
replace gross_cat_10=9 if gross_0>300&gross_0<=400
replace gross_cat_10=10 if gross_0>400&gross_0<500
lab def gross_cat_10 1 "<=50" 2 "50-75" 3 "75-100" 4 "100-125" 5 "125-150" 6 "150-175" 7 "175-200" 8 "200-300" 9 "300-400" 10 "400-500", replace 
lab val gross_cat_10 gross_cat_10
lab var gross_cat_10 "Turnover, '000 Birr"




* No employees: Own account enterprises
gen ownaccount=s12bq14==0
lab var ownaccount "Own account"
gen micro=s12bq14<=5
lab var micro "Microenterprise: 5 or less"

gen employee=s12bq14
lab var employee "Number of employees"

gen taxrate=(tax/gross)*100
lab var taxrate  "Tax as % of turnover"
replace taxrate=. if taxrate>100
*9 obs

gen obs_tax= s12bq25_1==131|s12bq25_2==131|s12bq25_3==131
lab var obs_tax "High taxes an obstacle (%)"

gen obs_informaltax= s12bq25_1==132|s12bq25_2==132|s12bq25_3==132
lab var obs_informaltax "Unofficial taxes an obstacle (%)"

**Annual costs of goods sold, 000 Birr
gen month_operational= s12bq12
lab var month_operational "Number of months operational"


gen goods=(s12bq17b*month_operational)
lab var goods "Annual purchase of goods for sale, Birr"
gen rawmaterial=(s12bq17c*month_operational)
lab var rawmaterial "Annual raw materials, Birr"

gen cost_annual=goods+rawmaterial
lab var cost_annual "Annual cost of goods sold"
winsor2 cost_annual, replace cuts(0 98) trim


gen cost_annual_0=(goods+rawmaterial)/1000
lab var cost_annual_0 "Annual cost of goods sold, 000"


***Start up capital (first and second sources)
gen capital_ag=s12bq07_1==1|s12bq07_2==1
lab var capital_ag "Agricultural income"
gen capital_nfi=s12bq07_1==2|s12bq07_2==2
lab var capital_nfi "Non farm self-employment income"
gen capital_wage=s12bq07_1==3|s12bq07_2==3
lab var capital_wage "Wage income"

gen capital_bank=s12bq07_1==6| s12bq07_1==8| s12bq07_1==9|s12bq07_2==6| s12bq07_2==8| s12bq07_2==9
lab var capital_bank "Banks, lenders, or credit association"

**Customer base
gen customer_local=s12bq09_1==1
lab var customer_local "Local consumers, passerby"
gen customer_market=s12bq09_1==2
lab var customer_market "Market"
gen customer_trader=s12bq09_1==3
lab var customer_trader "Traders"

**Months most active
gen november=s12bq11_1==3|s12bq11_2==3|s12bq11_3==3
gen december=s12bq11_1==4|s12bq11_2==4|s12bq11_3==4
gen january=s12bq11_1==5|s12bq11_2==5|s12bq11_3==5

tabulate cons_quint, generate(quintile)
gen urban=rural==2
lab var urban "Urban"

*********************************
**Impute presumptive taxes by sector and turnover


** Chat trade (16%)
gen presump_impute=80 if chat==1&gross_cat==1
replace presump_impute=480 if chat==1&gross_cat==2
replace presump_impute=880 if chat==1&gross_cat==3
replace presump_impute=1290 if chat==1&gross_cat==4
replace presump_impute=1890 if chat==1&gross_cat==5
replace presump_impute=2490 if chat==1&gross_cat==6
replace presump_impute=3090 if chat==1&gross_cat==7
replace presump_impute=3690 if chat==1&gross_cat==8
replace presump_impute=4370 if chat==1&gross_cat==9
replace presump_impute=5170 if chat==1&gross_cat==10
replace presump_impute=5970 if chat==1&gross_cat==11
replace presump_impute=6770 if chat==1&gross_cat==12
replace presump_impute=11220 if chat==1&gross_cat==17
replace presump_impute=13220 if chat==1&gross_cat==19

** Charcoal trade/wood trade (10%)
replace presump_impute=0 if wood==1&gross_cat==1
replace presump_impute=30 if wood==1&gross_cat==2
replace presump_impute=280 if wood==1&gross_cat==3
replace presump_impute=530 if wood==1&gross_cat==4
replace presump_impute=1030 if wood==1&gross_cat==6
replace presump_impute=1290 if wood==1&gross_cat==7
replace presump_impute=2040 if wood==1&gross_cat==9
replace presump_impute=3915 if wood==1&gross_cat==14

** Beauty salon (10%)
replace presump_impute=0 if beautysalon==1&gross_cat==1
replace presump_impute=30 if beautysalon==1&gross_cat==2
replace presump_impute=280 if beautysalon==1&gross_cat==3
replace presump_impute=530 if beautysalon==1&gross_cat==4
replace presump_impute=1290 if beautysalon==1&gross_cat==7


**Weaving/boutique (10%) = Thread, Textiles and Textile Products Trade /Tailoring Service Only (same rate)
replace presump_impute=0 if (manuf_cloth==1|boutique==1)&gross_cat==1
replace presump_impute=30 if (manuf_cloth==1|boutique==1)&gross_cat==2
replace presump_impute=280 if (manuf_cloth==1|boutique==1)&gross_cat==3
replace presump_impute=530 if (manuf_cloth==1|boutique==1)&gross_cat==4
replace presump_impute=780 if (manuf_cloth==1|boutique==1)&gross_cat==5
replace presump_impute=1030 if (manuf_cloth==1|boutique==1)&gross_cat==6
replace presump_impute=1665 if (manuf_cloth==1|boutique==1)&gross_cat==8
replace presump_impute=2040 if (manuf_cloth==1|boutique==1)&gross_cat==9
replace presump_impute=2415 if (manuf_cloth==1|boutique==1)&gross_cat==10
replace presump_impute=2790 if (manuf_cloth==1|boutique==1)&gross_cat==11
replace presump_impute=3165 if (manuf_cloth==1|boutique==1)&gross_cat==12
replace presump_impute=3540 if (manuf_cloth==1|boutique==1)&gross_cat==13
replace presump_impute=3915 if (manuf_cloth==1|boutique==1)&gross_cat==14
replace presump_impute=4370 if(manuf_cloth==1|boutique==1)&gross_cat==15


** Cereal Trade =Cereals and Pulses Trade (10%)
replace presump_impute=0 if grain==1&gross_cat==1
replace presump_impute=30 if grain==1&gross_cat==2
replace presump_impute=280 if grain==1&gross_cat==3
replace presump_impute=780 if grain==1&gross_cat==5
replace presump_impute=1290 if grain==1&gross_cat==7
replace presump_impute=3915 if grain==1&gross_cat==14
replace presump_impute=4370 if grain==1&gross_cat==15

* Meat trader (10%) = animal / animal product trade, also = Chicken and Egg Trade 
replace presump_impute=0 if meat==1&gross_cat==1
replace presump_impute=30 if meat==1&gross_cat==2
replace presump_impute=280 if meat==1&gross_cat==3
replace presump_impute=530 if meat==1&gross_cat==4
replace presump_impute=780 if meat==1&gross_cat==5
replace presump_impute=1290 if meat==1&gross_cat==7
replace presump_impute=2040 if meat==1&gross_cat==9
replace presump_impute=2415 if meat==1&gross_cat==10
replace presump_impute=3915 if meat==1&gross_cat==14
replace presump_impute=5370 if meat==1&gross_cat==17

**Edible oil or bamboo prod or tyre repair or grain cleaning =mill service (10%)
replace presump_impute=0 if (bamboo==1|oil==1|tire==1|mill==1)&gross_cat==1
replace presump_impute=30 if (bamboo==1|oil==1|tire==1|mill==1)&gross_cat==2
replace presump_impute=280 if (bamboo==1|oil==1|tire==1|mill==1)&gross_cat==3
replace presump_impute=530 if (bamboo==1|oil==1|tire==1)&gross_cat==4
replace presump_impute=780 if (bamboo==1|oil==1|tire==1)&gross_cat==5
replace presump_impute=2040 if (bamboo==1|oil==1|tire==1)&gross_cat==9
replace presump_impute=4370 if (bamboo==1|oil==1|tire==1)&gross_cat==15


**Furniture store, carpenter? = Bed ,Mattress and Dengel Production and Trade? (10%)
replace presump_impute=0 if (carpenter==1|furniture==1)&gross_cat==1
replace presump_impute=30 if (carpenter==1|furniture==1)&gross_cat==2
replace presump_impute=280 if (carpenter==1|furniture==1)&gross_cat==3
replace presump_impute=530 if (carpenter==1|furniture==1)&gross_cat==4
replace presump_impute=780 if (carpenter==1|furniture==1)&gross_cat==5
replace presump_impute=2790 if (carpenter==1|furniture==1)&gross_cat==11

replace presump_impute=4370 if (carpenter==1|furniture==1)&gross_cat==15


***Laundry service (11%)
replace presump_impute=0 if laundry==1&gross_cat==1
replace presump_impute=380 if laundry==1&gross_cat==3

*Guard service (12%), cleaning service (12%)
replace presump_impute=0 if (clean==1|guard==1)&gross_cat==1
replace presump_impute=180 if (clean==1|guard==1)&gross_cat==2

**Fruit and veg trade (13%)
replace presump_impute=0 if veg_trade==1&gross_cat==1
replace presump_impute=255 if veg_trade==1&gross_cat==2
replace presump_impute=580 if veg_trade==1&gross_cat==3
replace presump_impute=905 if veg_trade==1&gross_cat==4
replace presump_impute=1230 if veg_trade==1&gross_cat==5
replace presump_impute=2190 if veg_trade==1&gross_cat==7
replace presump_impute=2678 if veg_trade==1&gross_cat==8
replace presump_impute=3165 if veg_trade==1&gross_cat==9
replace presump_impute=5470 if veg_trade==1&gross_cat==13

*Butcher = slaughter services (13%)
replace presump_impute=0 if butcher==1&gross_cat==1
replace presump_impute=255 if butcher==1&gross_cat==2
replace presump_impute=905 if butcher==1&gross_cat==4
replace presump_impute=2190 if butcher==1&gross_cat==7
replace presump_impute=3165 if butcher==1&gross_cat==9
replace presump_impute=4170 if butcher==1&gross_cat==11
replace presump_impute=6120 if butcher==1&gross_cat==14

**Mechanic & motorcycle operater=Vehicles Spare Parts Trade and Workshop Services (13%)
replace presump_impute=0 if mechanic==1&gross_cat==1
replace presump_impute=255 if mechanic==1&gross_cat==2
replace presump_impute=580 if mechanic==1&gross_cat==3
replace presump_impute=905 if mechanic==1&gross_cat==4
replace presump_impute=1230 if mechanic==1&gross_cat==5
replace presump_impute=2190 if mechanic==1&gross_cat==7
replace presump_impute=3165 if mechanic==1&gross_cat==9
replace presump_impute=4170 if mechanic==1&gross_cat==11

** Grocery store/supermarket =General Merchandise  Trade and Grocery(14%)
*** Classify local alcohol under this one.
*** June 1, 2022. Non-establishment based food service classify under this one (21 obs)
** Dec 9 20222 include bakeries
replace presump_impute=0 if (alcohol==1|store==1|bakery==1)&gross_cat==1
replace presump_impute=330 if (alcohol==1|store==1|bakery==1)&gross_cat==2
replace presump_impute=680 if (alcohol==1|store==1|bakery==1)&gross_cat==3
replace presump_impute=1030 if (alcohol==1|store==1|bakery==1)&gross_cat==4
replace presump_impute=1440 if (alcohol==1|store==1|bakery==1)&gross_cat==5
replace presump_impute=1965 if (alcohol==1|store==1|bakery==1)&gross_cat==6
replace presump_impute=2490 if (alcohol==1|store==1|bakery==1)&gross_cat==7
replace presump_impute=3015 if (alcohol==1|store==1|bakery==1)&gross_cat==8
replace presump_impute=3540 if (alcohol==1|store==1|bakery==1)&gross_cat==9
replace presump_impute=4070 if (alcohol==1|store==1|bakery==1)&gross_cat==10
replace presump_impute=4770 if (alcohol==1|store==1|bakery==1)&gross_cat==11
replace presump_impute=5470 if (alcohol==1|store==1|bakery==1)&gross_cat==12
replace presump_impute=6870 if (alcohol==1|store==1|bakery==1)&gross_cat==14
replace presump_impute=10720 if (alcohol==1|store==1|bakery==1)&gross_cat==19

** Transit services (30%)
replace presump_impute=780 if transit==1&gross_cat==1
replace presump_impute=1665 if transit==1&gross_cat==2
replace presump_impute=2790 if transit==1&gross_cat==3
replace presump_impute=3915 if transit==1&gross_cat==4
replace presump_impute=5370 if transit==1&gross_cat==5
replace presump_impute=6870 if transit==1&gross_cat==6
replace presump_impute=8370 if transit==1&gross_cat==7
replace presump_impute=10095 if transit==1&gross_cat==8
replace presump_impute=11970 if transit==1&gross_cat==9
replace presump_impute=13845 if transit==1&gross_cat==10
replace presump_impute=15720 if transit==1&gross_cat==11
replace presump_impute=16125 if transit==1&gross_cat==12
replace presump_impute=18750 if transit==1&gross_cat==13
replace presump_impute=21375 if transit==1&gross_cat==14
replace presump_impute=34500 if transit==1&gross_cat==19

** Manuf metal, producing clay, gold trade - Gold, Silver Smith, Jewelry and other Precious Minerals Trade (15%), Is this "Metal and Building Materials Trade" (15%) not "Construction Materials Production and Trade" (18%)
replace presump_impute=30 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==1
replace presump_impute=405 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==2
replace presump_impute=1155 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==4
replace presump_impute=2228 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==6
replace presump_impute=3353 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==8
replace presump_impute=3915 if (gold_trade==1|clay==1|manuf_metal==1)&gross_cat==9

**Construction Materials Production and Trade (18%)
replace presump_impute= 180 if construction_trade==1&gross_cat==1
replace presump_impute= 630 if construction_trade==1&gross_cat==2
replace presump_impute= 5370 if construction_trade==1&gross_cat==9
replace presump_impute= 10095 if construction_trade==1&gross_cat==14
replace presump_impute= 11220 if construction_trade==1&gross_cat==15
replace presump_impute= 15720 if construction_trade==1&gross_cat==19


* Building contractor or  mason=Building Contractors (16%)
replace presump_impute=80 if (mason==1|construction_building==1)&gross_cat==1
replace presump_impute=480 if (mason==1|construction_building==1)&gross_cat==2
replace presump_impute=880 if (mason==1|construction_building==1)&gross_cat==3
replace presump_impute=1290 if (mason==1|construction_building==1)&gross_cat==4
replace presump_impute=1890 if (mason==1|construction_building==1)&gross_cat==5
replace presump_impute=4370 if (mason==1|construction_building==1)&gross_cat==9
replace presump_impute=5970 if (mason==1|construction_building==1)&gross_cat==11

**Phone store=Electronic Goods Supply and Repair (16%)
replace presump_impute=80 if  phone==1&gross_cat==1
replace presump_impute=480 if  phone==1&gross_cat==2
replace presump_impute=880 if  phone==1&gross_cat==3
replace presump_impute=1290 if  phone==1&gross_cat==4
replace presump_impute=5970 if  phone==1&gross_cat==11

***Electricians? =Electrical Lift Works and Repair (25%)
replace presump_impute=530 if  electrician==1&gross_cat==1
replace presump_impute=1155 if  electrician==1&gross_cat==2
replace presump_impute=2040 if  electrician==1&gross_cat==3
replace presump_impute=3915 if  electrician==1&gross_cat==5
replace presump_impute=5120 if  electrician==1&gross_cat==6

**** Bars, hotel, cafes (25%), Sporting Activities and Games Services (25%) 
**** Legal=Attorney Services (25%)

replace presump_impute=530  if (restaurant==1|bar==1|attorney==1)& gross_cat==1
replace presump_impute=1155 if (restaurant==1|bar==1|attorney==1)& gross_cat==2
replace presump_impute=2040 if (restaurant==1|bar==1|attorney==1)& gross_cat==3
replace presump_impute=2978 if (restaurant==1|bar==1|attorney==1)& gross_cat==4
replace presump_impute=3915 if (restaurant==1|bar==1|attorney==1)& gross_cat==5
replace presump_impute=5120 if (restaurant==1|bar==1|attorney==1)& gross_cat==6
replace presump_impute=6370 if (restaurant==1|bar==1|attorney==1)& gross_cat==7
replace presump_impute=7620 if (restaurant==1|bar==1|attorney==1)& gross_cat==8
replace presump_impute=8870 if (restaurant==1|bar==1|attorney==1)& gross_cat==9
replace presump_impute=10408 if (restaurant==1|bar==1|attorney==1)& gross_cat==10
replace presump_impute=11970 if (restaurant==1|bar==1|attorney==1)& gross_cat==11
replace presump_impute=13533 if (restaurant==1|bar==1|attorney==1)& gross_cat==12
replace presump_impute=15095 if (restaurant==1|bar==1|attorney==1)& gross_cat==13
replace presump_impute=14813 if (restaurant==1|bar==1|attorney==1)& gross_cat==14
replace presump_impute=17000 if (restaurant==1|bar==1|attorney==1)& gross_cat==15
replace presump_impute=19188 if (restaurant==1|bar==1|attorney==1)& gross_cat==16
replace presump_impute=21375 if (restaurant==1|bar==1|attorney==1)& gross_cat==17
replace presump_impute=23563 if (restaurant==1|bar==1|attorney==1)& gross_cat==18
replace presump_impute=25750 if (restaurant==1|bar==1|attorney==1)& gross_cat==19



**Video music store (28%)
replace presump_impute=680  if (video==1)& gross_cat==1
replace presump_impute=1440  if (video==1)& gross_cat==2
replace presump_impute=2490  if (video==1)& gross_cat==3
replace presump_impute=3540 if (video==1)& gross_cat==4
replace presump_impute=7570 if (video==1)& gross_cat==7


**Engineer (29%)
replace presump_impute=730   if (engineer==1)& gross_cat==1
replace presump_impute=1553  if(engineer==1)& gross_cat==2
replace presump_impute=2640  if (engineer==1)& gross_cat==3
replace presump_impute=7970  if (engineer==1)& gross_cat==7

**Broker (30%)
replace presump_impute=780 if  broker==1&gross_cat==1
replace presump_impute=1665 if  broker==1&gross_cat==2
replace presump_impute=2790 if  broker==1&gross_cat==3
replace presump_impute=3915 if  broker==1&gross_cat==4
replace presump_impute=5370 if  broker==1&gross_cat==5
replace presump_impute=11970 if  broker==1&gross_cat==9
lab var presump_impute "Imputed presumptive taxes"



gen taxrate_impute=((presump_impute)/gross)*100
lab var taxrate_impute "Imputed presumptive tax as % of sales"
replace taxrate_impute=. if taxrate_impute>100
*6


gen taxnet=100 if presump_impute>0&presump_impute!=.
replace taxnet=0 if presump_impute==0&presump_impute!=.
replace taxnet=. if presump_impute==.
lab var taxnet "% who should pay presumptive tax"

xtile gross_quintile = gross[pweight=pw_w5], nq(5)
lab var gross_quintile "Quintile of turnover"



xtile gross_quartile= gross[pweight=pw_w5], nq(4)
lab var gross_quartile "Quartile of turnover"


gen     gross_cat_3=1 if gross_0<=50
replace gross_cat_3=2 if gross_0>50&gross_0<=75
replace gross_cat_3=3 if gross_0>75
lab def gross_cat_3 1 "<=50" 2 "50-75" 3 "75-500", replace 
lab val gross_cat_3 gross_cat_3
lab var gross_cat_3 "Turnover, '000 Birr"


gen     gross_cat_4=1 if gross_0<=25
replace gross_cat_4=2 if gross_0>25&gross_0<=50
replace gross_cat_4=3 if gross_0>50&gross_0<=75
replace gross_cat_4=4 if gross_0>75
lab def gross_cat_4 1 "<=25" 2 "25-50" 3 "50-75" 4 "75-500", replace 
lab val gross_cat_4 gross_cat_4
lab var gross_cat_4 "Turnover, '000 Birr"


gen non_exempt_sector=chat==1| leather==1| movie==1| transit ==1|gold_trade==1|clay==1|manuf_metal==1 | mason==1|construction_building==1| factory==1| phone==1|  electrician==1| bar==1| broker==1|restaurant==1
replace non_exempt_sector=. if presump_impute==.
lab var non_exempt_sector "Non exempt sector"


gen non_exempt_sector_per=non_exempt_sector*100
lab var non_exempt_sector_per "% of firms in non exempt sectors"

gen exempt_sector=non_exempt_sector==0
replace exempt_sector=. if non_exempt_sector==.
lab var exempt_sector "Sector with tax-free threshold"
	
*********************************************************
**Hypothetical taxes
*************************

**Hypothetical taxes
** Presumptive tax=2.5% of turnover, exempts 50,000 Birr
gen presump_hyp=gross*0.025
replace presump_hyp=0 if gross<=50000
*set to missing if taxpaid is missing so as to compare two results
replace presump_hyp=. if tax==.
lab var presump_hyp "Hypothetical presumptive tax amount"

gen presump_hyp_rate=presump_hyp/gross*100
lab var presump_hyp_rate "Hypothetical presumptive tax rate"




gen presump_hyp_positive=presump_hyp
replace presump_hyp_positive=. if presump_hyp<=0
lab var presump_hyp_positive "Presumptive taxes paid hypothetical given tax>0"

gen tax_positive=tax
replace tax_positive=. if tax<=0
lab var tax_positive "Tax paid, given tax>0"

gen exempt_hyp=presump_hyp==0
replace exempt_hyp=. if presump_hyp==.
lab var exempt_hyp "% of firms that are exempt"

gen taxpaying_hyp=presump_hyp!=0
replace taxpaying_hyp=. if presump_hyp==.
lab var taxpaying_hyp "% of taxpaying firms, hypothetical"

gen presump_hyp_50=presump_hyp
replace presump_hyp_50=0 if gross_0<100
lab var presump_hyp_50 "Hypothetical presumptive tax but noncompliance for firms <100,000"

gen presump_hyp_50_positive=presump_hyp_50
replace presump_hyp_50_positive=. if presump_hyp_50<=0
lab var presump_hyp_50_positive "Hypothetical presumptive tax but noncompliance for firms <100,000 given tax>0"

gen exempt_hyp_50 = presump_hyp_50==0
lab var exempt_hyp_50 "% of firms that are not paying"

gen taxpaying_hyp50=presump_hyp_50!=0
replace taxpaying_hyp50=. if presump_hyp_50==.
lab var taxpaying_hyp50 "% of taxpaying firms, hypothetical 50% compliance"

gen tax_new2=0.02*gross
replace tax_new2=0 if gross<=50000
count if tax_new2!=0

gen tax_new25=0.025*gross
replace tax_new25=0 if gross<=50000
count if tax_new25!=0

gen tax_new3=0.03*gross
replace tax_new3=0 if gross<=50000
count if tax_new3!=0


gen presump_hyp_rate_2= tax_new2/gross*100
lab var presump_hyp_rate_2 "Hypothetical presumptive tax rate (2%)"

gen presump_hyp_2_50=tax_new2
replace presump_hyp_2_50=0 if gross_0<100
lab var presump_hyp_2_50 "Hypothetical presumptive tax (2%) but noncompliance for firms <100,000"

gen exempt=presump_impute==0

foreach var in presump_hyp_positive taxpaying_hyp presump_hyp_50 presump_hyp_50_positive exempt_hyp_50 taxpaying_hyp50 presump_hyp_2_50{
    replace `var'=. if presump_hyp==.
}


gen exempt_sector_per=exempt_sector*100
lab var exempt_sector_per "% of firms with tax-free threshold"

 gen taxpaid_per=taxpaid*100
 lab var taxpaid_per "% of taxpayers"
 
 
foreach var in home_inside home_outside market shop road mobile construction_site{
    replace `var'=`var'*100
}

 
gen other_sector=sector_prof+sector_misc+sector_primary
lab var other_sector "Others"  

gen alcohol_per=alcohol*100
gen transit_per=transit*100
gen food_service_per=food_service*100
gen sector_trade_per=sector_trade*100

foreach var in sector_manuf manuf_food manuf_cloth manuf_other   wholesale sector_service    other_pc sector_construction other_sector{
    replace `var'=`var'*100
}


save "$newdata/ethiopia_enterprise_wave5_Oct92023.dta", replace


preserve
*** By enterprise
keep household_id owner_sex_2 presump_impute gross gross_0   tax tax_0  bar restaurant transit food_service  wood manuf_beverage manuf_food  alcohol manuf_cloth manuf_wood manuf_metal manuf_other wholesale retail_other retail_all sector_trade other_pc sector_service sector_manuf sector_primary sector_construction sector* other_activities sector sub_sector

collapse   (sum) presump_impute gross gross_0    tax tax_0 (max)  bar restaurant  transit food_service  wood manuf_beverage manuf_food  alcohol manuf_cloth manuf_wood manuf_metal manuf_other wholesale retail_other retail_all sector_trade other_pc sector_service sector_manuf sector_primary sector_construction  sector_prof sector_misc  other_activities  , by(household_id)
lab var gross "Annual turnover, Birr"
lab var gross_0 "Annual turnover ('000 Birr)"
lab var presump_impute "Impute presumptive taxes"

*  1,435 households 

*** By household
save "$newdata/ethiopia_household_wave5_Oct92023.dta", replace
restore 


use "$newdata/ethiopia_enterprise_wave5_Oct92023.dta", clear
drop if tax==.
** 22 dropped



** 2021: 152.7 in 2019 price
gen real_gross=(gross/152.7)*100 
lab var real_gross "Real turnover, 2019 prices"
gen real_gross_0=real_gross/1000
lab var real_gross_0 "Real turnover,'000, 2019 prices"

gen taxpaying_hyp_2=tax_new2!=0
replace taxpaying_hyp_2=. if tax_new2==.
lab var taxpaying_hyp_2 "% of taxpaying firms (2%), hypothetical"


gen taxpaying_hyp_2_50=presump_hyp_2_50!=0
replace taxpaying_hyp_2_50=. if presump_hyp_2_50==.
lab var taxpaying_hyp_2_50 "% of taxpaying firms (2%), hypothetical 50% compliance"


lab var gross_50 "<=50,000 Birr"

gen gross_cat_2=1 if gross_0<=50
replace gross_cat_2=2 if gross_0>50
lab def gross_cat_2 1 "<=50" 2 "50-500", replace 
lab val gross_cat_2 gross_cat_2
lab var gross_cat_2 "Turnover, '000 Birr"

gen revenue_2=1 if gross_50==1
replace revenue_2=2 if gross_50==0
lab def revenue_2 1 "Low revenue" 2 "High revenue"
lab val revenue_2 revenue_2


	
*************************
********FIGURE 1 
*************************

/*
graph bar (mean) sector_trade_per alcohol_per  manuf_cloth  manuf_food  manuf_other food_service_per  transit_per other_pc  sector_construction other_sector,  blabel(bar,  format(%9.1f)) scheme(s1color) over(owner_sex_2)title("Period 1 (2018/2019)") ,  [pw=pw_w5],  ///
   legend(label(1 "Trade") label(2 "Manuf of local beverages") label(3 "Manufacturing clothes") label(4 "Manufacturing food") label(5 "Other manufacturing") label(6 "Food services") label(7 "Transportation services") label(8 "Other personal services") label(9 "Construction") label(10 "Others"))   ///
  title("Period 1 (2018/2019)")   ///
  ytitle("% of enterprises") ///
  graphregion(color(white)) bgcolor(white)
graph save Graph "$excel/Figure1_1.gph", replace
*/


putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(Figure 1)

svyset ea_id[pw=pw_w5],  strata(region)

putexcel B19 = "Period 2, 2021/2022"
putexcel B20 = "Male-owned"
putexcel C20 = "Female-owned"

tabstat sector_trade_per  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B21=matrix(r(Stat1)),  nformat(0.0)
putexcel C21=matrix(r(Stat2)),  nformat(0.0)
putexcel A21  = "Trade"

tabstat alcohol_per  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B22=matrix(r(Stat1)),  nformat(0.0)
putexcel C22=matrix(r(Stat2)),  nformat(0.0)
putexcel A22  = "Manufacture or sale of local beverages"

tabstat manuf_cloth  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B23=matrix(r(Stat1)),  nformat(0.0)
putexcel C23=matrix(r(Stat2)),  nformat(0.0)
putexcel A23  = "Manufacturing clothes"

tabstat manuf_food  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B24=matrix(r(Stat1)),  nformat(0.0)
putexcel C24=matrix(r(Stat2)),  nformat(0.0)
putexcel A24  = "Manufacturing food"

tabstat manuf_other  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B25=matrix(r(Stat1)),  nformat(0.0)
putexcel C25=matrix(r(Stat2)),  nformat(0.0)
putexcel A25  = "Other manufacturing"


tabstat food_service_per  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B26=matrix(r(Stat1)),  nformat(0.0)
putexcel C26=matrix(r(Stat2)),  nformat(0.0)
putexcel A26  = "Food and beverage services and hotels"

tabstat transit_per  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B27=matrix(r(Stat1)),  nformat(0.0)
putexcel C27=matrix(r(Stat2)),  nformat(0.0)
putexcel A27  = "Transportation services"


tabstat other_pc  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B28=matrix(r(Stat1)),  nformat(0.0)
putexcel C28=matrix(r(Stat2)),  nformat(0.0)
putexcel A28  = "Other personal services"


tabstat sector_construction  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B29=matrix(r(Stat1)),  nformat(0.0)
putexcel C29=matrix(r(Stat2)),  nformat(0.0)
putexcel A29  = "Construction"

tabstat other_sector  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B30=matrix(r(Stat1)),  nformat(0.0)
putexcel C30=matrix(r(Stat2)),  nformat(0.0)
putexcel A30  = "Others"
 
 
 

/********************
*********ENTERPRISE CHARACTERISTICS  /TABLE 3
********************/


foreach var in micro ownaccount registered urban gross_50 markettax_paid   exempt_sector{
    replace `var'=`var'*100
}


set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(TABLE 3)

svyset ea_id[pw=pw_w5],  strata(region)

svyset ea_id[pw=pw_w5],  strata(region)

putexcel A1 = "Table 3: Enterprise characteristics, by sex of owner", bold

putexcel E4 = "Period 2 (2021/2022)", bold

putexcel E5 = "Male-owned"
putexcel F5 = "Female-owned"
putexcel G5 = "P-values"
putexcel D5 = "P-values"

putexcel (B5:G5), border(bottom)

putexcel (A20:G20),  border(bottom)
putexcel (A25:G25),  border(bottom)

putexcel (E4:E25),  border(left)
putexcel (A4:G4),  border(top)

tabstat micro  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel E6=matrix(r(Stat1)),  nformat(0.0)
putexcel F6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "Microenterprise (%)"
svy: mean micro, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G6=(`r(p)'), nformat(number_d2)

tabstat ownaccount  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel E7=matrix(r(Stat1)),  nformat(0.0)
putexcel F7=matrix(r(Stat2)),  nformat(0.0)

putexcel A7  = "Own account (%)"
svy: mean ownaccount, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G7=(`r(p)'), nformat(number_d2)


tabstat registered  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel E8=matrix(r(Stat1)),  nformat(0.0)
putexcel F8=matrix(r(Stat2)),  nformat(0.0)

putexcel A8 = "Registered (%)"
svy: mean registered, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G8=(`r(p)'), nformat(number_d2)


tabstat urban  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel E9=matrix(r(Stat1)),  nformat(0.0)
putexcel F9=matrix(r(Stat2)),  nformat(0.0)
putexcel A9  = "Urban (%)"
svy: mean urban, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G9=(`r(p)'), nformat(number_d2)

putexcel A10  = "Annual sales", bold

tabstat gross_0  [aw = pw_w5],  by(owner_sex_2) s(median) save 
putexcel E11=matrix(r(Stat1)),  nformat(0.0)
putexcel F11=matrix(r(Stat2)),  nformat(0.0)
putexcel A11  = "  Median annual sales ('000 Birr)"

median gross_0, by(owner_sex_2)

tabstat gross_0  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel E12 = matrix(r(Stat1)), nformat(0.0)
putexcel F12 = matrix(r(Stat2)), nformat(0.0)


** with standard deviation
tabstat gross_0  [aw = pw_w5],  by(owner_sex_2) s(sd) save 
putexcel E13 = matrix(r(Stat1)), nformat("(0.0)")
putexcel F13 = matrix(r(Stat2)), nformat("(0.0)")

putexcel A12  = "  Average annual sales ('000 Birr)"
svy: mean gross_0, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G12=(`r(p)'), nformat(number_d2)

tabstat gross_50  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel E14=matrix(r(Stat1)),  nformat(0.0)
putexcel F14=matrix(r(Stat2)),  nformat(0.0)
putexcel A14  = "  % with sales <=50,000 Birr"
svy: mean gross_50, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G14=(`r(p)'), nformat(number_d2)

putexcel A15  = "Taxes", bold

tabstat markettax_paid  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel E16=matrix(r(Stat1)),  nformat(0.0)
putexcel F16=matrix(r(Stat2)),  nformat(0.0)
putexcel A16  = "  Paid market tax or municipality fees (%)"
svy: mean markettax_paid, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G16=(`r(p)'), nformat(number_d2)


tabstat taxpaid_per [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel E17=matrix(r(Stat1)),  nformat(0.0)
putexcel F17=matrix(r(Stat2)),  nformat(0.0)
putexcel A17  = "  Paid tax on business income (%)"
svy: mean taxpaid_per, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G17=(`r(p)'), nformat(number_d2)

****** Mean and standard deviation
tabstat tax  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
matrix male = r(Stat1)
matrix female = r(Stat2)
putexcel E18 = matrix(male), nformat(0.0)
putexcel F18 = matrix(female), nformat(0.0)
putexcel A18  = "  Average tax paid on business income (Birr, self-reported)"

** with standard deviation
tabstat tax  [aw = pw_w5],  by(owner_sex_2) s(sd) save 
putexcel E19 = matrix(r(Stat1)), nformat("(0.0)")
putexcel F19 = matrix(r(Stat2)), nformat("(0.0)")

svy: mean tax, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G18=(`r(p)'), nformat(number_d2)
 
count if owner_sex_2==1&tax!=.
putexcel E20=(`r(N)')
count if owner_sex_2==2&tax!=.
putexcel F20=(`r(N)')
putexcel A20 = "Number of enterprises", bold


tabstat taxnet  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel E21=matrix(r(Stat1)),  nformat(0.0)
putexcel F21=matrix(r(Stat2)),  nformat(0.0)
putexcel A21  = "  % of enterprises in presumptive tax net"
svy: mean taxnet, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G21=(`r(p)'), nformat(number_d2)


****** Mean and standard deviation
tabstat presump_impute  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel E22=matrix(r(Stat1)),  nformat(0.0)
putexcel F22=matrix(r(Stat2)),  nformat(0.0)
putexcel A22  = "Average presumptive tax (Birr, imputed)"

** with standard deviation
tabstat presump_impute  [aw = pw_w5],  by(owner_sex_2) s(sd) save 
putexcel E23 = matrix(male), nformat("(0.0)")
putexcel F23 = matrix(female), nformat("(0.0)")


svy: mean presump_impute, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G22=(`r(p)'), nformat(number_d2)




tabstat exempt_sector [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel E24=matrix(r(Stat1)),  nformat(0.0)
putexcel F24=matrix(r(Stat2)),  nformat(0.0)
putexcel A24  = "  % in sectors with tax-free threshold"
svy: mean exempt_sector, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]
putexcel G24=(`r(p)'), nformat(number_d2)

count if owner_sex_2==1&presump_impute!=.
putexcel E25=(`r(N)')
count if owner_sex_2==2&presump_impute!=.
putexcel F25=(`r(N)') 
putexcel A25 = "Number of enterprises", bold


putexcel (E7:F7), bold
putexcel (E8:F8), bold
putexcel (E9:F9), bold
putexcel (E11:F11), bold
putexcel (E12:F12), bold
putexcel (E14:F14), bold

putexcel (E16:F16), bold
putexcel (E17:F17), bold
putexcel (E18:F18), bold

putexcel (E21:F21), bold
putexcel (E22:F22), bold
putexcel (E24:F24), bold


putexcel (E6:F6), nobold
putexcel (D6:D24), nobold
putexcel (G6:G24), nobold

/************************
* TABLE 4
************************/
set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(TABLE 4)
putexcel A1 = "Table 4: Enterprise characteristics, by sex of owner and sector", bold
putexcel B4 = "Period 1", bold
putexcel F4 = "Period 1", bold
putexcel H4 = "Period 2", bold
putexcel D4 = "Period 2", bold

putexcel D5 = "Male-owned"
putexcel E5 = "Female-owned"
putexcel H5 = "Male-owned"
putexcel I5 = "Female-owned"
putexcel F3 = "Number of enterprises", bold

putexcel (A3:I3), border(top)

putexcel (B5:I5), border(bottom)

putexcel (A20:I20),  border(bottom)

putexcel (F4:F20),  border(left)

putexcel A6 = "Median annual sales ('000 Birr) by sector", bold

tabstat gross_0  [aw = pw_w5],  by(owner_sex_2) s(median), if alcohol==1, save 
putexcel D7="na"
putexcel E7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "  Manufacturing beverages"

count if owner_sex_2==2&alcohol==1
putexcel I7=(`r(N)')

tabstat gross_0  [aw = pw_w5],  by(owner_sex_2) s(median), if food_service==1, save 
putexcel D8="na"
putexcel E8=matrix(r(Stat2)),  nformat(0.0)
putexcel A8  = "  Food and beverage services ('000 Birr)"
median gross_0, by(owner_sex_2), if food_service==1

count if owner_sex_2==2&food_service==1
putexcel I8=(`r(N)')

tabstat gross_0  [aw = pw_w5],  by(owner_sex_2) s(median), if retail_all==1, save 
putexcel D9=matrix(r(Stat1)),  nformat(0.0)
putexcel E9=matrix(r(Stat2)),  nformat(0.0)
putexcel A9  = "  Retail ('000 Birr)"
median gross_0, by(owner_sex_2), if retail_all==1

count if owner_sex_2==1&retail_all==1
putexcel H9=(`r(N)')
count if owner_sex_2==2&retail_all==1
putexcel I9=(`r(N)')

tabstat gross_0  [aw = pw_w5],  by(owner_sex_2) s(median), if transit==1, save 
putexcel D10=matrix(r(Stat1)),  nformat(0.0)
putexcel E10="na"
putexcel A10  = "  Transit services ('000 Birr)"
count if owner_sex_2==1&transit==1
putexcel H10=(`r(N)')



putexcel A11 = "Average annual sales ('000 Birr) by sector", bold

tabstat gross_0  [aw = pw_w5],  by(owner_sex_2) s(mean), if alcohol==1, save 
putexcel D12="na"
putexcel E12=matrix(r(Stat2)),  nformat(0.0)
putexcel A12  = "  Manufacture or sale of local beverages ('000 Birr)"
svy: mean gross_0,  over(owner_sex_2) , if alcohol==1
test  _b[_subpop_1] = _b[_subpop_2]


count if owner_sex_2==2&alcohol==1
putexcel I12=(`r(N)')

tabstat gross_0  [aw = pw_w5],  by(owner_sex_2) s(mean), if food_service==1, save 
putexcel D13="na"
putexcel E13=matrix(r(Stat2)),  nformat(0.0)
putexcel A13  = "  Food and beverage services ('000 Birr)"

count if owner_sex_2==2&food_service==1
putexcel I13=(`r(N)')

tabstat gross_0  [aw = pw_w5],  by(owner_sex_2) s(mean), if retail_all==1, save 
putexcel D14=matrix(r(Stat1)),  nformat(0.0)
putexcel E14=matrix(r(Stat2)),  nformat(0.0)
putexcel A14  = "  Retail ('000 Birr)"

svy: mean gross_50, over(owner_sex_2), if retail_all==1
test  _b[_subpop_1] = _b[_subpop_2]

estat sd

count if owner_sex_2==1&retail_all==1
putexcel H14=(`r(N)')
count if owner_sex_2==2&retail_all==1
putexcel I14=(`r(N)')

tabstat gross_0  [aw = pw_w5],  by(owner_sex_2) s(mean), if transit==1, save 

putexcel D15=matrix(r(Stat1)),  nformat(0.0)
putexcel E15="na"
putexcel A15  = "  Transit services ('000 Birr)"
count if owner_sex_2==1&transit==1
putexcel H15=(`r(N)')


**Firms with less than 50,000 Birr
putexcel A16  = "% with <50,000", bold


tabstat gross_50[aw = pw_w5],  by(owner_sex_2) s(mean), if alcohol==1, save
putexcel D17="na"
putexcel E17=matrix(r(Stat2)),  nformat(0.0)
putexcel A17  = "  Manufacture or sale of local beverages"


count if owner_sex_2==2&alcohol==1
putexcel I17=(`r(N)')

tabstat gross_50[aw = pw_w5],  by(owner_sex_2) s(mean), if food_service==1, save
putexcel D18="na"
putexcel E18=matrix(r(Stat2)),  nformat(0.0)
putexcel A18  = "  Food and beverage services"
svy: mean gross_50, over(owner_sex_2), if food_service==1
test  _b[_subpop_1] = _b[_subpop_2]

count if owner_sex_2==2&food_service==1
putexcel I18=(`r(N)')


tabstat gross_50[aw = pw_w5],  by(owner_sex_2) s(mean), if retail_all==1, save
putexcel D19=matrix(r(Stat1)),  nformat(0.0)
putexcel E19=matrix(r(Stat2)),  nformat(0.0)
putexcel A19  = "  Retail"
svy: mean gross_50, over(owner_sex_2), if retail_all==1
test  _b[_subpop_1] = _b[_subpop_2]


count if owner_sex_2==1&retail_all==1
putexcel H19=(`r(N)')
count if owner_sex_2==2&retail_all==1
putexcel I19=(`r(N)')

tabstat gross_50[aw = pw_w5],  by(owner_sex_2) s(mean), if transit==1, save
putexcel D20=matrix(r(Stat1)),  nformat(0.0)
putexcel E20="na"
putexcel A20  = "  Transit services"
count if owner_sex_2==1&transit==1
putexcel H20=(`r(N)')



putexcel (B9:E9), bold
putexcel (D14:E14), bold
putexcel (D19:E19), bold

************************
* TABLE 5 
************************

set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(TABLE 5)

putexcel A2 = "Table 5: Percentage of businesses in non-exempt sectors, by quartile", bold

putexcel A5 = "Quartile (turnover)"
putexcel B4 = "Period 1", bold
putexcel B5 = "Male-owned", bold
putexcel C5 = "Female-owned", bold
putexcel D5 = "Male-owned", bold
putexcel E5 = "Female-owned", bold
putexcel D4 = "Period 2", bold


putexcel (A4:E4), border(top)
putexcel (A10:E10), border(bottom)

putexcel (D3:D10), border(left)

tabstat non_exempt_sector_per  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==1&taxrate_impute!=.,s(mean) save 
putexcel D6=matrix(r(Stat1)),  nformat(0.0)
putexcel E6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "1"

svy: mean non_exempt_sector_per, over(owner_sex_2), if  gross_quartile==1&taxrate_impute!=.
test  _b[_subpop_1] = _b[_subpop_2]

tabstat non_exempt_sector_per  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==2&taxrate_impute!=., s(mean) save 
putexcel D7=matrix(r(Stat1)),  nformat(0.0)
putexcel E7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "2"
svy: mean non_exempt_sector_per, over(owner_sex_2), if  gross_quartile==2&taxrate_impute!=.
test  _b[_subpop_1] = _b[_subpop_2]


tabstat non_exempt_sector_per  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==3&taxrate_impute!=., s(mean) save 
putexcel D8=matrix(r(Stat1)),  nformat(0.0)
putexcel E8=matrix(r(Stat2)),  nformat(0.0)
putexcel A8  = "3"
svy: mean non_exempt_sector_per, over(owner_sex_2), if  gross_quartile==3&taxrate_impute!=.
test  _b[_subpop_1] = _b[_subpop_2]



tabstat non_exempt_sector_per  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==4&taxrate_impute!=., s(mean) save 
putexcel D9=matrix(r(Stat1)),  nformat(0.0)
putexcel E9=matrix(r(Stat2)),  nformat(0.0)
putexcel A9  = "4"
svy: mean non_exempt_sector_per, over(owner_sex_2), if  gross_quartile==4&taxrate_impute!=.
test  _b[_subpop_1] = _b[_subpop_2]


putexcel A10  = "Number of enterprises", italic

count if owner_sex_2==1&taxrate_impute!=.
putexcel D10=(`r(N)')
count if owner_sex_2==2&taxrate_impute!=.
putexcel E10=(`r(N)')

putexcel (A10:E10), italic

putexcel (B9:C9), bold
putexcel (B14:E14), bold
putexcel (B19:E19), bold

putexcel (D6:E6), bold
putexcel (D7:E7), bold
putexcel (D8:E8), bold

putexcel (D4:E4), merge
putexcel (F4:G4), merge
putexcel (H4:I4), merge



***************************
******FIGURE 2:  PANEL 1: SELF-REPORTED
**************************
 
 set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(FIGURE 2 PANEL 1)

putexcel A1 = "Figure 2: Effective tax rates (percentage of turnover), by turnover quartile", bold

putexcel B2 = "Panel 1: Self-reported"
putexcel A3 = "Turnover quartile"
putexcel C3 = "Period 2"


putexcel A4  = "1"
tabstat  taxrate [aw = pw_w5],s(mean ),  if  gross_quartile==1, save 
return list
matrix all = r(StatTotal)'
putexcel C4 = matrix(all), nformat(0.0)

putexcel A5  = "2"
tabstat  taxrate [aw = pw_w5], s(mean ), if  gross_quartile==2, save 
return list
matrix all = r(StatTotal)'
putexcel C5 = matrix(all), nformat(0.0)


putexcel A6  = "3"
tabstat  taxrate [aw = pw_w5],s(mean ),  if  gross_quartile==3, save 
return list
matrix all = r(StatTotal)'
putexcel C6 = matrix(all), nformat(0.0)

putexcel A7  = "4"
tabstat  taxrate [aw = pw_w5], s(mean ), if  gross_quartile==4, save 
return list
matrix all = r(StatTotal)'
putexcel C7 = matrix(all), nformat(0.0)



***************************
******FIGURE 2:  PANEL 2: IMPUTED
**************************
 
 
 
 set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(FIGURE 2 PANEL 2)

 
putexcel B2 = "Panel 2: Imputed"
putexcel A3 = "Turnover quartile"
putexcel B3 = "Period 1"
putexcel C3 = "Period 2"

putexcel A4  = "1"
tabstat  taxrate_impute [aw = pw_w5],s(mean ),  if  gross_quartile==1, save 
return list
matrix all = r(StatTotal)'
putexcel C4 = matrix(all), nformat(0.0)

putexcel A5  = "2"
tabstat  taxrate_impute [aw = pw_w5], s(mean ), if  gross_quartile==2, save 
return list
matrix all = r(StatTotal)'
putexcel C5 = matrix(all), nformat(0.0)


putexcel A6  = "3"
tabstat  taxrate_impute [aw = pw_w5],s(mean ),  if  gross_quartile==3, save 
return list
matrix all = r(StatTotal)'
putexcel C6 = matrix(all), nformat(0.0)

putexcel A7  = "4"
tabstat  taxrate_impute [aw = pw_w5], s(mean ), if  gross_quartile==4, save 
return list
matrix all = r(StatTotal)'
putexcel C7 = matrix(all), nformat(0.0)



************************
*** FIGURE 2, PANEL 4: SELF-REPORTED, PERIOD 2
*************************

 set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(FIGURE 2 PANEL 4)

putexcel B1 = "Panel 4: Self-reported, period 2"
putexcel A2 = "Turnover quartile"

putexcel B2 = "Male-owned"
putexcel C2 = "Female-owned"


tabstat taxrate  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==1,s(mean) save 
putexcel B3=matrix(r(Stat1)),  nformat(0.0)
putexcel C3=matrix(r(Stat2)),  nformat(0.0)
putexcel A3  = "1"
svy: mean taxrate, over(owner_sex_2), if  gross_quartile==1
test  _b[_subpop_1] = _b[_subpop_2]


tabstat taxrate  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==2,s(mean) save 
putexcel B4=matrix(r(Stat1)),  nformat(0.0)
putexcel C4=matrix(r(Stat2)),  nformat(0.0)
putexcel A4  = "2"
svy: mean taxrate, over(owner_sex_2), if  gross_quartile==2
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==3,s(mean) save 
putexcel B5=matrix(r(Stat1)),  nformat(0.0)
putexcel C5=matrix(r(Stat2)),  nformat(0.0)
putexcel A5  = "3"
svy: mean taxrate, over(owner_sex_2), if  gross_quartile==3
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==4,s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "4***"
svy: mean taxrate, over(owner_sex_2), if  gross_quartile==4
test  _b[_subpop_1] = _b[_subpop_2]


************************
*** FIGURE 2, PANEL 6: IMPUTED, PERIOD 2
*************************

putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(FIGURE 2 PANEL 6)

putexcel B1 = "Panel 6: Imputed, period 2"
putexcel A2 = "Turnover quartile"

putexcel B2 = "Male-owned"
putexcel C2 = "Female-owned"


tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==1,s(mean) save 
putexcel B3=matrix(r(Stat1)),  nformat(0.0)
putexcel C3=matrix(r(Stat2)),  nformat(0.0)
putexcel A3  = "1**"
svy: mean taxrate_impute, over(owner_sex_2), if  gross_quartile==1
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==2,s(mean) save 
putexcel B4=matrix(r(Stat1)),  nformat(0.0)
putexcel C4=matrix(r(Stat2)),  nformat(0.0)
putexcel A4  = "2**"
svy: mean taxrate_impute, over(owner_sex_2), if  gross_quartile==2
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==3,s(mean) save 
putexcel B5=matrix(r(Stat1)),  nformat(0.0)
putexcel C5=matrix(r(Stat2)),  nformat(0.0)
putexcel A5  = "3**"
svy: mean taxrate_impute, over(owner_sex_2), if  gross_quartile==3
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==4,s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(0.0)
putexcel C6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "4"
svy: mean taxrate_impute, over(owner_sex_2), if  gross_quartile==4
test  _b[_subpop_1] = _b[_subpop_2]

*********************
**TABLE 6 
********************
set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(TABLE 6)

putexcel A1="Table 6: Effective tax rates (percentage of turnover), by sector and sex of owner"

putexcel B3 = "(1)", bold
putexcel C3 = "(2)", bold
putexcel D3 = "(3)", bold
putexcel E3 = "(4)", bold
putexcel B4 = "Period 1", hcenter bold
putexcel D4 = "Period 2", hcenter bold
putexcel (B4:I4), border(bottom)
putexcel (A3:I3), border(top)
putexcel (F3:F31), border(left)

putexcel (A31:I31), border(bottom)

putexcel (B4:C4), merge
putexcel (D4:E4), merge


putexcel B5 = "Male-owned"
putexcel C5 = "Female-owned"

putexcel D5 = "Male-owned"
putexcel E5 = "Female-owned"
putexcel F5 = "Male-owned"
putexcel G5 = "Female-owned"
putexcel H5 = "Male-owned"
putexcel I5 = "Female-owned"

putexcel F4 = "Period 1", hcenter bold
putexcel H4 = "Period 2", hcenter bold
putexcel F3 = "Number of enterprises", hcenter bold
putexcel (F4:G4), merge
putexcel (H4:I4), merge

putexcel (F3:I3), merge

svyset ea_id[pw=pw_w5],  strata(region)

putexcel A6="(1) Effective tax rate (self-reported)"



****** Mean and standard deviation
tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel D6=matrix(r(Stat1)),  nformat(0.0)
putexcel E6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "Effective tax rate (self-reported)"
svy: mean taxrate, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(sd) save 
putexcel D7 = matrix(r(Stat1)), nformat("(0.0)")
putexcel E7 = matrix(r(Stat2)), nformat("(0.0)")


count if owner_sex_2==1&taxrate!=.
putexcel H6=(`r(N)')
count if owner_sex_2==2&taxrate!=.
putexcel I6=(`r(N)')

tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel D8=matrix(r(Stat1)),  nformat(0.0)
putexcel E8=matrix(r(Stat2)),  nformat(0.0)
putexcel A8  = "Effective tax rate (imputed)"
svy: mean taxrate_impute, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(sd) save 
putexcel D9 = matrix(r(Stat1)), nformat("(0.0)")
putexcel E9 = matrix(r(Stat2)), nformat("(0.0)")

count if owner_sex_2==1&taxrate_impute!=.
putexcel H8=(`r(N)')
count if owner_sex_2==2&taxrate_impute!=.
putexcel I8=(`r(N)')


tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(mean), if taxpaid==1, save 
putexcel D10=matrix(r(Stat1)),  nformat(0.0)
putexcel E10=matrix(r(Stat2)),  nformat(0.0)
putexcel A10  = "Effective tax rate (self-reported), given tax>0"
svy: mean taxrate, over(owner_sex_2), if taxpaid==1
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(sd), if taxpaid==1, save 
putexcel D11 = matrix(r(Stat1)), nformat("(0.0)")
putexcel E11 = matrix(r(Stat2)), nformat("(0.0)")


count if owner_sex_2==1&taxpaid==1&taxrate!=.
putexcel H10=(`r(N)')
count if owner_sex_2==2&taxpaid==1&taxrate!=.
putexcel I10=(`r(N)')

putexcel A12  = "Effective tax rate (imputed), given tax>0"

tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(mean), if presump_impute>0&presump_impute!=., save 
putexcel D12=matrix(r(Stat1)),  nformat(0.0)
putexcel E12=matrix(r(Stat2)),  nformat(0.0)
svy: mean taxrate_impute, over(owner_sex_2), if presump_impute>0&presump_impute!=.
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(sd), if presump_impute>0&presump_impute!=., save 
putexcel D13 = matrix(r(Stat1)), nformat("(0.0)")
putexcel E13 = matrix(r(Stat2)), nformat("(0.0)")


count if owner_sex_2==1&taxrate_impute!=.&presump_impute>0&presump_impute!=.
putexcel H12=(`r(N)')
count if owner_sex_2==2&taxrate_impute!=.&presump_impute>0&presump_impute!=.
putexcel I12=(`r(N)')

putexcel A14  =   "Effective tax rate (self-reported), by sector"


putexcel A15  =   "(5) Manufacturing or sale of local beverages"
count if owner_sex_2==2& alcohol==1&taxrate!=.
putexcel I15=(`r(N)')

tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(mean), if  alcohol==1, save 
putexcel D15 = "na"
putexcel E15=matrix(r(Stat2)),  nformat(0.0)

tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(sd), if  alcohol==1, save 
putexcel E16 = matrix(r(Stat2)), nformat("(0.0)")


putexcel A17  =  "(6)  Food and beverage services"
count if owner_sex_2==2& food_service==1&taxrate!=.
putexcel I17=(`r(N)')

tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(mean), if  food_service==1, save 
putexcel D17 = "na"
putexcel E17=matrix(r(Stat2)),  nformat(0.0)

tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(sd), if  food_service==1, save 
putexcel E18 = matrix(r(Stat2)), nformat("(0.0)")


putexcel A19  =  "(7)  Retail trade"
count if owner_sex_2==1& retail_all==1&taxrate!=.
putexcel H19=(`r(N)')
count if owner_sex_2==2& retail_all==1&taxrate!=.
putexcel I19=(`r(N)')

tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(mean), if  retail_all==1, save 
putexcel D19=matrix(r(Stat1)),  nformat(0.0)
putexcel E19=matrix(r(Stat2)),  nformat(0.0)

svy: mean taxrate, over(owner_sex_2), if retail_all==1
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(sd), if  retail_all==1, save 
putexcel D20 = matrix(r(Stat1)), nformat("(0.0)")
putexcel E20 = matrix(r(Stat2)), nformat("(0.0)")

putexcel A21  =   "(8) Transit services"
count if owner_sex_2==1& transit==1&taxrate!=.
putexcel H21=(`r(N)')


tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(mean), if  transit==1, save 
putexcel D21=matrix(r(Stat1)),  nformat(0.0)
putexcel E21 = "na"

tabstat taxrate  [aw = pw_w5],  by(owner_sex_2) s(sd), if  transit==1, save 
putexcel D22 = matrix(r(Stat1)), nformat("(0.0)")


putexcel A23="Effective tax rate (imputed), by sector"

putexcel A24  = "(9) Manufacturing or sale of local beverages"
tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(mean), if alcohol==1, save 
putexcel D24 = "na"
putexcel E24=matrix(r(Stat2)),  nformat(0.0)

tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(sd), if alcohol==1, save 
putexcel E25=matrix(r(Stat2)),   nformat("(0.0)")

count if owner_sex_2==2&taxrate_impute!=.& (alcohol==1)
putexcel I24=(`r(N)')


putexcel A26  = "(10)  Food and beverage services"
tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(mean), if food_service==1, save 
putexcel D26 = "na"
putexcel E26=matrix(r(Stat2)),  nformat(0.0)

tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(sd), if food_service==1, save 
putexcel E27=matrix(r(Stat2)),   nformat("(0.0)")

count if owner_sex_2==2&taxrate_impute!=.& (food_service==1)
putexcel I26=(`r(N)')


putexcel A28 = "(11) Retail trade"
tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(mean), if retail_all==1, save 
putexcel D28=matrix(r(Stat1)),  nformat(0.0)
putexcel E28=matrix(r(Stat2)),  nformat(0.0)

tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(sd), if retail_all==1, save 
putexcel D29 = matrix(r(Stat1)), nformat("(0.0)")
putexcel E29 = matrix(r(Stat2)), nformat("(0.0)")

svy: mean taxrate_impute, over(owner_sex_2), if retail_all==1
test  _b[_subpop_1] = _b[_subpop_2]

count if owner_sex_2==1&taxrate_impute!=.& retail_all==1
putexcel H28=(`r(N)')
count if owner_sex_2==2&taxrate_impute!=.& retail_all==1.
putexcel I28=(`r(N)')

putexcel A30  = "(12) Transit services"
tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(mean), if transit==1, save 
putexcel D30=matrix(r(Stat1)),  nformat(0.0)
putexcel E30 = "na"
tabstat taxrate_impute  [aw = pw_w5],  by(owner_sex_2) s(sd), if transit==1, save 
putexcel D31=matrix(r(Stat1)),   nformat("(0.0)")

count if owner_sex_2==1&taxrate_impute!=.& transit==1
putexcel H30=(`r(N)')



putexcel (D28:E28), bold

putexcel (D8:E8), bold

***********
*** TABLE 7
************HYPOTHETICAL TAX RATE (2.5% ON TURNOVER OF FIRMS MAKING OVER 50,000 
*****************************************

putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(TABLE 7)

svyset ea_id[pw=pw_w5],  strata(region)
count if owner_sex_2==1&taxrate!=.
putexcel D8=(`r(N)')
count if owner_sex_2==2&taxrate!=.
putexcel E8=(`r(N)')

putexcel A1 =  "Table 7: Effective tax rates of a hypothetical presumptive tax, by sex (2.5% of turnover)", bold
putexcel B4 = "Period 1", bold hcenter
putexcel D4 = "Period 2", bold hcenter
putexcel B5 = "Male-owned", bold
putexcel C5 = "Female-owned", bold
putexcel D5 = "Male-owned", bold
putexcel E5 = "Female-owned", bold


putexcel (B4:C4), merge
putexcel (D4:E4), merge
putexcel A8 = "Number of enterprises", italic

tabstat presump_hyp_rate  [aw = pw_w5],  by(owner_sex_2), if taxrate!=., s(mean) save 
putexcel D6=matrix(r(Stat1)),  nformat(0.0)
putexcel E6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "(1) Effective tax rate (all)"
svy: mean presump_hyp_rate, over(owner_sex_2), if taxrate!=.
test  _b[_subpop_1] = _b[_subpop_2]


tabstat presump_hyp_rate  [aw = pw_w5],  by(owner_sex_2), if presump_hyp_rate>0& taxrate!=., s(mean) save 
putexcel D7=matrix(r(Stat1)),  nformat(0.0)
putexcel E7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "(2) Effective tax rate, given tax>0"



putexcel (A8:E8), italic
putexcel (B6:C6), bold
putexcel (D6:E6), bold


********************************
********FIGURE 3
******************************
/*
separate presump_hyp_rate, by(owner_sex_2) veryshortlabel
graph bar (mean) presump_hyp_rate1 presump_hyp_rate2,  over(gross_quartile) nofill bar(1, bcolor(blue)) bar(2, bcolor(orange)) blabel(bar,  format(%9.1f)), [pw=pw_w5], ///
 title("Panel 2: hypothetical, period 2")  ytitle("")  ylabel(0 2 4 6 8 10 12 14) legend(order(1 "Male" 2 "Female" )) ///
graphregion(color(white)) bgcolor(white)   
graph save Graph "$excel/Figure4_2.gph", replace
*/
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(FIGURE 3 PANEL2)

/*
separate presump_hyp_rate, by(owner_sex_2) veryshortlabel
graph bar (mean) presump_hyp_rate1 presump_hyp_rate2,  over(gross_quartile) nofill bar(1, bcolor(blue)) bar(2, bcolor(orange)) blabel(bar,  format(%9.1f)), [pw=pw_w5], ///
 title("Panel 1: hypothetical, period 1")  ytitle("")  ylabel(0 2 4 6 8 10 12 14) legend(order(1 "Male" 2 "Female" )) ///
graphregion(color(white)) bgcolor(white)   
graph save Graph "$excel/Figure4_1.gph", replace
*/


putexcel A1="Figure 3: Effective tax rates of a hypothetical presumptive tax, by turnover quartile"

putexcel B2 = "Panel 2: hypothetical, period 2"
putexcel A3 = "Turnover quartile"

putexcel B3 = "Male-owned"
putexcel C3 = "Female-owned"


tabstat presump_hyp_rate  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==1&taxrate!=.,s(mean) save 
putexcel B4=matrix(r(Stat1)),  nformat(0.0)
putexcel C4=matrix(r(Stat2)),  nformat(0.0)
putexcel A4  = "1"
svy: mean presump_hyp_rate, over(owner_sex_2), if  gross_quartile==1
test  _b[_subpop_1] = _b[_subpop_2]

tabstat presump_hyp_rate  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==2&taxrate!=.,s(mean) save 
putexcel B5=matrix(r(Stat1)),  nformat(0.0)
putexcel C5=matrix(r(Stat2)),  nformat(0.0)
putexcel A5  = "2"
svy: mean presump_hyp_rate, over(owner_sex_2), if  gross_quartile==2
test  _b[_subpop_1] = _b[_subpop_2]

tabstat presump_hyp_rate  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==3&taxrate!=.,s(mean) save 
putexcel B6=matrix(r(Stat1)),  nformat(number_d2)
putexcel C6=matrix(r(Stat2)),  nformat(number_d2)
putexcel A6  = "3***"
svy: mean presump_hyp_rate, over(owner_sex_2), if  gross_quartile==3
test  _b[_subpop_1] = _b[_subpop_2]

tabstat presump_hyp_rate  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==4&taxrate!=.,s(mean) save 
putexcel B7=matrix(r(Stat1)),  nformat(0.0)
putexcel C7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "4"
svy: mean presump_hyp_rate, over(owner_sex_2), if  gross_quartile==4
test  _b[_subpop_1] = _b[_subpop_2]




******************************
***** APPENDIX 5 THIS GENERATES DATA FOR THE GRAPHS
*************************

putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 5)

svyset ea_id[pw=pw_w5],  strata(region)

putexcel B1 = "Appendix 5: Primary location where enterprise operates", bold

putexcel B14 = "Period 2 (2021/2022)"

putexcel B15 = "Male-owned"
putexcel C15 = "Female-owned"

tabstat home_inside  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B16=matrix(r(Stat1)),  nformat(0.0)
putexcel C16=matrix(r(Stat2)),  nformat(0.0)
putexcel A16  = "Inside home***"
svy: mean home_inside, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat home_outside  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B17=matrix(r(Stat1)),  nformat(0.0)
putexcel C17=matrix(r(Stat2)),  nformat(0.0)
putexcel A17  = "Outside home"
svy: mean home_outside, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat market  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B18=matrix(r(Stat1)),  nformat(0.0)
putexcel C18=matrix(r(Stat2)),  nformat(0.0)
putexcel A18  = "Traditional market*"
svy: mean market, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat shop  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B19=matrix(r(Stat1)),  nformat(0.0)
putexcel C19=matrix(r(Stat2)),  nformat(0.0)
putexcel A19  = "Shop in commercial area**"
svy: mean shop, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat road  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B20=matrix(r(Stat1)),  nformat(0.0)
putexcel C20=matrix(r(Stat2)),  nformat(0.0)
putexcel A20 = "Roadside"
svy: mean road, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat mobile  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B21=matrix(r(Stat1)),  nformat(0.0)
putexcel C21=matrix(r(Stat2)),  nformat(0.0)
putexcel A21  = "Mobile location***"
svy: mean mobile, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat construction_site  [aw = pw_w5],  by(owner_sex_2) s(mean) save 
putexcel B22=matrix(r(Stat1)),  nformat(0.0)
putexcel C22=matrix(r(Stat2)),  nformat(0.0)
putexcel A22  = "Construction site*"
svy: mean construction_site, over(owner_sex_2)
test  _b[_subpop_1] = _b[_subpop_2]


**********************
*****APPENDIX 8
***********************


putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 8)

putexcel A1 ="Appendix 8: Businesses who paid tax, by turnover quartile (%)", bold
putexcel B11 = "Period 2"
putexcel B12 = "Male-owned"
putexcel C12 = "Female-owned"

tabstat taxpaid_per [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==1,s(mean) save 
putexcel B13=matrix(r(Stat1)),  nformat(0.0)
putexcel C13=matrix(r(Stat2)),  nformat(0.0)
putexcel A13  = "1"
svy: mean taxpaid_per, over(owner_sex_2), if  gross_quartile==1
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxpaid_per  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==2,s(mean) save 
putexcel B14=matrix(r(Stat1)),  nformat(0.0)
putexcel C14=matrix(r(Stat2)),  nformat(0.0)
putexcel A14  = "2"
svy: mean taxpaid_per, over(owner_sex_2), if  gross_quartile==2
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxpaid_per  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==3,s(mean) save 
putexcel B15=matrix(r(Stat1)),  nformat(0.0)
putexcel C15=matrix(r(Stat2)),  nformat(0.0)
putexcel A15  = "3"
svy: mean taxpaid_per, over(owner_sex_2), if  gross_quartile==3
test  _b[_subpop_1] = _b[_subpop_2]

tabstat taxpaid_per  [aw = pw_w5],  by(owner_sex_2), if  gross_quartile==4,s(mean) save 
putexcel B16=matrix(r(Stat1)),  nformat(0.0)
putexcel C16=matrix(r(Stat2)),  nformat(0.0)
putexcel A16  = "4***"
svy: mean taxpaid_per, over(owner_sex_2), if  gross_quartile==4
test  _b[_subpop_1] = _b[_subpop_2]


*******************
***** APPENDIX 9.1.    ** Impact on tax revenue
************************

gen presump_hyp_current=presump_hyp if taxpaid==1
replace presump_hyp_current=0 if taxpaid==0
lab var presump_hyp_current "Hypothetical tax (2.5%) at current compliance"


foreach var in  taxpaying_hyp taxpaying_hyp50  taxpaying_hyp_2 taxpaying_hyp_2_50{
    gen `var'_per=`var'*100
}


putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 9.1)
putexcel A1 = "Appendix A10.2: Estimated Tax Revenue (2.5% of turnover and exemption for firms earning 50,000 Birr or less), ESS 2021/2022", bold

*****2.5% of turnover
svyset ea_id[pw=pw_w5],  strata(region)



putexcel A5 = "Existing system", bold
putexcel A6  = "(1) Estimated revenue"

putexcel C5 = "Percentage of taxpaying firms (%)", bold hcenter
putexcel B5 = "'000,000 Birr", bold hcenter
tabstat taxpaid_per [aw = pw_w5], save 
return list
matrix taxpaid = r(StatTotal)'
putexcel C6 = matrix(taxpaid), nformat(0.0)

putexcel A8 = "First Scenario: 2.5% on turnover,100% tax compliance", bold 
putexcel A9 = "(2) Estimated revenue under hypothetical system (100% compliance)"

tabstat taxpaying_hyp_per [aw = pw_w5], save 
return list
matrix taxpaying_hyp = r(StatTotal)'
putexcel C9 = matrix(taxpaying_hyp), nformat(0.0)

putexcel A11 = "Second Scenario: 2.5% on turnover, only tax compliance by larger revenue firms >100,000 Birr", bold 
putexcel A12  = "(3) Estimated revenue under hypothetical system (only by larger revenue firms)" 

tabstat taxpaying_hyp50_per [aw = pw_w5], save 
return list
matrix taxpaid_hyp50 = r(StatTotal)'
putexcel C12 = matrix(taxpaid_hyp50), nformat(0.0)

count if tax!=.
putexcel B13=(`r(N)')
putexcel A13 = "Number of enterprises", bold italic

putexcel (A13:C13), bold italic

putexcel (A5:C5), border(top)
putexcel (B6:C6), border(bottom)
putexcel (A13:C13), border(bottom)


****************
*********APPENDIX 9.2 
**2% on turnover
**************

putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 9.2)

putexcel A1 = "Appendix A10.2: Estimated Tax Revenue (2% of turnover and exemption for firms earning 50,000 Birr or less), ESS 2021/2022", bold


svyset ea_id[pw=pw_w5],  strata(region)


putexcel A5 = "Existing system", bold
putexcel A6  = "(1) Estimated revenue"

putexcel C5 = "Percentage of taxpaying firms (%)", bold hcenter
putexcel B5 = "'000,000 Birr", bold hcenter
tabstat taxpaid_per [aw = pw_w5], save 
return list
matrix taxpaid = r(StatTotal)'
putexcel C6 = matrix(taxpaid), nformat(0.0)

putexcel A8 = "First Scenario: 2% on turnover, 100% tax compliance", bold 
putexcel A9 = "(2) Estimated revenue under hypothetical system (100% compliance)" 

tabstat  taxpaying_hyp_2_per [aw = pw_w5], save 
return list
matrix taxpaying_hyp = r(StatTotal)'
putexcel C9 = matrix(taxpaying_hyp), nformat(0.0)

putexcel A11 = "Second Scenario: 2% on turnover, only tax compliance by larger revenue firms >100,000 Birr", bold 
putexcel A12  = "(3) Estimated revenue under hypothetical system (only by larger revenue firms)" 

tabstat taxpaying_hyp_2_50_per [aw = pw_w5], save 
return list
matrix taxpaid_hyp50 = r(StatTotal)'
putexcel C12 = matrix(taxpaid_hyp50), nformat(0.0)

count if tax!=.
putexcel B13=(`r(N)')
putexcel A13 = "Number of enterprises", bold italic

putexcel (A13:C13), bold italic

putexcel (A5:C5), border(top)
putexcel (B6:C6), border(bottom)
putexcel (A13:C13), border(bottom)





***********
*** APPENDIX 10
************HYPOTHETICAL TAX RATE (2% ON TURNOVER OF FIRMS MAKING OVER 50,000 
*****************************************

putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 10)

svyset ea_id[pw=pw_w5],  strata(region)
count if owner_sex_2==1&taxrate!=.
putexcel D8=(`r(N)')
count if owner_sex_2==2&taxrate!=.
putexcel E8=(`r(N)')

*putexcel (B4:C4), merge
putexcel A1 =  "Appendix 10: Effective tax rates of a hypothetical presumptive tax, by sex (2% of turnover)"
putexcel D4 = "Period 2", hcenter
putexcel D5 = "Male-owned"
putexcel E5 = "Female-owned"

putexcel A8 = "Number of enterprises"

tabstat presump_hyp_rate_2  [aw = pw_w5],  by(owner_sex_2), if taxrate!=., s(mean) save 
putexcel D6=matrix(r(Stat1)),  nformat(0.0)
putexcel E6=matrix(r(Stat2)),  nformat(0.0)
putexcel A6  = "(1) Effective tax rate (all)"
svy: mean presump_hyp_rate_2, over(owner_sex_2), if taxrate!=.
test  _b[_subpop_1] = _b[_subpop_2]


tabstat presump_hyp_rate_2  [aw = pw_w5],  by(owner_sex_2), if presump_hyp_rate>0& taxrate!=., s(mean) save 
putexcel D7=matrix(r(Stat1)),  nformat(0.0)
putexcel E7=matrix(r(Stat2)),  nformat(0.0)
putexcel A7  = "(2) Effective tax rate, given tax>0"


putexcel (D6:E6), bold 

putexcel (B5:E5), border(bottom)
putexcel (A4:E4), border(top)

putexcel (A8:E8), border(bottom)

putexcel (B4:C4), merge
putexcel (D4:E4), merge




*************tax revenue
**2.5%

preserve

su tax  presump_hyp presump_hyp_50 tax_new2 tax_new25 tax_new3
collapse (sum) tax  presump_hyp presump_hyp_50 tax_new2 tax_new25 tax_new3 presump_hyp_2_50 presump_hyp_current[pw=pw_w5]

format presump_hyp %15.0f
format presump_hyp_50 %15.0f
format tax_new2 %15.0f
format tax_new25 %15.0f
format tax_new3 %15.0f
format presump_hyp_2_50 %15.0f
format presump_hyp_current %15.0f
lab var tax "Current revenue, '000 Birr"
lab var presump_hyp "Revenue, '000 Birr 2.5% of turnover exempts 50,000 Birr"
lab var presump_hyp_50 "Revenue, '000 Birr 2.5% but noncompliance for firms <100,000"
lab var tax_new2 "2% of turnover, exempts 50,000 Birr"
lab var tax_new3 "3% of turnover, exempts 50,000 Birr"
lab var presump_hyp_current "Hypothetical tax (2.5%) at current compliance"

foreach var in  tax presump_hyp presump_hyp_50 tax_new2 tax_new25 tax_new3 presump_hyp_2_50 presump_hyp_current{
    gen `var'_000=`var'/1000000
}



putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 9.1)
putexcel B4 = "'000,000 Birr"


tabstat tax_000, save 
return list
matrix current = r(StatTotal)'
putexcel B6 = matrix(current), nformat(0.0)


tabstat presump_hyp_000, save 
return list
matrix hypo50 = r(StatTotal)'
putexcel B9 = matrix(hypo50), nformat(0.0)

tabstat presump_hyp_50_000, save 

return list
matrix hypo100 = r(StatTotal)'
putexcel B12 = matrix(hypo100), nformat(0.0)
tabstat presump_hyp_50_000, save 




putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 9.2)
putexcel B4 = "'000,000 Birr"


tabstat tax_000, save 
return list
matrix current = r(StatTotal)'
putexcel B6 = matrix(current), nformat(0.0)


tabstat tax_new2_000, save 
return list
matrix hypo50 = r(StatTotal)'
putexcel B9 = matrix(hypo50), nformat(0.0)

tabstat presump_hyp_2_50_000, save 

return list
matrix hypo100 = r(StatTotal)'
putexcel B12 = matrix(hypo100), nformat(0.0)
tabstat presump_hyp_50_000, save 


restore
