


**ETHIOPIA PRESUMPTIVE TAX PAPER 
** DOFILE #3

clear all
capture log close
set more off


global rawdata 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2018
global newdata 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2018

global excel 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2018



 /*-------------------------------------------------------------------------- */
/*        HOUSING DWELLING OWNERSHIP                            */
/* -------------------------------------------------------------------------- */

 use "$rawdata/sect10a_hh_w4.dta", clear

 gen own_dwelling=s10aq02==1
 lab var own_dwelling "Own dwelling"
 
 gen electricity_cook =s10aq38==9|s10aq38==9==10
 lab var electricity_cook "Source of cooking fuel: electricity"
 gen electricity_light=s10aq34==1|s10aq34==3|s10aq34==4
 lab var electricity_light "Source of light: electricity"
 keep household_id own_dwelling electricity_light electricity_cook
 
tempfile dwelling
save `dwelling'

/* -------------------------------------------------------------------------- */
/*         10B HH LEVEL LAND ROSTER  - PARCEL LEVEL            */
/* -------------------------------------------------------------------------- */
 
 use "$rawdata/sect10b_hh_w4.dta", clear
 

lab def s10bq05 1.00 "Granted by leaders" 2.00 "Inherited" 3.00 "Rent" 4.00 "Borrowed for free" 5.00 "Moved in without permission" 6.00 "Shared crop in" 7.00 "Purchased" 8.00 "Other", replace
lab val s10bq05 s10bq05
replace s10bq05=1 if  s10bq05_os=="Granted by Local Leaders" 

*own land if the land was granted by leaders, or if the land was inherited or purchased. 
gen land=s10bq05==1.00|s10bq05==2.00|s10bq05==7.00

/* -------------------------------------------------------------------------- */
/*          COLLAPSE AT HH LEVEL                                     */
/* -------------------------------------------------------------------------- */

collapse (max) land, by(household_id)
lab var land "Own land"
* 6767 households

tempfile parcel
save `parcel'



/* -------------------------------------------------------------------------- */
/*         10D HH LEVEL LIVESTOCK OWNERSHIP          */
/* -------------------------------------------------------------------------- */
 
use "$rawdata/sect10d1_hh_w4.dta", clear


keep household_id livestock_cd s10dq01
gen own_oxen= (livestock_cd==502)& s10dq01==1
gen own_largelv=(livestock_cd==501|livestock_cd==503|livestock_cd==504|livestock_cd==505|livestock_cd==506)& (s10dq01==1)
 
collapse (max) own_oxen own_largelv, by(household_id)
lab var own_oxen "HH owns oxen"
lab var own_largelv "HH owns other large livestock"


tempfile livestock
save `livestock'

/* -------------------------------------------------------------------------- */
/*          A. HOUSEHOLD ROSTER                                   */
/* -------------------------------------------------------------------------- */
 ***Household roster 
 
use "$rawdata/sect1_hh_w4.dta", clear

** Drop servants
drop if s1q01==14

ren s1q03a age
gen head=s1q01==1
gen woman=s1q02==2
gen f_head=head==1&woman==1
gen husband=s1q01==2&woman==0
gen daughter=(s1q01==3)&(woman==1)&(age>=18)
gen son=(s1q01==3)&(woman==0)&(age>=18)
gen son_inlaw=s1q01==9&woman==0&age>=18
gen father=s1q01==5&woman==0
gen nephew=s1q01==7&woman==0&age>=18
ren s1q09 marital

gen spouse_underage=s1q01==2&age<18
gen spouse_hh=s1q01==2

gen head_married_polygamous=head==1&(marital==3)
gen head_married_monogamous=head==1&(marital==2)

gen head_married=head==1&(marital==2|marital==3|marital==7)
gen head_spouse_hh=s1q10==1&head==1
gen head_divorce=head==1&(marital==4|marital==5)
gen head_widow=head==1&marital==6
gen head_nevermarried=head==1&marital==1

gen adult_f=woman==1&age>=18
gen adult_m=woman==0&age>=18
gen head_age=age if head==1

gen hhsize_new=1

gen head_muslim = head==1&s1q08==4
gen head_protestant=head==1&s1q08==3

* Dependency ratio is the ratio of dependents (people younger than 15 or older than 64) to the working-age population (ages 15–64).

gen age5=age<=5
gen age610=age>5&age<=10
gen age1115=age>10&age<15
gen young=age<15
gen old=age>64
gen workage=age>=15&age<=64

/* -------------------------------------------------------------------------- */
/*          COLLAPSE AT HH LEVEL    -RURAL                                    */
/* -------------------------------------------------------------------------- */

collapse (sum) hhsize_new adult_f adult_m young old workage age5 age610 age1115 (max) spouse_hh spouse_underage head_spouse_hh head_married_monogamous head_married_polygamous husband son daughter father nephew son_inlaw head_protestant head_muslim head_age head_married head_widow head_divorce head_nevermarried  f_head, by(household_id)

lab var spouse_hh "HH head's spouse in HH from q2"
lab var spouse_underage "HH head's spouse <18"
lab var head_spouse_hh "HH head's spouse in HH from q10"
lab var hhsize_new "Household size, new"
lab var f_head "Female headed households"
lab def f_head  0 "Male" 1 "Female"
lab val f_head f_head
lab var adult_f "Number of adult women"
lab var adult_m "Number of adult men"
lab var head_married "Head married"
lab var head_divorce "Head divorced, separated"
lab var head_widow "Head widow"
lab var head_nevermarried "Head never married"
lab var head_age "Age of household head"
lab var young "Number of children younger than 15"
lab var old "Number of seniors older than 64"
lab var workage "Number of working age adults"
lab var age5 "Number of children age 5 or younger"
lab var age610 "Number of children 6-10"
lab var age1115 "Number of children 11-14"
lab var head_muslim "Head is Muslim" 
lab var head_protestant "Head is Protestant"
lab var son "Adult son in HH"
lab var daughter "Adult daughter in HH"
lab var father "Father in HH"
lab var husband "Husband in HH"
lab var nephew "Adult nephew in HH"
lab var son_inlaw "Adult son-in-law in HH"
***Oct 9, 2020 Switched hh_type 
gen      hh_type=1 if adult_m>0&adult_f>0
replace  hh_type=2 if adult_m==0&adult_f>0
replace  hh_type=3 if adult_m>0&adult_f==0
replace  hh_type=4 if adult_m==0&adult_f==0
lab def hh_type  1 "Dual adult" 2 "Female adult only" 3 "Male adult only" 4 "No adults"
lab val hh_type hh_type
lab var hh_type "Household type"

gen sex_comp=1 if adult_m>adult_f
replace sex_comp=2 if adult_m<adult_f
replace sex_comp=3 if adult_m==adult_f
lab def sex_comp 1 "More men" 2 "More women" 3 "Equal number"
lab val sex_comp sex_comp
lab var sex_comp "HH sex composition"

gen      marital_type_4=1 if f_head==0&head_married==1
replace  marital_type_4=2 if f_head==0&(head_divorce==1|head_nevermarried==1|head_widow==1)
replace  marital_type_4=3 if f_head==1&head_married==1
replace  marital_type_4=4 if f_head==1&(head_divorce==1|head_nevermarried==1|head_widow==1)
lab def marital_type_4 1 "Married male head" 2 "Divorced/widow/never married male head"   3 "Married female head"  4 "Divorced/widow/never married female head"  
lab val marital_type_4 marital_type_4

gen dependency=(young+old)/workage
replace dependency = 10 if workage==0
lab var dependency "Dependency ratio"

tempfile household
save `household'


/* -------------------------------------------------------------------------- */
/*          CONSUMPTION AGGREGATES    -- RURAL AND URBAN                               */
/* -------------------------------------------------------------------------- */
 
use "$rawdata/cons_agg_w4.dta", clear
*6770 households
ren saq14 rural

keep household_id ea_id saq01 rural pw_w4 spat_totcons_aeq nom_totcons_aeq total_cons_ann cons_quint  hh_size

tempfile consumption
save `consumption'

merge 1:1 household_id using `dwelling'
drop _m

merge 1:1 household_id using `parcel'
drop _m

merge 1:1 household_id using `livestock'
drop _m

merge 1:1 household_id using "$newdata/ethiopia_household_Oct92023.dta"
drop _m
lab var tax "Taxes paid as profit or income tax,=0 if no tax paid"
lab var tax_0 "Taxes paid as profit or income tax, '000"
merge 1:1 household_id using  `household'
drop _m

merge 1:1 household_id using "$newdata/ethiopia_household_number.dta"
drop _m
replace enterprise_hh=0 if enterprise_hh==.

gen tax_cons=tax/total_cons_ann
replace tax_cons=0 if tax_cons==.
lab var tax_cons "Tax as a % of hh consumption"


gen tax_cons_impute=presump_impute/total_cons_ann
replace tax_cons_impute=0 if tax_cons_impute==.
lab var tax_cons_impute "Imputed tax as a % of hh consumption"

gen quint_2=0 if cons_quint==1|cons_quint==2
replace quint_2=cons_quint==3|cons_quint==4|cons_quint==5
lab var quint_2 "40/60 of cons quintile"
lab def quint_2 0 "Bottom 40%" 1 "Top 60%"
lab val quint_2 quint_2

gen hh_type_sex=1 if hh_type==1|hh_type==3|hh_type==4
replace hh_type_sex=2 if hh_type==2
lab def hh_type_sex 1 "Dual adult or male" 2 "Female only", replace
lab val hh_type_sex hh_type_sex
** 26 households have both male-owned and female-owned enterprises



gen f_only= hh_type==2
lab var f_only "Female only household"

gen hh_f_enterprise= female_owned==1
lab var hh_f_enterprise "HH owns female owned enterprise"

gen hh_m_enterprise= male_owned==1
lab var hh_m_enterprise "HH owns male/joint owned enterprise"

gen hh_food_service=food_service==1
lab var hh_food_service "HH owns food service"


gen hh_bar=bar==1
lab var hh_bar "HH owns bar, hotel"

gen hh_restaurant=restaurant==1
lab var hh_restaurant "HH owns restaurant"

gen hh_female_food_service=food_service==1&female_owned==1
lab var hh_female_food_service "HH owns female-owned food service"

gen hh_alcohol=alcohol==1
lab var hh_alcohol "HH owns alcohol"

gen hh_transit=transit==1
lab var hh_transit "HH owns transit enterprise"

gen hh_retail=retail_all==1
lab var hh_retail "HH owns retail enterprise"

gen hh_other_pc=other_pc==1
lab var hh_other_pc "HH owns other personal service"

gen ln_cons=log(spat_totcons_aeq)

gen electricity=electricity_light ==1| electricity_cook==1
lab var electricity "Electricity source of light or cooking fuel"
gen livestock=own_oxen==1|own_largelv ==1
ren saq01 region

gen wave=4

gen enterprise_hh_per=enterprise_hh*100
save "$newdata/enterprise_household_wave4_Oct92023.dta", replace

use "$newdata/enterprise_household_wave4_Oct92023.dta", clear

**************************
*****TABLE 1
***************************
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(TABLE1)

svyset ea_id[pw=pw_w4],  strata(region)

putexcel A1 = "Table 1: Percentage of households with a non-farm enterprise (NFE), by household type"
putexcel B4 = "Period 1", bold hcenter
putexcel B5 = "2018/2019", bold hcenter



putexcel A6  = "% of households with NFEs"
tabstat  enterprise_hh_per [aw = pw_w4], save 
return list
matrix all = r(StatTotal)'
putexcel B6 = matrix(all), nformat(0.0)
count if enterprise_hh_per!=.
putexcel B7=(`r(N)')

putexcel B8 = "Period 1", bold hcenter



putexcel B9  = "Dual adult households", bold
putexcel C9 = "Female only households", bold

tabstat enterprise_hh_per[aw = pw_w4],  by( hh_type_sex) s(mean) save 
putexcel B10=matrix(r(Stat1)),  nformat(0.0)
putexcel C10=matrix(r(Stat2)),  nformat(0.0)
putexcel A10  = "% of households with NFEs"
svy: mean enterprise_hh_per, over(hh_type_sex)
test  _b[_subpop_1] = _b[_subpop_2]

count if hh_type_sex==1
putexcel B11=(`r(N)')
count if hh_type_sex==2
putexcel C11=(`r(N)')
putexcel A11  = "Number of households", italic


tabstat enterprise_hh_per[aw = pw_w4],  by( hh_type_sex), if quint_2==0, s(mean) save 
putexcel B12=matrix(r(Stat1)),  nformat(0.0)
putexcel C12=matrix(r(Stat2)),  nformat(0.0)
putexcel A12  = "% of poor households with NFEs"
svy: mean enterprise_hh_per, over(hh_type_sex), if quint_2==0
test  _b[_subpop_1] = _b[_subpop_2]


tabstat enterprise_hh_per[aw = pw_w4],  by( hh_type_sex), if quint_2==1, s(mean) save 
putexcel B13=matrix(r(Stat1)),  nformat(0.0)
putexcel C13=matrix(r(Stat2)),  nformat(0.0)
putexcel A13  = "% of nonpoor households with NFEs"
svy: mean enterprise_hh_per, over(hh_type_sex), if quint_2==1
test  _b[_subpop_1] = _b[_subpop_2]


putexcel (D13:E14), bold

**************************
*****APPENDIX 2: BY SEX OF HOUSEHOLD HEAD
***************************

gen f_head_2=1 if f_head==0
replace f_head_2=2 if f_head==1
lab def f_head_2 1 "Male-headed" 2 "Female-headed"
lab val f_head_2 f_head_2

putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 2)

svyset ea_id[pw=pw_w4],  strata(region)

putexcel A1 = "Appendix 2: Percentage of households with a non-farm enterprise (NFE), by household type"
putexcel B4 = "Period 1", bold hcenter
putexcel B5 = "2018/2019", bold hcenter
putexcel B5 = "2018/2019", bold hcenter



putexcel A6  = "% of households with NFEs"
tabstat  enterprise_hh_per [aw = pw_w4], save 

putexcel A6  = "% of households with NFEs"
tabstat  enterprise_hh_per [aw = pw_w4], save 
return list
matrix all = r(StatTotal)'
putexcel B6 = matrix(all), nformat(0.0)
count if enterprise_hh_per!=.
putexcel B7=(`r(N)')

putexcel B8 = "Period 1", bold hcenter



putexcel B9  = "Male-headed households", bold
putexcel C9 = "Female-headed households", bold

tabstat enterprise_hh_per[aw = pw_w4],  by( f_head_2) s(mean) save 
putexcel B10=matrix(r(Stat1)),  nformat(0.0)
putexcel C10=matrix(r(Stat2)),  nformat(0.0)
putexcel A10  = "% of households with NFEs"
svy: mean enterprise_hh_per, over(f_head_2)
test  _b[_subpop_1] = _b[_subpop_2]

count if f_head_2==1
putexcel B11=(`r(N)')
count if f_head_2==2
putexcel C11=(`r(N)')
putexcel A11  = "Number of households", italic


tabstat enterprise_hh_per[aw = pw_w4],  by( f_head_2), if quint_2==0, s(mean) save 
putexcel B12=matrix(r(Stat1)),  nformat(0.0)
putexcel C12=matrix(r(Stat2)),  nformat(0.0)
putexcel A12  = "% of poor households with NFEs"
svy: mean enterprise_hh_per, over(f_head_2), if quint_2==0
test  _b[_subpop_1] = _b[_subpop_2]


tabstat enterprise_hh_per[aw = pw_w4],  by( f_head_2), if quint_2==1, s(mean) save 
putexcel B13=matrix(r(Stat1)),  nformat(0.0)
putexcel C13=matrix(r(Stat2)),  nformat(0.0)
putexcel A13  = "% of nonpoor households with NFEs"
svy: mean enterprise_hh_per, over(f_head_2), if quint_2==1
test  _b[_subpop_1] = _b[_subpop_2]


putexcel (B13:C14), bold

preserve 
keep household_id hh_m_enterprise hh_f_enterprise  land electricity livestock  hhsize_new age5 age610 age1115 head_age head_married head_protestant head_muslim
save  "$newdata/household_vars.dta", replace

restore

preserve 
keep household_id  hh_type_sex adult_m hhsize_new
save  "$newdata/household_type.dta", replace

restore

