
**ETHIOPIA PRESUMPTIVE TAX PAPER 
** DOFILE #5


**********
****APPENDIX 2
*****************
*****PLEASE USE STATA 16 OR HIGHER FOR THE GRAPH. STATA CORRECTED BANDWIDTH VALUES

set more off


ssc install grstyle
ssc install colrspace




global wave4 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2018
global wave5 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2021

global excel 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2018



*****************************************
******* average firm size (turnover)



use "$wave4/ethiopia_enterprise_wave4_Oct92023", clear

keep household_id gross
collapse (mean) gross, by(household_id)

ren gross av_gross
gen wave=4
lab var av_gross "Average enterprise revenue per household, Birr, 2019 prices"
tempfile wave4
save `wave4'



use "$wave5/ethiopia_enterprise_wave5_Oct92023.dta", clear

keep household_id gross
collapse (mean) gross, by(household_id)
gen av_gross=(gross/152.7)*100 
drop gross
gen wave=5
lab var av_gross "Average enterprise revenue per household, Birr, 2019 prices"
tempfile wave5
save `wave5'

******************************************
***** POOLED HOUSEHOLDS IN WAVES 4 AND 5
*****************************************


use "$wave4/enterprise_household_wave4_Oct92023.dta", clear

keep household_id ea_id region rural spat_totcons_aeq pw_w4 f_head total_cons_ann tax presump_impute wave own_dwelling electricity_cook electricity_light electricity head_married   hhsize_new  ln_cons age5 age610 age1115 head_age  head_protestant head_muslim f_only enterprise_hh hh_f_enterprise hh_m_enterprise hh_food_service hh_alcohol hh_retail hh_bar hh_restaurant hh_transit hh_other_pc adult_f adult_m hh_type

tempfile household4
save `household4'


use "$wave5/enterprise_household_wave5_Oct092023.dta", clear
**4959 households
keep household_id ea_id region rural spat_totcons_aeq pw_w5 f_head total_cons_ann tax presump_impute wave own_dwelling electricity_cook electricity_light electricity head_married   hhsize_new  ln_cons age5 age610 age1115 head_age  head_protestant head_muslim f_only enterprise_hh hh_f_enterprise hh_m_enterprise hh_food_service hh_alcohol hh_retail hh_bar hh_restaurant hh_transit hh_other_pc  f_only adult_f adult_m hh_type hh_f_enterprise hh_m_enterprise hh_food_service hh_bar hh_restaurant hh_alcohol hh_retail hh_transit hh_other_pc

tempfile household5
save `household5'


use `household4', clear
append using `household5'

merge 1:1 household_id wave using `wave4'
drop _m

merge 1:1 household_id wave using `wave5', update
drop _m



** 11,729  households 

*************************************
******POOLED SAMPLE
*************************************


***** use household weights for each
gen hh_weight=pw_w4
replace hh_weight=pw_w5 if hh_weight==.

lab def f_only 0 "Male" 1 "Female"
lab val f_only f_only



******CPI Ethiopia (2010 = 100)
**https://data.worldbank.org/indicator/FP.CPI.TOTL?locations=ET 
** 2010 =100 price
** 2019: 322.5
** 2021: 492.4 


** Real in 2019 prices = (nominal/CPI)*100
** 2021: 152.7 in 2019 prices

gen real_spat_totcons_aeq=spat_totcons_aeq if wave==4
replace real_spat_totcons_aeq=(spat_totcons_aeq/152.7)*100 if wave==5
lab var real_spat_totcons_aeq "Real annual consn per AEQ, spatially adjusted, 2019 prices"


***** RE-DO CONSUMPTION QUINTILES
xtile spat_aec_5_wave_4 = real_spat_totcons_aeq[pweight=pw_w4], nq(5)
lab var spat_aec_5_wave_4 "5 quintiles of real spat_totcons_aeq, wave4"

xtile spat_aec_5_wave_5 = real_spat_totcons_aeq[pweight=pw_w5], nq(5)
lab var spat_aec_5_wave_5 "5 quintiles of real spat_totcons_aeq, wave5"


xtile spat_aec_quartile = real_spat_totcons_aeq[pweight=hh_weight], nq(4)
lab var spat_aec_quartile "4 quartiles of real spat_totcons_aeq, waves 4 and 5"


xtile spat_aec_4_wave4 = real_spat_totcons_aeq[pweight=pw_w4], nq(4)
lab var spat_aec_4_wave4 "4 quartiles of real spat_totcons_aeq, wave4"

xtile spat_aec_4_wave5 = real_spat_totcons_aeq[pweight=pw_w5], nq(4)
lab var spat_aec_4_wave5 "4 quartiles of real spat_totcons_aeq, wave5"

gen quint_2_4=1 if spat_aec_5_wave_4==1|spat_aec_5_wave_4==2
replace quint_2_4=2 if spat_aec_5_wave_4==3|spat_aec_5_wave_4==4|spat_aec_5_wave_4==5
lab var quint_2_4 "40/60 of cons quintile, wave4"
lab def quint_2_4 1 "Bottom 40%" 2 "Top 60%"
lab val quint_2_4 quint_2_4


gen quint_2_5=1 if spat_aec_5_wave_5==1|spat_aec_5_wave_5==2
replace quint_2_5=2 if spat_aec_5_wave_5==3|spat_aec_5_wave_5==4|spat_aec_5_wave_5==5
lab var quint_2_5 "40/60 of cons quintile, wave5"
lab def quint_2_5 1 "Bottom 40%" 2 "Top 60%"
lab val quint_2_5 quint_2_5

save "$wave4/enterprise_household_pooled_1010023.dta", replace

drop ln_cons
gen ln_cons=log(real_spat_totcons_aeq)
lab var ln_cons "Real annual cons per AEQ, spatially adjusted, 2019 prices"

gen av_gross_0=av_gross/1000
lab var av_gross_0 "Average revenue,'000 Birr 2019 prices"

gen hh_type_2=1 if f_only==0
replace hh_type_2=2 if f_only==1
lab def hh_type_2 1 "Dual adult households" 2 "Female only households"
lab val hh_type_2 hh_type_2
lab var hh_type_2 "Household type"


gen rural_d=rural==1


lab var f_only "Female only household"
lab var ln_cons "Log of household consumption"
lab var hhsize_new "Household size"

lab var rural_d "Rural"
lab var f_head "Female headed household"


set more off
local controls     hhsize_new age5 age610 age1115 i.head_married  head_age i.electricity rural_d  i.head_protestant i.head_muslim i.region 

reg enterprise i.f_only##c.ln_cons `controls', cluster(ea_id), if wave==4
outreg2  using "$excel/table2.xls",    dec(3)  ctitle(Period 1)  keep (i.f_only ln_cons i.f_only#c.ln_cons hhsize_new rural_d) nocons  label title(Table 2: Probability that a household owns a nonfarm enterprise) replace

reg enterprise i.f_only##c.ln_cons `controls', cluster(ea_id), if wave==5

outreg2 using "$excel/table2.xls",   dec(3)  ctitle(Period 2)  keep (i.f_only ln_cons i.f_only#c.ln_cons hhsize_new rural_d) nocons label append



set more off
local controls     hhsize_new age5 age610 age1115 i.head_married  head_age i.electricity rural_d  i.head_protestant i.head_muslim i.region 

reg enterprise i.f_head##c.ln_cons `controls', cluster(ea_id), if wave==4
outreg2  using "$excel/table2.xls",    dec(3)  ctitle(Period 1)  keep (i.f_head ln_cons i.f_head#c.ln_cons hhsize_new rural_d) nocons  label title(Table 2: Probability that a household owns a nonfarm enterprise) append

reg enterprise i.f_head##c.ln_cons `controls', cluster(ea_id), if wave==5

outreg2 using "$excel/table2.xls",   dec(3)  ctitle(Period 2)  keep (i.f_head ln_cons i.f_head#c.ln_cons hhsize_new rural_d) nocons label append

	
/*
** new in STATA 16
*/

**********
****APPENDIX 3
*****************


grstyle  init

grstyle set ci burd, select(11 13 ) opacity(60)



twoway (lpolyci av_gross_0 spat_aec_quartile if hh_type_2==1 )(lpolyci av_gross_0 spat_aec_quartile if hh_type_2==2, astyle(ci2)), ///
ytitle("Average enterprise revenue, '000 Birr") xtitle("Household consumption quartile")   ylabel (10 20 30 40 50 60 70)  ///
              legend(order(2 "Dual or male households" 4 "Female households" ))  ///
              graphregion(color(white)) bgcolor(white)
              graph export "$excel\appendix3_1.png",  replace
	
	
	
twoway (lpolyci av_gross_0 spat_aec_quartile if f_head==0 )(lpolyci av_gross_0 spat_aec_quartile if f_head==1, astyle(ci2)), ///
ytitle("Average enterprise revenue, '000 Birr") xtitle("Household consumption quartile")   ylabel (10 20 30 40 50 60 70)  ///
              legend(order(2 "Male headed households" 4 "Female headed households" ))  ///
              graphregion(color(white)) bgcolor(white)
              graph export "$excel\appendix3_2.png",  replace
	


	
