

**ETHIOPIA PRESUMPTIVE TAX PAPER 
** DOFILE #7

****APPENDIX 3

set more off

global rawdata 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2021
global newdata 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2021

global excel 	/Users/hitomikomatsu/Documents/World Bank Ethiopia/ESS_2018


use "$newdata/ethiopia_enterprise_wave5_Oct92023.dta", clear


keep household_id enterprise_id food_service alcohol transit retail_all

tempfile enterprise_level
save `enterprise_level'

/* -------------------------------------------------------------------------- */
*Household sample (exludes households in bottom 1% of sales)
*

bysort household_id: gen temp=_n
keep if temp==1
*1,302 HHs
keep household_id 

tempfile household_sample
save `household_sample'

/* -------------------------------------------------------------------------- */
/*          CONSUMPTION AGGREGATES                                */
/* -------------------------------------------------------------------------- */
 
use "$rawdata/cons_agg_w5.dta", clear

keep household_id cons_quint spat_totcons_aeq hh_size

tempfile consumption
save `consumption'



/* -------------------------------------------------------------------------- */
*          HH level variables
/* -------------------------------------------------------------------------- */
 ***Household roster
 
use "$rawdata/sect1_hh_w5.dta", clear


** Drop servants
drop if s1q01==14

ren s1q03a age
gen head=s1q01==1
gen woman=s1q02==2
gen f_head=head==1&woman==1
gen daughter=(s1q01==3)&(woman==1)&(age>=18)
gen son=(s1q01==3)&(woman==0)&(age>=18)
gen son_inlaw=s1q01==9&woman==0&age>=18
gen father=s1q01==5&woman==0
gen nephew=s1q01==7&woman==0&age>=18
ren s1q09 marital

*gen spouse_underage=s1q01==2&age<18
*gen spouse_hh=s1q01==2

gen head_married_polygamous=head==1&(marital==3)
gen head_married_monogamous=head==1&(marital==2)

gen head_married=head==1&(marital==2|marital==3|marital==7)
*gen head_spouse_hh=s1q10==1&head==1
gen head_divorce=head==1&(marital==4|marital==5)
gen head_widow=head==1&marital==6
gen head_nevermarried=head==1&marital==1

gen adult_f=woman==1&age>=18
gen adult_m=woman==0&age>=18
gen head_age=age if head==1



* Dependency ratio is the ratio of dependents (people younger than 15 or older than 64) to the working-age population (ages 15–64).

gen age5=age<=5
gen age610=age>5&age<=10
gen age1115=age>10&age<15
gen young=age<15
gen old=age>64
gen workage=age>=15&age<=64

/* -------------------------------------------------------------------------- */
/*          COLLAPSE AT HH LEVEL                                      */
/* -------------------------------------------------------------------------- */

collapse (sum)  adult_f adult_m young old workage age5 age610 age1115 (max)    head_married_monogamous head_married_polygamous  son daughter father nephew son_inlaw  head_age head_married head_widow head_divorce head_nevermarried  f_head, by(household_id)

lab var f_head "Female headed households"
lab def f_head  0 "Male" 1 "Female"
lab val f_head f_head
lab var adult_f "Number of adult women"
lab var adult_m "Number of adult men"
lab var head_married "Head married"
lab var head_divorce "Head divorced, separated"
lab var head_widow "Head widow"
lab var head_nevermarried "Head never married"
lab var head_age "Age of household head"
lab var young "Number of children younger than 15"
lab var old "Number of seniors older than 64"
lab var workage "Number of working age adults"
lab var age5 "Number of children age 5 or younger"
lab var age610 "Number of children 6-10"
lab var age1115 "Number of children 11-14"

lab var son "Adult son in HH"
lab var daughter "Adult daughter in HH"
lab var father "Father in HH"
lab var nephew "Adult nephew in HH"
lab var son_inlaw "Adult son-in-law in HH"

gen      hh_type=1 if adult_m>0&adult_f>0
replace  hh_type=2 if adult_m==0&adult_f>0
replace  hh_type=3 if adult_m>0&adult_f==0
replace  hh_type=4 if adult_m==0&adult_f==0
lab def hh_type  1 "Dual adult" 2 "Female adult only" 3 "Male adult only" 4 "No adults"
lab val hh_type hh_type
lab var hh_type "Household type"

gen sex_comp=1 if adult_m>adult_f
replace sex_comp=2 if adult_m<adult_f
replace sex_comp=3 if adult_m==adult_f
lab def sex_comp 1 "More men" 2 "More women" 3 "Equal number"
lab val sex_comp sex_comp
lab var sex_comp "HH sex composition"

gen dependency=(young+old)/workage
replace dependency = 10 if workage==0
lab var dependency "Dependency ratio"

tempfile household
save `household'



/* -------------------------------------------------------------------------- */
/*          A. HOUSEHOLD ROSTER                                     */
/* -------------------------------------------------------------------------- */
 ***Household roster 
 
use "$rawdata/sect1_hh_w5.dta", clear

ren saq14 rural 
ren saq01 region

ren s1q03a age
ren s1q02 sex
gen head=s1q01==1

ren s1q09 marital
keep household_id individual_id  sex age  marital region ea_id rural pw_w5 region saq02 saq03 s1q01  head 
ren individual_id s12bq03_1
gen s12bq03_2=s12bq03_1

tempfile individual
save `individual'


*literacy

use "$rawdata/sect2_hh_w5.dta", clear

keep household_id individual_id s2q03 s2q06

tempfile literacy
save `literacy'

* By enterprise  
 use "$rawdata/sect12b1_hh_w5.dta", clear
 *1,551 enterprises
 
 *merge with indi data
merge m:1 household_id s12bq03_1 using  `individual'
keep if _m==3
drop _m
ren  s12bq03_1 individual_id
drop s12bq03_2

tempfile first_owner
save `first_owner'

* By enterprise  
 use "$rawdata/sect12b1_hh_w5.dta", clear
 
 *merge with indi data
merge m:1 household_id s12bq03_2 using  `individual'
keep if _m==3
drop _m
ren  s12bq03_2 individual_id
drop s12bq03_1

tempfile second_owner
save `second_owner'


use `first_owner', clear
append using `second_owner'

gen f_own=sex==2
gen m_own=sex==1

bysort household_id enterprise_id:egen f_owner_least=max(f_own)
lab var f_owner_least "At least one female owner"
bysort household_id enterprise_id:egen m_owner_least=max(m_own)
lab var m_owner_least "At least one male owner"
gen both_owner=f_owner_least==1&m_owner_least==1
lab var both_owner "Male and female owners"


* 58 individuals own more than 1 enterprise
bysort  household_id individual_id: gen temp=_n
drop if temp==2
drop if temp==3
drop temp

merge 1:1  household_id individual_id using `literacy'
keep if _m==3
drop _m
drop s12bq01a-s12bq02_os  s12bq04-s12bq25_os
** 1,716   individuals 

merge m:1 household_id using `household'
keep if _m==3
drop _m


merge m:1 household_id using `consumption'
keep if _m==3
drop _m

merge m:1 household_id using `household_sample'
keep if _m==3
*163 dropped
drop _m

gen f_owner_only=m_owner_least==0
lab var f_owner_only "Only female owners"
gen m_owner_only=f_owner_least==0
lab var m_owner_only "Only male owners"

gen owner_cat=1     if sex==1
replace owner_cat=2 if f_owner_only==1
replace owner_cat=3 if f_own==1&f_owner_only==0
lab def owner_cat 1 "Men" 2 "Women, only female owned" 3 "Women, joint ownership"
lab val owner_cat owner_cat
drop m_own f_own

gen married=marital==2|marital==3|marital==7
lab var married "Married"
gen divorced=marital==1|marital==4|marital==5|marital==6
lab var divorced "Never married, divorced or widowed"
lab var head "Head of household"
gen spouse=s1q01==2
lab var spouse "Spouse of head"
gen child_head=s1q01==3
lab var child_head "Child of head"
gen literate=s2q03==1
lab var literate "Literate"


gen no_maleadult=hh_type==2
lab var no_maleadult "No male adult in household (%)"
** Owner level data (unique individual owner)

tempfile owner_nosector
save `owner_nosector'

* Merge owner data with sector data

use `first_owner', clear
append using `second_owner'
keep household_id enterprise_id individual_id
**Multiple owners for one enterprise and some owners own multiple enterprises

merge m:1  household_id enterprise_id  using `enterprise_level'
keep if _m==3
* 1,594 owners


collapse (max) transit food_service alcohol, by(household_id individual_id)
*1545 owners

tempfile sector
save `sector'

use `owner_nosector', clear
merge 1:1  household_id individual_id  using `sector'

keep if _m==3
 *1,545 owners
drop _m
save "$newdata/enterprise_owners_wave5.dta", replace


set more off
*** Unique owners (ID variable)
use "$newdata/enterprise_owners_wave5.dta", clear

** merge with household variables
merge m:1 household_id using "$newdata/household_vars_wave5.dta"
keep if _m==3
drop _m


save "$newdata/enterprise_owners_wave5_Oct092023.dta", replace

gen ln_cons=log(spat_totcons_aeq)

gen f_only= hh_type==2
lab var f_only "Female only household"


foreach var in head spouse married divorced literate f_head no_maleadult{
    replace `var'=`var'*100
}



****APPENDIX 4
set more off
putexcel set "$excel/Enterprises_10112023.xlsx", modify sheet(APPENDIX 4)


putexcel B4 = "Period 1", hcenter bold
putexcel D4 = "Period 2", hcenter bold
putexcel D5 = "Male owner", bold
putexcel E5 = "Female owner", bold

tabstat age  [aw = pw_w5],  by(sex) s(mean) save 
putexcel D6=matrix(r(Stat1)),  nformat(0.0)
putexcel E6=matrix(r(Stat2)),  nformat(0.0)
svy: mean age, over(sex)
test  _b[_subpop_1] = _b[_subpop_2]

putexcel A6 = "Age"

putexcel A7 = "Relation to household head (%)", bold

tabstat head  [aw = pw_w5],  by(sex) s(mean) save 
putexcel D8=matrix(r(Stat1)),  nformat(0.0)
putexcel E8=matrix(r(Stat2)),  nformat(0.0)
putexcel A8 = "  Household head"
svy: mean head, over(sex)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat spouse  [aw = pw_w5],  by(sex) s(mean) save 
putexcel D9=matrix(r(Stat1)),  nformat(0.0)
putexcel E9=matrix(r(Stat2)),  nformat(0.0)
putexcel A9 = "  Spouse of head"
svy: mean spouse, over(sex)
test  _b[_subpop_1] = _b[_subpop_2]

putexcel A10 = "  Marital status (%)", bold

tabstat married  [aw = pw_w5],  by(sex) s(mean) save 
putexcel D11=matrix(r(Stat1)),  nformat(0.0)
putexcel E11=matrix(r(Stat2)),  nformat(0.0)
putexcel A11 = "  Married"
svy: mean married , over(sex)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat divorced  [aw = pw_w5],  by(sex) s(mean) save 
putexcel D12=matrix(r(Stat1)),  nformat(0.0)
putexcel E12=matrix(r(Stat2)),  nformat(0.0)
putexcel A12 = "  Never married, divorced or widowed"
svy: mean divorce , over(sex)
test  _b[_subpop_1] = _b[_subpop_2]

putexcel A13 = "Literacy (%)", bold

tabstat literate  [aw = pw_w5],  by(sex) s(mean) save 
putexcel D14=matrix(r(Stat1)),  nformat(0.0)
putexcel E14=matrix(r(Stat2)),  nformat(0.0)
putexcel A14 = "  Can read and write"
svy:mean  literate , over(sex)
test  _b[_subpop_1] = _b[_subpop_2]

putexcel A15 = "Household characteristics", bold

tabstat f_head  [aw = pw_w5],  by(sex) s(mean) save 
putexcel D16=matrix(r(Stat1)),  nformat(0.0)
putexcel E16=matrix(r(Stat2)),  nformat(0.0)
putexcel A16 = "  % of owners living in female-headed household"
svy: mean f_head , over(sex)
test  _b[_subpop_1] = _b[_subpop_2]


tabstat no_maleadult  [aw = pw_w5],  by(sex) s(mean) save 
putexcel D17=matrix(r(Stat1)),  nformat(0.0)
putexcel E17=matrix(r(Stat2)),  nformat(0.0)
putexcel A17 = "  No male adults in household (%)"
svy: mean no_maleadult , over(sex)
test  _b[_subpop_1] = _b[_subpop_2]

tabstat hh_size  [aw = pw_w5],  by(sex) s(mean) save 
putexcel D18=matrix(r(Stat1)),  nformat(0.0)
putexcel E18=matrix(r(Stat2)),  nformat(0.0)
putexcel A18 = "  Household size"
svy:mean  hh_size , over(sex)

test  _b[_subpop_1] = _b[_subpop_2]

tabstat dependency  [aw = pw_w5],  by(sex) s(mean) save 
putexcel D19=matrix(r(Stat1)),  nformat(0.00)
putexcel E19=matrix(r(Stat2)),  nformat(0.00)
putexcel A19 = "  Dependency ratio"
svy:mean  dependency , over(sex)

test  _b[_subpop_1] = _b[_subpop_2]

putexcel A20 = "Number of owners", bold italic


putexcel (A20:E20), border(bottom)
putexcel (A4:E4), border(top)
putexcel (B5:E5), border(bottom)

putexcel (B4:C4), merge
putexcel (D4:E4), merge

putexcel (A20:E20), italic bold

putexcel (B8:E8), bold
putexcel (B9:E9), bold
putexcel (B11:C11), bold
putexcel (B12:C12), bold
putexcel (B14:E14), bold
putexcel (B16:E16), bold
putexcel (B17:E17), bold


count if sex==1
putexcel D20=(`r(N)')
count if sex==2
putexcel E20=(`r(N)')

